/*==========================================================================
**
**	znyx/hw/bcm5000.h
**
**	Definitions for Broadcom BCM5000 part
**
**==========================================================================
**
**	(c) Copyright 1995, 1998, 1999 ZNYX Corporation
**	All Rights Reserved.
**
**==========================================================================
**
**	Modification History:
**	jr	09/13/95	Created
**	jr	10/09/95	Added BCM5000_ prefix, fixed ID
**	dew	10/23/98	Added Broadcom 5201
**	dew	02/09/99	Added Broadcom 5208
**
**==========================================================================
*/



/* MII Control Register (MIICR) */

#define	BCM5000_MIICR_REG	0x00
#define	BCM5000_MIICR_RESET	0x8000	/* Reset PHY to default		*/
#define	BCM5000_MIICR_LOOPBACK	0x4000	/* Enable loopback mode		*/
#define	BCM5000_MIICR_100	0x2000	/* Speed select 10/100		*/
#define	BCM5000_MIICR_ANENA	0x1000	/* Auto-Negotiation Enable	*/
#define	BCM5000_MIICR_PWRDN	0x0800	/* Power down mode enable	*/
#define	BCM5000_MIICR_ISOLATE	0x0400	/* Isolate PHY from MII data	*/
#define	BCM5000_MIICR_ANRST	0x0200	/* Restart auto-negotiation	*/
#define	BCM5000_MIICR_FD	0x0100	/* Full duplex mode enable	*/
#define	BCM5000_MIICR_COLTEST	0x0080	/* Collision test mode enable	*/


/* MII Status Register (MIISR) */

#define	BCM5000_MIISR_REG	0x01
#define	BCM5000_MIISR_100T4	0x8000	/* 100Base-T4 capable		*/
#define	BCM5000_MIISR_100TXFD	0x4000	/* 100Base-TX/FD capable	*/
#define	BCM5000_MIISR_100TX	0x2000	/* 100Base-TX capable		*/
#define	BCM5000_MIISR_10TPFD	0x1000	/* 100Base-TP/FD capable	*/
#define	BCM5000_MIISR_10TP	0x0800	/* 100Base-TP capable		*/
#define	BCM5000_MIISR_ANCPL	0x0020	/* Auto-negotiation complete	*/
#define	BCM5000_MIISR_RFLT	0x0010	/* Remote fault			*/
#define	BCM5000_MIISR_ANABL	0x0008	/* Able to perform auto-neg.	*/
#define	BCM5000_MIISR_LNKST	0x0004	/* Valid link status		*/
#define	BCM5000_MIISR_JAB	0x0002	/* Jabber detect		*/
#define	BCM5000_MIISR_XR	0x0001	/* Extended register capable	*/


/* PHY Identifier Register #1/#2 (PHYIDR1/PHYIDR2) */

#define	BCM5000_PHYIDR1_REG	0x02
#define	BCM5000_PHYIDR1		0x03E0
#define	BCM5000_PHYIDR2_REG	0x03
#define	BCM5000_PHYIDR2		0x0000


/* MII Extended Register 0 (MIIXR0) */

#define	BCM5000_MIIXR0_REG	0x10
#define	BCM5000_MIIXR0_JABDIS	0x8000	/* Jabber function disabled	*/
#define	BCM5000_MIIXR0_LINKDIS	0x4000	/* Link integrity test disabled	*/
#define	BCM5000_MIIXR0_FFAILENA	0x0100	/* Force fail enabled		*/
#define	BCM5000_MIIXR0_RCMASK	0x00E0	/* Revision control		*/
#define	BCM5000_MIIXR0_HSQ	0x0010	/* High squelch			*/
#define	BCM5000_MIIXR0_LSQ	0x0008	/* Low squelch			*/
#define	BCM5000_MIIXR0_TXDACPWR	0x0004	/* TX DAC permanent power	*/
#define	BCM5000_MIIXR0_100	0x0002	/* High speed indication	*/


/* MII Extended Register 1 (MIIXR1) */

#define	BCM5000_MIIXR1_REG	0x14
#define	BCM5000_MIIXR1_PRSKWERR	0x8000	/* Pair skew error		*/
#define	BCM5000_MIIXR1_DCBALERR	0x4000	/* DC balance error		*/
#define	BCM5000_MIIXR1_INVCODE	0x2000	/* Invalid code error		*/
#define	BCM5000_MIIXR1_BADCODE	0x1000	/* Bad code error		*/
#define	BCM5000_MIIXR1_EOPERR	0x0800	/* EOP error			*/
#define	BCM5000_MIIXR1_MANCHERR	0x0400	/* Manchester code error	*/
#define	BCM5000_MIIXR1_C2EOF	0x0200	/* Channel 2 EOF detection err	*/
#define	BCM5000_MIIXR1_DTEMODE	0x0100	/* DTE mode			*/
#define	BCM5000_MIIXR1_SYMRPT	0x0080	/* Symbol repeater mode		*/
#define	BCM5000_MIIXR1_C2POLERR	0x0010	/* Channel 2 polarity error	*/
#define	BCM5000_MIIXR1_C3POLERR	0x0008	/* Channel 3 polarity error	*/
#define	BCM5000_MIIXR1_C4POLERR	0x0004	/* Channel 4 polarity error	*/
#define	BCM5000_MIIXR1_C2SFDERR	0x0002	/* Channel 2SFD not found	*/



/*----------------------------------------------------------------------*/

/* MII Control Register (MIICR) */

#define	BCM5201_MIICR_REG	0x00
#define	BCM5201_MIICR_RESET	0x8000	/* Reset PHY to default		*/
#define	BCM5201_MIICR_LOOPBACK	0x4000	/* Enable loopback mode		*/
#define	BCM5201_MIICR_100	0x2000	/* Speed select 10/100		*/
#define	BCM5201_MIICR_ANENA	0x1000	/* Auto-Negotiation Enable	*/
#define	BCM5201_MIICR_PWRDN	0x0800	/* Power down mode enable	*/
#define	BCM5201_MIICR_ISOLATE	0x0400	/* Isolate PHY from MII data	*/
#define	BCM5201_MIICR_ANRST	0x0200	/* Restart auto-negotiation	*/
#define	BCM5201_MIICR_FD	0x0100	/* Full duplex mode enable	*/
#define	BCM5201_MIICR_COLTEST	0x0080	/* Collision test mode enable	*/


/* MII Status Register (MIISR) */

#define	BCM5201_MIISR_REG	0x01
#define	BCM5201_MIISR_100T4	0x8000	/* 100Base-T4 capable		*/
#define	BCM5201_MIISR_100TXFD	0x4000	/* 100Base-TX/FD capable	*/
#define	BCM5201_MIISR_100TX	0x2000	/* 100Base-TX capable		*/
#define	BCM5201_MIISR_10TPFD	0x1000	/* 100Base-TP/FD capable	*/
#define	BCM5201_MIISR_10TP	0x0800	/* 100Base-TP capable		*/
#define	BCM5201_MIISR_PRESUP	0x0040	/* Peramble may be supressed	*/
#define	BCM5201_MIISR_ANCPL	0x0020	/* Auto-negotiation complete	*/
#define	BCM5201_MIISR_RFLT	0x0010	/* Remote fault			*/
#define	BCM5201_MIISR_ANABL	0x0008	/* Able to perform auto-neg.	*/
#define	BCM5201_MIISR_LNKST	0x0004	/* Valid link status		*/
#define	BCM5201_MIISR_JAB	0x0002	/* Jabber detect		*/
#define	BCM5201_MIISR_XR	0x0001	/* Extended register capable	*/


/* PHY Identifier Register #1/#2 (PHYIDR1/PHYIDR2) */

#define	BCM5201_PHYIDR1_REG	0x02
#define	BCM5201_PHYIDR1		0x0040
#define	BCM5201_PHYIDR2_REG	0x03
#define	BCM5201_PHYIDR2		0x6210

#define	BCM5201_PHYID		0x00406210

/* Auto-Negotiation Advertisment Register (ANAR) */

#define	BCM5201_ANAR_REG	0x04
#define	BCM5201_ANAR_NEXTPG	0x8000	/* Next Page        		*/
#define	BCM5201_ANAR_REMOFAULT	0x2000	/* Remote Fault     		*/
#define	BCM5201_ANAR_PAUSE	0x0400	/* Advertise Pause  		*/
#define	BCM5201_ANAR_T4		0x0200	/* Advertise 100Base-T4		*/
#define	BCM5201_ANAR_TXFD	0x0100	/* Advertise 100Base-X-FDX	*/
#define	BCM5201_ANAR_TX		0x0080	/* Advertise 100Base-X		*/
#define	BCM5201_ANAR_TPFD	0x0040	/* Advertise 10Base-TP-FDX	*/
#define	BCM5201_ANAR_TP		0x0020	/* Advertise 10Base-TP		*/

/* Auto-Negotiation Link Partner Ability Register (ANLPAR) */

#define	BCM5201_ANLPAR_REG	0x05
#define	BCM5201_ANLPAR_NEXTPG	0x8000	/* Next Page        		*/
#define	BCM5201_ANLPAR_ACK	0x4000	/* Acknowledge      		*/
#define	BCM5201_ANLPAR_REMOFAULT 0x2000	/* Remote Fault     		*/
#define	BCM5201_ANLPAR_PAUSE	0x0400	/* Link Partner has Pause  	*/
#define	BCM5201_ANLPAR_T4	0x0200	/* Link Partner has 100Base-T4	*/
#define	BCM5201_ANLPAR_TXFD	0x0100	/* Link Partner has 100Base-X-FDX*/
#define	BCM5201_ANLPAR_TX	0x0080	/* Link Partner has 100Base-X	*/
#define	BCM5201_ANLPAR_TPFD	0x0040	/* Link Partner has 10Base-TP-FDX*/
#define	BCM5201_ANLPAR_TP	0x0020	/* Link Partner has 10Base-TP	*/

/* Auto-Negotiation Expansion Register (ANXR) */

#define	BCM5201_ANXR_REG	0x06
#define	BCM5201_ANXR_PDFAULT	0x0010	/* Parallel Detection Fault	*/
#define	BCM5201_ANXR_LPNPA	0x0008	/* Link Partner Next Page Able	*/
#define	BCM5201_ANXR_NPA	0x0004	/* Next Page Able		*/
#define	BCM5201_ANXR_PAGERCV	0x0002	/* New Page has been Received	*/
#define	BCM5201_ANXR_LPANA	0x0001	/* Link Partner Auto-Neg Able

/* TX Auxiliary Control Register (TXACR) */

#define	BCM5201_TXACR_REG	0x10
#define	BCM5201_TXACR_TXDIS	0x2000	/* Transmitter Disable		*/
#define	BCM5201_TXACR_BYPS4B5B	0x0400	/* Bypass 4B5B Encoder/Decoder	*/
#define	BCM5201_TXACR_BYPSSCRAM	0x0200	/* Bypass Scrambler/Descrambler	*/
#define	BCM5201_TXACR_BYPSNRZI	0x0100	/* Bypass NRZI Endocer/Decoder	*/
#define	BCM5201_TXACR_BYPSRSA	0x0080	/* Bypass Receive Symbol Alignment */
#define	BCM5201_TXACR_BASEWCD	0x0040	/* Baseline Wonder Correction Disable */
#define	BCM5201_TXACR_FEF	0x0020	/* Far End Fault Enable		*/


/* TX Auxiliary Status Register (TXASR) */

#define	BCM5201_TXASR_REG	0x11
#define	BCM5201_TXASR_FXMODE	0x0400	/* FX Mode			*/
#define	BCM5201_TXASR_LOCKED	0x0200	/* Locked			*/
#define	BCM5201_TXASR_LINK100	0x0100	/* Current 100Base-X Link State	*/
#define	BCM5201_TXASR_REMOFAULT	0x0080	/* Remote Fault			*/
#define	BCM5201_TXASR_DISCO	0x0040	/* Disconnect State		*/
#define	BCM5201_TXASR_FCD	0x0020	/* False Carrier Detected	*/
#define	BCM5201_TXASR_BADESD	0x0010	/* Bad ESD Detected		*/
#define	BCM5201_TXASR_RXERR	0x0008	/* Receive Error Detected	*/
#define	BCM5201_TXASR_TXERR	0x0004	/* Transmit Error Detected	*/
#define	BCM5201_TXASR_LOCKERR	0x0002	/* Lock Error Detected		*/
#define	BCM5201_TXASR_MLT3ERR	0x0001	/* MLT3 Code Error Detected	*/

/* TX Receive Error Counter (TXREC) */

#define	BCM5201_TXREC_REG	0x12

/* TX False Carrier Sense Counter (TXFCSC) */

#define	BCM5201_TXFCSC_REG	0x13

/* TX Disconnect Counter (TXDC) */

#define	BCM5201_TXDC_REG	0x14

/* PTEST Register (PTEST) */

#define	BCM5201_PTEST_REG	0x17

/* Auxiliary Conrtol/Status Register (ACSR) */

#define	BCM5201_ACSR_REG	0x18
#define	BCM5201_ACSR_JABBER	0x8000	/* Jabber Disable		*/
#define	BCM5201_ACSR_FORCELINK	0x4000	/* Force Link			*/
#define	BCM5201_ACSR_HSQ	0x0080	/* High Squelch			*/
#define	BCM5201_ACSR_LSQ	0x0040	/* Low Squelch			*/
#define	BCM5201_ACSR_EDGERATE	0x0030	/* Edge Rate[1:0]		*/
#define	BCM5201_ACSR_ANI	0x0008	/* Auto-Negotiation Indication	*/
#define	BCM5201_ACSR_FORCE100	0x0004	/* Force 100Base-TX		*/
#define	BCM5201_ACSR_SPEED	0x0002	/* 1->TX, 0->TP			*/
#define	BCM5201_ACSR_FDX	0x0001	/* Full Duplex Active		*/


/* Auxiliary Status Summary Register (ASSR) */

#define	BCM5201_ASSR_REG	0x19
#define	BCM5201_ASSR_ANCPL	0x8000	/* Auto-negotiation complete	*/
#define	BCM5201_ASSR_ANCPLACK	0x4000	/* Auto-negotiation complete Ack */
#define	BCM5201_ASSR_ANACKDET	0x2000	/* Auto-negotiation Ack Detect	*/
#define	BCM5201_ASSR_CANAN	0x1000	/* Can Auto-negotiate 		*/
#define	BCM5201_ASSR_ANPAUSE	0x0800	/* Auto-negotiation Pause	*/
#define	BCM5201_ASSR_ANPDF	0x0080	/* AN Parallel Detection Fault	*/
#define	BCM5201_ASSR_LPRF	0x0040	/* Link Partner Remote Fault	*/
#define	BCM5201_ASSR_LPPR	0x0020	/* Link Partner Page Received	*/
#define	BCM5201_ASSR_LPANA	0x0010	/* Link Partner Can AN		*/
#define	BCM5201_ASSR_SPEED	0x0008	/* 1->100, 0->10		*/
#define	BCM5201_ASSR_LINK	0x0004	/* Link Status, 1->Link		*/
#define	BCM5201_ASSR_ANE	0x0002	/* Auto-negotiation enabled	*/
#define	BCM5201_ASSR_JABBER	0x0001	/* Jabber Detect		*/


/* Interrupt Register (IR) */

#define	BCM5201_IR_REG		0x1a
#define	BCM5201_IR_FDXLED	0x8000	/* Full-Duplex LED Enable	*/
#define	BCM5201_IR_INTEN	0x4000	/* Interrupt Enable		*/
#define	BCM5201_IR_FDXMASK	0x0800	/* Full Duplex Interrupt Mask	*/
#define	BCM5201_IR_SPDMASK	0x0400	/* Speed Interrupt Mask		*/
#define	BCM5201_IR_LINKMASK	0x0200	/* Link Mask			*/
#define	BCM5201_IR_INTMASK	0x0100	/* Interrupt Mask		*/
#define	BCM5201_IR_FDXCHANGE	0x0008	/* Full Duplex Interrupt Change	*/
#define	BCM5201_IR_SPDCHANGE	0x0004	/* Speed Interrupt Change	*/
#define	BCM5201_IR_LINKCHANGE	0x0002	/* Link Change			*/
#define	BCM5201_IR_INTSTATUS	0x0001	/* Interrupt Status		*/


/* Auxiliary Mode 2 Register (AM2R) */

#define	BCM5201_AM2R_REG	0x1b
#define	BCM5201_AM2R_BLOCKRXDV	0x0200	/* Block RXDV Mode		*/
#define	BCM5201_AM2R_ANPDQM	0x0100	/* AN Par Detection Qual Mode	*/
#define	BCM5201_AM2R_TMLED	0x0040	/* Traffic Meter LED Mode	*/
#define	BCM5201_AM2R_FORCELED	0x0020	/* Force XMTLED, RCVLED On	*/
#define	BCM5201_AM2R_TOKENRING	0x0010	/* High Speed Token Ring Mode	*/
#define	BCM5201_AM2R_AUTOLPM	0x0008	/* Auto Low Power Mode		*/
#define	BCM5201_AM2R_2LNKLED	0x0004	/* Two LNKLED Mode		*/
#define	BCM5201_AM2R_SQE	0x0002	/* SQE Disable			*/


/* 10BASE-T Auxiliary Error and General Status Register (10AEGSR) */

#define	BCM5201_10AEGSR_REG	0x1c
#define	BCM5201_10AEGSR_MCE	0x0400	/* Manchester Code Error	*/
#define	BCM5201_10AEGSR_EOFERR	0x0200	/* EOF Detection Error		*/
#define	BCM5201_10AEGSR_POL	0x0100	/* Polarity Inversion		*/
#define	BCM5201_10AEGSR_ANI	0x0008	/* Auto-Negotaition Indication	*/
#define	BCM5201_10AEGSR_100IND	0x0004	/* Force 100 Indication		*/
#define	BCM5201_10AEGSR_SPEED	0x0002	/* Speed Indication		*/
#define	BCM5201_10AEGSR_FDXIND	0x0001	/* Full Duplex Indication	*/


/* Auxiliary Mode Register (AMR) */

#define	BCM5201_AMR_REG		0x1d
#define	BCM5201_AMR_ACTLED	0x0010	/* Activity LED Disable		*/
#define	BCM5201_AMR_LINKLED	0x0008	/* Link LED Disable		*/
#define	BCM5201_AMR_BLOCKTXEN	0x0002	/* Block TXEN Mode		*/


/* Auxiliary Multiple Phy Register (AMPR) */

#define	BCM5201_AMPR_REG	0x1e
#define	BCM5201_AMPR_HCDTXFDX	0x8000	/* AN result is TXFD		*/
#define	BCM5201_AMPR_HCDT4	0x4000	/* AN result is T4		*/
#define	BCM5201_AMPR_HCDTX	0x2000	/* AN result is TX		*/
#define	BCM5201_AMPR_HCDTPFD	0x1000	/* AN result is TPFD		*/
#define	BCM5201_AMPR_HCDTP	0x0800	/* AN result is TP		*/
#define	BCM5201_AMPR_RAN	0x0100	/* Restaet Auto-Negotiation	*/
#define	BCM5201_AMPR_ANC	0x0080	/* Auto-Negotiation complete	*/
#define	BCM5201_AMPR_ACKC	0x0040	/* Acknowledge Complete		*/
#define	BCM5201_AMPR_ACKD	0x0020	/* Acknowledge Detected		*/
#define	BCM5201_AMPR_AD		0x0010	/* Ability Detect		*/
#define	BCM5201_AMPR_SUPI	0x0008	/* Super Isolate mode		*/
#define	BCM5201_AMPR_10SERIAL	0x0002	/* 10Base-T Serial Mode		*/


/* Boardcom Test Register (BTR) */

#define	BCM5201_BTR_REG		0x1f



/*----------------------------------------------------------------------*/

/* MII Control Register (MIICR) */

#define	BCM5208_MIICR_REG	0x00
#define	BCM5208_MIICR_RESET	0x8000	/* Reset PHY to default		*/
#define	BCM5208_MIICR_LOOPBACK	0x4000	/* Enable loopback mode		*/
#define	BCM5208_MIICR_100	0x2000	/* Speed select 10/100		*/
#define	BCM5208_MIICR_ANENA	0x1000	/* Auto-Negotiation Enable	*/
#define	BCM5208_MIICR_PWRDN	0x0800	/* Power down mode enable	*/
#define	BCM5208_MIICR_ISOLATE	0x0400	/* Isolate PHY from MII data	*/
#define	BCM5208_MIICR_ANRST	0x0200	/* Restart auto-negotiation	*/
#define	BCM5208_MIICR_FD	0x0100	/* Full duplex mode enable	*/
#define	BCM5208_MIICR_COLTEST	0x0080	/* Collision test mode enable	*/


/* MII Status Register (MIISR) */

#define	BCM5208_MIISR_REG	0x01
#define	BCM5208_MIISR_100T4	0x8000	/* 100Base-T4 capable		*/
#define	BCM5208_MIISR_100TXFD	0x4000	/* 100Base-TX/FD capable	*/
#define	BCM5208_MIISR_100TX	0x2000	/* 100Base-TX capable		*/
#define	BCM5208_MIISR_10TPFD	0x1000	/* 100Base-TP/FD capable	*/
#define	BCM5208_MIISR_10TP	0x0800	/* 100Base-TP capable		*/
#define	BCM5208_MIISR_PRESUP	0x0040	/* Peramble may be supressed	*/
#define	BCM5208_MIISR_ANCPL	0x0020	/* Auto-negotiation complete	*/
#define	BCM5208_MIISR_RFLT	0x0010	/* Remote fault			*/
#define	BCM5208_MIISR_ANABL	0x0008	/* Able to perform auto-neg.	*/
#define	BCM5208_MIISR_LNKST	0x0004	/* Valid link status		*/
#define	BCM5208_MIISR_JAB	0x0002	/* Jabber detect		*/
#define	BCM5208_MIISR_XR	0x0001	/* Extended register capable	*/


/* PHY Identifier Register #1/#2 (PHYIDR1/PHYIDR2) */

#define	BCM5208_PHYIDR1_REG	0x02
#define	BCM5208_PHYIDR1		0x0040
#define	BCM5208_PHYIDR2_REG	0x03
#define	BCM5208_PHYIDR2		0x6130

#define	BCM5208_PHYID		0x00406130

/* Auto-Negotiation Advertisment Register (ANAR) */

#define	BCM5208_ANAR_REG	0x04
#define	BCM5208_ANAR_NEXTPG	0x8000	/* Next Page        		*/
#define	BCM5208_ANAR_REMOFAULT	0x2000	/* Remote Fault     		*/
#define	BCM5208_ANAR_PAUSE	0x0400	/* Advertise Pause  		*/
#define	BCM5208_ANAR_T4		0x0200	/* Advertise 100Base-T4		*/
#define	BCM5208_ANAR_TXFD	0x0100	/* Advertise 100Base-X-FDX	*/
#define	BCM5208_ANAR_TX		0x0080	/* Advertise 100Base-X		*/
#define	BCM5208_ANAR_TPFD	0x0040	/* Advertise 10Base-TP-FDX	*/
#define	BCM5208_ANAR_TP		0x0020	/* Advertise 10Base-TP		*/

/* Auto-Negotiation Link Partner Ability Register (ANLPAR) */

#define	BCM5208_ANLPAR_REG	0x05
#define	BCM5208_ANLPAR_NEXTPG	0x8000	/* Next Page        		*/
#define	BCM5208_ANLPAR_ACK	0x4000	/* Acknowledge      		*/
#define	BCM5208_ANLPAR_REMOFAULT 0x2000	/* Remote Fault     		*/
#define	BCM5208_ANLPAR_PAUSE	0x0400	/* Link Partner has Pause  	*/
#define	BCM5208_ANLPAR_T4	0x0200	/* Link Partner has 100Base-T4	*/
#define	BCM5208_ANLPAR_TXFD	0x0100	/* Link Partner has 100Base-X-FDX*/
#define	BCM5208_ANLPAR_TX	0x0080	/* Link Partner has 100Base-X	*/
#define	BCM5208_ANLPAR_TPFD	0x0040	/* Link Partner has 10Base-TP-FDX*/
#define	BCM5208_ANLPAR_TP	0x0020	/* Link Partner has 10Base-TP	*/

/* Auto-Negotiation Expansion Register (ANXR) */

#define	BCM5208_ANXR_REG	0x06
#define	BCM5208_ANXR_PDFAULT	0x0010	/* Parallel Detection Fault	*/
#define	BCM5208_ANXR_LPNPA	0x0008	/* Link Partner Next Page Able	*/
#define	BCM5208_ANXR_NPA	0x0004	/* Next Page Able		*/
#define	BCM5208_ANXR_PAGERCV	0x0002	/* New Page has been Received	*/
#define	BCM5208_ANXR_LPANA	0x0001	/* Link Partner Auto-Neg Able	*/

/* TX Auxiliary Control Register (TXACR) */

#define	BCM5208_TXACR_REG	0x10
#define	BCM5208_TXACR_TXDIS	0x2000	/* Transmitter Disable		*/
#define	BCM5208_TXACR_DIMDIS	0x1000	/* TYPO - see next entry	*/
#define	BCM5208_TXACR_CIMDIS	0x1000	/* Carrier Integrity Mon Disable*/
#define	BCM5208_TXACR_BYPS4B5B	0x0400	/* Bypass 4B5B Encoder/Decoder	*/
#define	BCM5208_TXACR_BYPSSCRAM	0x0200	/* Bypass Scrambler/Descrambler	*/
#define	BCM5208_TXACR_BYPSNRZI	0x0100	/* Bypass NRZI Endocer/Decoder	*/
#define	BCM5208_TXACR_BYPSRSA	0x0080	/* Bypass Receive Symbol Alignment */
#define	BCM5208_TXACR_BASEWCD	0x0040	/* Baseline Wander Correction Disable */
#define	BCM5208_TXACR_FEF	0x0020	/* Far End Fault Enable		*/


/* TX Auxiliary Status Register (TXASR) */

#define	BCM5208_TXASR_REG	0x11
#define	BCM5208_TXASR_FXMODE	0x0400	/* FX Mode			*/
#define	BCM5208_TXASR_LOCKED	0x0200	/* Locked			*/
#define	BCM5208_TXASR_LINK100	0x0100	/* Current 100Base-X Link State	*/
#define	BCM5208_TXASR_REMOFAULT	0x0080	/* Remote Fault			*/
#define	BCM5208_TXASR_DISCO	0x0040	/* Disconnect State		*/
#define	BCM5208_TXASR_FCD	0x0020	/* False Carrier Detected	*/
#define	BCM5208_TXASR_BADESD	0x0010	/* Bad ESD Detected		*/
#define	BCM5208_TXASR_RXERR	0x0008	/* Receive Error Detected	*/
#define	BCM5208_TXASR_TXERR	0x0004	/* Transmit Error Detected	*/
#define	BCM5208_TXASR_LOCKERR	0x0002	/* Lock Error Detected		*/
#define	BCM5208_TXASR_MLT3ERR	0x0001	/* MLT3 Code Error Detected	*/

/* TX Receive Error Counter (TXREC) */

#define	BCM5208_TXREC_REG	0x12

/* TX False Carrier Sense Counter (TXFCSC) */

#define	BCM5208_TXFCSC_REG	0x13

/* TX Disconnect Counter (TXDC) */

#define	BCM5208_TXDC_REG	0x14

/* PTEST Register (PTEST) */

#define	BCM5208_PTEST_REG	0x17

/* Auxiliary Conrtol/Status Register (ACSR) */

#define	BCM5208_ACSR_REG	0x18
#define	BCM5208_ACSR_JABBER	0x8000	/* Jabber Disable		*/
#define	BCM5208_ACSR_FORCELINK	0x4000	/* Force Link			*/
#define	BCM5208_ACSR_HSQ	0x0080	/* High Squelch			*/
#define	BCM5208_ACSR_LSQ	0x0040	/* Low Squelch			*/
#define	BCM5208_ACSR_EDGERATE	0x0030	/* Edge Rate[1:0]		*/
#define	BCM5208_ACSR_ANI	0x0008	/* Auto-Negotiation Indication	*/
#define	BCM5208_ACSR_FORCE100	0x0004	/* Force 100Base-TX		*/
#define	BCM5208_ACSR_SPEED	0x0002	/* 1->TX, 0->TP			*/
#define	BCM5208_ACSR_FDX	0x0001	/* Full Duplex Active		*/


/* Auxiliary Status Summary Register (ASSR) */

#define	BCM5208_ASSR_REG	0x19
#define	BCM5208_ASSR_ANCPL	0x8000	/* Auto-negotiation complete	*/
#define	BCM5208_ASSR_ANCPLACK	0x4000	/* Auto-negotiation complete Ack */
#define	BCM5208_ASSR_ANACKDET	0x2000	/* Auto-negotiation Ack Detect	*/
#define	BCM5208_ASSR_CANAN	0x1000	/* Can Auto-negotiate 		*/
#define	BCM5208_ASSR_ANPAUSE	0x0800	/* Auto-negotiation Pause	*/
#define	BCM5208_ASSR_ANPDF	0x0080	/* AN Parallel Detection Fault	*/
#define	BCM5208_ASSR_LPRF	0x0040	/* Link Partner Remote Fault	*/
#define	BCM5208_ASSR_LPPR	0x0020	/* Link Partner Page Received	*/
#define	BCM5208_ASSR_LPANA	0x0010	/* Link Partner Can AN		*/
#define	BCM5208_ASSR_SPEED	0x0008	/* 1->100, 0->10		*/
#define	BCM5208_ASSR_LINK	0x0004	/* Link Status, 1->Link		*/
#define	BCM5208_ASSR_ANE	0x0002	/* Auto-negotiation enabled	*/
#define	BCM5208_ASSR_JABBER	0x0001	/* Jabber Detect		*/


/* Interrupt Register (IR) */

#define	BCM5208_IR_REG		0x1a
#define	BCM5208_IR_FDXLED	0x8000	/* Full-Duplex LED Enable	*/
#define	BCM5208_IR_INTEN	0x4000	/* Interrupt Enable		*/
#define	BCM5208_IR_FDXMASK	0x0800	/* Full Duplex Interrupt Mask	*/
#define	BCM5208_IR_SPDMASK	0x0400	/* Speed Interrupt Mask		*/
#define	BCM5208_IR_LINKMASK	0x0200	/* Link Mask			*/
#define	BCM5208_IR_INTMASK	0x0100	/* Interrupt Mask		*/
#define	BCM5208_IR_FDXCHANGE	0x0008	/* Full Duplex Interrupt Change	*/
#define	BCM5208_IR_SPDCHANGE	0x0004	/* Speed Interrupt Change	*/
#define	BCM5208_IR_LINKCHANGE	0x0002	/* Link Change			*/
#define	BCM5208_IR_INTSTATUS	0x0001	/* Interrupt Status		*/


/* Auxiliary Mode 2 Register (AM2R) */

#define	BCM5208_AM2R_REG	0x1b
#define	BCM5208_AM2R_BLOCKRXDV	0x0080	/* Block 10BASE-T Echo Disable	*/
#define	BCM5208_AM2R_TMLED	0x0040	/* Traffic Meter LED Mode	*/
#define	BCM5208_AM2R_FORCELED	0x0020	/* Force XMTLED, RCVLED On	*/
#define	BCM5208_AM2R_SERIALLED	0x0010	/* Serial LED mode enable	*/
#define	BCM5208_AM2R_SQE	0x0008	/* SQE Disable			*/
#define	BCM5208_AM2R_PARDET	0x0002	/* Parallel Detect Qual Mode on */


/* 10BASE-T Auxiliary Error and General Status Register (10AEGSR) */

#define	BCM5208_10AEGSR_REG	0x1c
#define	BCM5208_10AEGSR_MCE	0x0400	/* Manchester Code Error	*/
#define	BCM5208_10AEGSR_EOFERR	0x0200	/* EOF Detection Error		*/
#define	BCM5208_10AEGSR_POL	0x0100	/* Polarity Inversion		*/
#define	BCM5208_10AEGSR_REPEAT	0x0010	/* Repeater Mode		*/
#define	BCM5208_10AEGSR_ANI	0x0008	/* Auto-Negotaition Indication	*/
#define	BCM5208_10AEGSR_100IND	0x0004	/* Force 100 Indication		*/
#define	BCM5208_10AEGSR_SPEED	0x0002	/* Speed Indication		*/
#define	BCM5208_10AEGSR_FDXIND	0x0001	/* Full Duplex Indication	*/


/* Auxiliary Mode Register (AMR) */

#define	BCM5208_AMR_REG		0x1d
#define	BCM5208_AMR_SEGCTRL	0xc000	/* Segmentation Control		*/
#define	BCM5208_AMR_PHY		0x2000	/* Phy Enable			*/
#define	BCM5208_AMR_SEGMENT	0x1000	/* Segmentation Enable		*/
#define	BCM5208_AMR_ACTLED	0x0010	/* Activity LED Disable		*/
#define	BCM5208_AMR_LINKLED	0x0008	/* Link LED Disable		*/
#define	BCM5208_AMR_BLOCKTXEN	0x0002	/* Block TXEN Mode		*/


/* Auxiliary Multiple Phy Register (AMPR) */

#define	BCM5208_AMPR_REG	0x1e
#define	BCM5208_AMPR_HCDTXFDX	0x8000	/* AN result is TXFD		*/
#define	BCM5208_AMPR_HCDT4	0x4000	/* AN result is T4		*/
#define	BCM5208_AMPR_HCDTX	0x2000	/* AN result is TX		*/
#define	BCM5208_AMPR_HCDTPFD	0x1000	/* AN result is TPFD		*/
#define	BCM5208_AMPR_HCDTP	0x0800	/* AN result is TP		*/
#define	BCM5208_AMPR_RAN	0x0100	/* Restaet Auto-Negotiation	*/
#define	BCM5208_AMPR_ANC	0x0080	/* Auto-Negotiation complete	*/
#define	BCM5208_AMPR_ACKC	0x0040	/* Acknowledge Complete		*/
#define	BCM5208_AMPR_ACKD	0x0020	/* Acknowledge Detected		*/
#define	BCM5208_AMPR_AD		0x0010	/* Ability Detect		*/
#define	BCM5208_AMPR_SUPI	0x0008	/* Super Isolate mode		*/
#define	BCM5208_AMPR_10SERIAL	0x0002	/* 10Base-T Serial Mode		*/
#define	BCM5208_AMPR_RXERCODE	0x0001	/* Enable RXER Code Mode	*/


/* Boardcom Test Register (BTR) */

#define	BCM5208_BTR_REG		0x1f


