/*==========================================================================
**
**	bcm5421s.h
**
**	Definitions for Broadcom BCM5421S PHY
**
**==========================================================================
**
**	(c) Copyright 2003 ZNYX Networks
**	All Rights Reserved.
**
**==========================================================================
**
**	Modification History:
**	jr	06/10/2003	From 5421 pdf, m88e1000.h, and bcm5000.h
**
**==========================================================================
*/



/* Control Register (CR) */

#define	BCM5421S_CR_REG		0x00
#define	BCM5421S_CR_RESET	0x8000	/* Reset PHY to default		*/
#define	BCM5421S_CR_LOOPBACK	0x4000	/* Enable loopback mode		*/
#define	BCM5421S_CR_100		0x2000	/* Speed select 10/100		*/
#define	BCM5421S_CR_ANENA	0x1000	/* Auto-Negotiation Enable	*/
#define	BCM5421S_CR_PWRDN	0x0800	/* Power down mode enable	*/
#define	BCM5421S_CR_ISOLATE	0x0400	/* Isolate PHY from MII data	*/
#define	BCM5421S_CR_ANRST	0x0200	/* Restart auto-negotiation	*/
#define	BCM5421S_CR_FD		0x0100	/* Full duplex mode enable	*/
#define	BCM5421S_CR_COLTEST	0x0080	/* Collision test mode enable	*/
#define BCM5421S_CR_1000	0x0040	/* Speed select 1000		*/


/* Status Register (SR) */

#define	BCM5421S_SR_REG		0x01
#define	BCM5421S_SR_100T4	0x8000	/* 100Base-T4 capable		*/
#define	BCM5421S_SR_100TXFD	0x4000	/* 100Base-TX/FD capable	*/
#define	BCM5421S_SR_100TX	0x2000	/* 100Base-TX capable		*/
#define	BCM5421S_SR_10TPFD	0x1000	/* 100Base-TP/FD capable	*/
#define	BCM5421S_SR_10TP	0x0800	/* 100Base-TP capable		*/
#define	BCM5421S_SR_100T2	0x0400	/* 100Base-T2 capable		*/
#define	BCM5421S_SR_100T2FD	0x0200	/* 100Base-T2/FD capable	*/
#define BCM5421S_SR_EXT_STATUS	0x0100	/* extended status in reg 15	*/
#define BCM5421S_SR_PRE_SUP	0x0040	/* Preamble may be suppressed */
#define	BCM5421S_SR_ANCPL	0x0020	/* Auto-negotiation complete	*/
#define	BCM5421S_SR_RFLT	0x0010	/* Remote fault			*/
#define	BCM5421S_SR_ANABL	0x0008	/* Able to perform auto-neg.	*/
#define	BCM5421S_SR_LNKST	0x0004	/* Valid link status		*/
#define	BCM5421S_SR_JAB		0x0002	/* Jabber detect		*/
#define	BCM5421S_SR_XR		0x0001	/* Extended register capable	*/


/* PHY Identifier Register #1/#2 (PHYIDR1/PHYIDR2) */

#define	BCM5421S_PHYIDR1_REG	0x02
#define	BCM5421S_PHYIDR1	0x0020
#define	BCM5421S_PHYIDR2_REG	0x03
#define	BCM5421S_PHYIDR2	0x60E0


/* Auto-Negotiation Advertisement Register (ANAR) */

#define	BCM5421S_ANAR_REG	0x04
#define	BCM5421S_ANAR_NP	0x8000
#define	BCM5421S_ANAR_ACK	0x4000	/* ???				*/
#define	BCM5421S_ANAR_RF	0x2000
#define	BCM5421S_ANAR_AS_PAUSE	0x0800	/* Asymmetric Pause		*/
#define	BCM5421S_ANAR_PAUSE	0x0400	/* Pause			*/
#define	BCM5421S_ANAR_T4	0x0200
#define	BCM5421S_ANAR_TXFD	0x0100
#define	BCM5421S_ANAR_TX	0x0080
#define	BCM5421S_ANAR_TPFD	0x0040
#define	BCM5421S_ANAR_TP	0x0020
#define	BCM5421S_ANAR_PS_MASK	0x001F
#define	BCM5421S_ANAR_PS_8023	0x0001


/* Auto-Negotiation Link Partner Ability Register (ANLPAR) */

#define	BCM5421S_ANLPAR_REG	0x05
#define	BCM5421S_ANLPAR_NP	0x8000
#define	BCM5421S_ANLPAR_ACK	0x4000
#define	BCM5421S_ANLPAR_RF	0x2000
#define	BCM5421S_ANLPAR_AP	0x0800
#define	BCM5421S_ANLPAR_PC	0x0400
#define	BCM5421S_ANLPAR_T4	0x0200
#define	BCM5421S_ANLPAR_TXFD	0x0100
#define	BCM5421S_ANLPAR_TX	0x0080
#define	BCM5421S_ANLPAR_TPFD	0x0040
#define	BCM5421S_ANLPAR_TP	0x0020
#define	BCM5421S_ANLPAR_PS_MASK	0x001F
#define	BCM5421S_ANLPAR_PS_8023	0x0001


/* Auto-Negotiation Expansion Register (ANER) */

#define	BCM5421S_ANER_REG	0x06
#define BCM5421S_ANER_PAR_DET	0x0010	/* parallel detection failed	*/
#define	BCM5421S_ANER_LPNPABLE	0x0008
#define	BCM5421S_ANER_NPABLE	0x0004
#define	BCM5421S_ANER_PAGE_RX	0x0002
#define	BCM5421S_ANER_LPANABLE	0x0001


/* Auto-Negotiation Advertisement Register, Second Page (ANAR2) */

#define	BCM5421S_ANAR2_REG	0x07
#define	BCM5421S_ANAR2_NP	0x8000
#define	BCM5421S_ANAR2_MSG	0x2000	/*++ formatted page		*/
#define	BCM5421S_ANAR2_ACK	0x1000
#define	BCM5421S_ANAR2_TOGGLE	0x0800


/* Auto-Negotiation Link Partner Ability Register, Second Page (ANLPAR2) */

#define	BCM5421S_ANLPAR2_REG	0x08
#define	BCM5421S_ANLPAR2_NP	0x8000
#define	BCM5421S_ANLPAR2_ACK	0x4000
#define	BCM5421S_ANLPAR2_MSG	0x2000
#define	BCM5421S_ANLPAR2_ACK2	0x1000
#define	BCM5421S_ANLPAR2_TOGGLE	0x0800


/* 1000Base-T Control Register, (GCR) */

#define	BCM5421S_GCR_REG	0x09
#define	BCM5421S_GCR_MS_MCEN	0x1000	/* M/S manual conf enable	*/
#define	BCM5421S_GCR_MS_MASTER	0x0800	/* Master			*/
#define	BCM5421S_GCR_PORT_TYPE	0x0400	/* Port type			*/
#define	BCM5421S_GCR_1000T_FD	0x0200
#define	BCM5421S_GCR_1000T_HD	0x0100


/* 1000Base-T Status Register, (GSR) */

#define	BCM5421S_GSR_REG	0x0A
#define	BCM5421S_GSR_MS_FAULT	0x8000
#define	BCM5421S_GSR_MS_MASTER	0x4000
#define	BCM5421S_GSR_LOC_RCV_OK	0x2000
#define	BCM5421S_GSR_REM_RCV_OK	0x1000
#define	BCM5421S_GSR_1000T_FD	0x0800	/* Link partner capable		*/
#define	BCM5421S_GSR_1000T_HD	0x0400
#define	BCM5421S_GSR_IEC_MASK	0x00FF	/* Idle error counter mask	*/


/* 1000Base-X Control Register, (XCR) */

#define	BCM5421S_XCR_REG	0x0B


/* 1000Base-X Status Register, (XSR) */

#define	BCM5421S_XSR_REG	0x0C


/* 1000Base-X Link Partner Capabilities Register, (XLPCR) */

#define	BCM5421S_XLPCR_REG	0x0D


/* 1000Base-X Misc Register, (XMR) */

#define	BCM5421S_XMR_REG	0x0E


/* Extended PHY Status Register, (EPSR) */

#define	BCM5421S_EPSR_REG	0x0F
#define	BCM5421S_EPSR_1000X_FD	0x8000
#define	BCM5421S_EPSR_1000X_HD	0x4000
#define	BCM5421S_EPSR_1000T_FD	0x2000
#define	BCM5421S_EPSR_1000T_HD	0x1000


/* PHY Specific Control Register, (PSCR) */

#define	BCM5421S_PSCR_REG	0x10


/* PHY Specific Status Register, (PSSR) pg 204 */

#define	BCM5421S_PSSR_REG	0x11
#define	BCM5421S_PSSR_SFM	0x8000
#define	BCM5421S_PSSR_WSD	0x4000	/* Wire speed downgrade		*/
#define	BCM5421S_PSSR_MCS	0x2000	/* MDI crossover state		*/
#define	BCM5421S_PSSR_IS	0x1000	/* Interrupt status		*/
#define	BCM5421S_PSSR_RRS	0x0800	/* Remote receiver status	*/
#define	BCM5421S_PSSR_LRS	0x0400	/* Local receiver status	*/
#define	BCM5421S_PSSR_DL	0x0200	/* Descrambler locked		*/
#define	BCM5421S_PSSR_LINK	0x0100	/* Link up			*/


