/*==========================================================================
**
**	znyx/hw/dec21040.h
**
**	Definitions for DEC 21040-AA, 21140, and compatibles
**
**==========================================================================
**
**	(c) Copyright 1993, 1994, 1995, 1996, 1997 ZNYX Corporation
**	All Rights Reserved.
**
**==========================================================================
**
**	Modification History:
**	jr	11/04/93	Created from DEC 21040-AA Spec rev2.0 (prelim.)
**	jr	01/21/94	Converted RDES/TDES blocks to all DWORDs
**	jr	04/13/94	Added CSR6_TR_nnn definitions
**	jr	05/03/94	Made inclusion of setup frame structure
**				definitions and '_far' pointer definitions
**				conditional (__STDC__)
**	jr	06/12/94	Added CFRV_FIFO_OK
**	jr	10/06/94	Fixed/added 21040 and 21140 information
**	jr	11/16/94	Added CSR12 GPP, loopback definitions for CSR6
**	jr	12/29/94	Added CSR9 definitions for 21140
**	jr	06/16/95	Added CSR6_BIT2X definitions and others
**	jr	07/20/95	Removed setup frame structure definitions
**	jr	07/28/95	Changed the FIFO threshold equates
**	jr	08/02/95	Added HBD bit to CSR6_100TX setup macro
**	jr	08/16/95	Changed definitions for MII management port
**	jr	09/08/95	Added board-level data
**	jr	09/13/95	Fixed ZX341 definitions
**	jr	10/10/95	Added some TX/RX process state definitions
**	jr	10/25/95	Added PCI ID macros
**	jr	12/07/95	Added 21040/21041 media equates
**	jr	12/19/95	Changed 21041 media equates
**	jr	05/13/96	Added 21143 equates
**	jr	10/07/96	Added partial 21140A equates
**	jr	06/25/97	Wrapped up 21143 equates
**	jr	07/14/97	Added detailed CFRV_??? equates
**	ram	04/28/98	Ported to PDK.  Added byte swap values
**	hamid	10/09/2002      added RX_STOP for network flow control	
**
**==========================================================================
*/



/* PCI IDs */
#define DEC_VENDOR_ID		0x1011	/* DEC PCI Vendor ID		*/
#define DEC_21040_DEVICE_ID	0x0002	/* DEC 21040 Device ID		*/
#define DEC_21140_DEVICE_ID	0x0009	/* DEC 21140 Device ID		*/
#define DEC_21041_DEVICE_ID	0x0014	/* DEC 21041 Device ID		*/
#define DEC_21143_DEVICE_ID	0x0019	/* DEC 21143 Device ID		*/
#define DEC_21040_PCI_ID	0x00021011
#define DEC_21140_PCI_ID	0x00091011
#define DEC_21041_PCI_ID	0x00141011
#define DEC_21142_PCI_ID	0x00191011
#define DEC_21143_PCI_ID	0x00191011


/* PCI Configuration Registers */
#define CFID		0x00		/* Config ID			*/
#define CFCS		0x04		/* Config Cmd/Stat		*/
#define CFRV		0x08		/* Config Revision		*/
#define CFLT		0x0C		/* Config Latency Timer 	*/
#define CBIO		0x10		/* Config Base I/O Address	*/
#define CBMA		0x14		/* Config Base Memory Address	*/
#define CSSI		0x2C		/* Config subsystem ID		*/
#define CBER		0x30		/* Config expansion ROM base	*/
#define CFIT		0x3C		/* Config Interrupt		*/
#define CFDA		0x40		/* Config Driver Area		*/

#define CFRV_FIFO_OK	0x23		/* First FIFO-clean 21040 rev	*/
#define CFRV_21140A	0x20		/* First 21140A revision	*/
#define CFRV_21140_AC	0x20
#define CFRV_21140_AE	0x22
#define CFRV_21140_AF	0x22
#define CFRV_21143	0x20		/* First 21143 revision 	*/
#define CFRV_21143_PA	0x21
#define CFRV_21143_PB	0x30
#define CFRV_21143_PC	0x30



/* CSR0: Bus Mode Register */
#define CSR0		0x00
#define CSR0_WIE	0x01000000	/* 140A,143 Write Invalidate EN */
#define CSR0_RLE	0x00800000	/* 140A,143 Read Line Enable	*/
#define CSR0_RME	0x00200000	/* 140 Read Multiple Enable	*/
#define CSR0_DBO	0x00100000	/* Descriptor byte ordering	*/
#define CSR0_XTAP_MASK	0x000E0000	/* TX Auto Polling 21140	*/
#define CSR0_TAP_MASK	0x00060000	/* Transmit Auto Polling Mask	*/
#define CSR0_TAP_NONE	0x00000000	/* No automatic transmit polling*/
#define CSR0_TAP_200U	0x00020000	/* Auto polling every 200 usec	*/
#define CSR0_TAP_800U	0x00040000	/* Auto polling every 800 usec	*/
#define CSR0_TAP_1600U	0x00060000	/* Auto polling every 1.6 msec	*/
#define CSR0_DAS	0x00010000	/* Diagnostic Address Space	*/
#define CSR0_CAL_MASK	0x0000C000	/* Cache Alignment Mask 	*/
#define CSR0_CAL_NONE	0x00000000	/* No boundry alignment 	*/
#define CSR0_CAL_8	0x00004000	/* 8 longword boundry alignment */
#define CSR0_CAL_16	0x00008000	/* 16 longword boundry alignment*/
#define CSR0_CAL_32	0x0000C000	/* 32 longword boundry alignment*/
#define CSR0_PBL_MASK	0x00003F00	/* Programmable Burst Length	*/
#define CSR0_PBL_0	0x00000000	/* At least 16 dwords, no max	*/
#define CSR0_PBL_1	0x00000100	/* Burst length is 1 longword	*/
#define CSR0_PBL_2	0x00000200
#define CSR0_PBL_4	0x00000400
#define CSR0_PBL_8	0x00000800
#define CSR0_PBL_16	0x00001000
#define CSR0_PBL_32	0x00002000	/* Burst length is 32 longwords */
#define CSR0_BLE	0x00000080	/* Big/Little Endian		*/
#define CSR0_DSL_MASK	0x0000007C	/* Descriptor Skip Length Mask	*/
#define CSR0_DSL_SHIFT	2		/* Descriptor Skip Length Shift */
#define CSR0_BAR	0x00000002	/* Bus Arbitration		*/
#define CSR0_SWR	0x00000001	/* Software Reset		*/

/* CSR1: Transmit Poll Demand */
#define CSR1		0x08
#define CSR1_TPD	0x00000001	/* Transmit Poll Demand Bit	*/

/* CSR2: Receive Poll Demand */
#define CSR2		0x10
#define CSR2_RPD	0x00000001	/* Receive Poll Demand Bit	*/

/* CSR3: Receive List Base Address */
#define CSR3		0x18

/* CSR4: Transmit List Base Address */
#define CSR4		0x20

/* CSR5: Status Register */
#define CSR5		0x28
#define CSR5_UNUSED	0x80000000	/* Undefined bit */
#define CSR5_LC 	0x08000000	/* 143 Link Changed		*/
#define CSR5_GPI	0x04000000	/* 142,143 General Purpose Port */
#define CSR5_EB_MASK	0x03800000	/* Error Bits			*/
#define CSR5_TS_MASK	0x00700000	/* Transmit Process State	*/
#define CSR5_TS_STOPPED 0x00000000	/* Stopped			*/
#define CSR5_TS_FETCH	0x00100000	/* Fetch Transmit Descriptor	*/
#define CSR5_TS_SETUP	0x00500000	/* Setup Frame			*/
#define CSR5_TS_SUSP	0x00600000	/* Suspended			*/
#define CSR5_TS_SHIFT	20		/* Transmit Process Shift Count */
#define CSR5_RS_MASK	0x000E0000	/* Receive Process State	*/
#define CSR5_RS_STOPPED 0x00000000	/* Stopped			*/
#define CSR5_RS_WAIT	0x00060000	/* Waiting For Receive Packet	*/
#define CSR5_RS_SUSP	0x00080000	/* Suspended			*/
#define CSR5_RS_SHIFT	17		/* Receive Process Shift Count	*/
#define CSR5_NIS	0x00010000	/* Normal Interrupt Summary	*/
#define CSR5_AIS	0x00008000	/* Abnormal Interrupt Summary	*/
#define CSR5_ERI	0x00004000	/* Early Receive Interrupt	*/
#define CSR5_SE 	0x00002000	/* System Error 		*/
#define CSR5_FBE	0x00002000	/* Fatal Bus Error (==SE)	*/
#define CSR5_LNF	0x00001000	/* Link Fail			*/
#define CSR5_FD 	0x00000800	/* FDX Short Frame (21040)	*/
#define CSR5_GTE	0x00000800	/* General Purpose Timer Exprd	*/
#define CSR5_AT 	0x00000400	/* AUI/TP Switch (21040)	*/
#define CSR5_ETI	0x00000400	/* Early Transmit Interrupt	*/
#define CSR5_RWT	0x00000200	/* Receive Watchdog Time-Out	*/
#define CSR5_RPS	0x00000100	/* Receive Process Stopped	*/
#define CSR5_RU 	0x00000080	/* Receive Buffer Unavailable	*/
#define CSR5_RI 	0x00000040	/* Receive Interrupt		*/
#define CSR5_UNF	0x00000020	/* Transmit Underflow		*/
#define CSR5_LNP_ANC	0x00000010	/* 142,143 Link Pass/AN Compl.	*/
#define CSR5_TJT	0x00000008	/* Transmit Jabber Time-Out	*/
#define CSR5_TU 	0x00000004	/* Transmit Buffer Unavailable	*/
#define CSR5_TPS	0x00000002	/* Transmit Process Stopped	*/
#define CSR5_TI 	0x00000001	/* Transmit Interrupt		*/
#define CSR5_CLEAR	0x0381BFEF

/* CSR6: Operation Mode Register */
#define CSR6		0x30
#define CSR6_SC 	0x80000000	/* Special Capture Effect Ena	*/
#define CSR6_RA 	0x40000000	/* Receive All			*/
#define CSR6_BIT28	0x10000000	/* Bit 28			*/
#define CSR6_BIT27	0x08000000	/* Bit 27			*/
#define CSR6_BIT26	0x04000000	/* Bit 26			*/
#define CSR6_BIT25	0x02000000	/* Bit 25			*/
#define CSR6_SCR	0x01000000	/* Scrambler Mode Enable	*/
#define CSR6_CS 	0x00800000	/* CS Mode			*/
#define CSR6_MDR	0x00400000	/* MII/SYM Data Rate		*/
#define CSR6_FP 	0x00200000	/* Full Packet TX Flag		*/
#define CSR6_IMM	0x00100000	/* Immediate TX Flag		*/
#define CSR6_HBD	0x00080000	/* Heart Beat Disable		*/
#define CSR6_PS 	0x00040000	/* Port Select			*/

#define CSR6_CA 	0x00020000	/* Capture Effect Enable	*/
#define CSR6_BP 	0x00010000	/* Back Pressure		*/
#define CSR6_TR_MASK	0x0000C000	/* Threshold Control Bits	*/
#define CSR6_TR_72	0x00000000
#define CSR6_TR_96	0x00004000
#define CSR6_TR_128	0x00008000
#define CSR6_TR_160	0x0000C000
#define CSR6_TFF_128	0x00000000
#define CSR6_TFF_256	0x00004000
#define CSR6_TFF_512	0x00008000
#define CSR6_TFF_1024	0x0000C000
#define CSR6_ST 	0x00002000	/* Start/Stop Transmission Cmd	*/
#define CSR6_FC 	0x00001000	/* Force Collision Mode 	*/
#define CSR6_OM_MASK	0x00000C00	/* Operating Mode		*/
#define CSR6_OM_EXTLB	0x00000800	/* External loopback mode	*/
#define CSR6_OM_INTLB	0x00000400	/* Internal loopback mode	*/
#define CSR6_FD 	0x00000200	/* Full Duplex Operating Mode	*/
#define CSR6_FKD	0x00000100	/* Flaky Oscillator Disable	*/
#define CSR6_PM 	0x00000080	/* Pass All Multicast		*/
#define CSR6_PR 	0x00000040	/* Promiscuous Mode		*/
#define CSR6_SB 	0x00000020	/* Start/Stop Backoff Counter	*/
#define CSR6_IF 	0x00000010	/* Inverse Filtering		*/
#define CSR6_PB 	0x00000008	/* Pass Bad Frames		*/
#define CSR6_HO 	0x00000004	/* Hash Only			*/
#define CSR6_SR 	0x00000002	/* Start/Stop Receive		*/
#define CSR6_HP 	0x00000001	/* Hash/Perfect Rcv Filter Mode */

#define CSR6_100TX	(CSR6_BIT25|CSR6_PS|CSR6_CS|CSR6_SCR|CSR6_HBD)

/* CSR7: Interrupt Mask Register */
#define CSR7		0x38
#define CSR7_LCE	0x08000000	/* 143 Link Changed Enable	*/
#define CSR7_GPE	0x04000000	/* 142,143 GP Port IRQ Enable	*/
#define CSR7_NIM	0x00010000	/* Normal Interrupt Sry Msk	*/
#define CSR7_AIM	0x00008000	/* Abnormal Interrupt Sry Mask	*/
#define CSR7_SEM	0x00002000	/* System Error Mask		*/
#define CSR7_LFM	0x00001000	/* Link Fail Mask		*/
#define CSR7_FDM	0x00000800	/* Full Duplex Short Frame Rcvd */
#define CSR7_GTM	0x00000800	/* General Purpose Timer Mask	*/
#define CSR7_ATM	0x00000400	/* AUI/TP Switch Mask		*/
#define CSR7_ETM	0x00000400	/* Early Transmit Interrupt Msk */
#define CSR7_RWM	0x00000200	/* Receive Watchdog Time-Out	*/
#define CSR7_RSM	0x00000100	/* Receive Process Stopped Mask */
#define CSR7_RUM	0x00000080	/* Receive Buffer Unavail Mask	*/
#define CSR7_RIM	0x00000040	/* Receive Interrupt Mask	*/
#define CSR7_UNM	0x00000020	/* Transmit Underflow Mask	*/
#define CSR7_LPE_ANE	0x00000010	/* 142,143 Link Pass/AN Compl.	*/
#define CSR7_TJM	0x00000008	/* Transmit Jabber Time-Out	*/
#define CSR7_TUM	0x00000004	/* Transmit Buffer Unavailable	*/
#define CSR7_TSM	0x00000002	/* Transmit Process Stopped	*/
#define CSR7_TIM	0x00000001	/* Transmit Interrupt Mask	*/

#define RX_STOP 	0xffffffbf	
/* CSR8: Missed Frame Counter */
#define CSR8		0x40
#define CSR8_OV_OV	0x10000000	/* 140A Overflow Counter Overfl */
#define CSR8_OV_MASK	0x0FFE0000	/* 140A Overflow Counter Mask	*/
#define CSR8_OV_SHIFT	17		/* 140A Overflow Counter Shift	*/
#define CSR8_MF_OV	0x00010000	/* Missed Frame Counter Overflow*/
#define CSR8_MF_MASK	0x0000FFFF	/* Missed Frame Counter Mask	*/

/* CSR9: ENET ROM Register (21040) / Serial ROM and PHY Register (21140) */
#define CSR9		0x48
#define CSR9_DN 	0x80000000	/* Data Not Valid Bit OBSOLETE	*/
#define CSR9_EA_MASK	0x000000FF	/* Ethernet Address ROM Data	*/

#define CSR9_PDI	0x00080000	/* PHY Mode Data In OBSOLETE	*/
#define CSR9_PMD1	0x00040000	/* PHY Mode  OBSOLETE		*/
#define CSR9_PMD0	0x00020000	/* PHY Mode  OBSOLETE		*/
#define CSR9_PDO	0x00010000	/* PHY Mode Data Out  OBSOLETE	*/

#define CSR9_MDI	0x00080000	/* Management Data In		*/
#define CSR9_MMD_RD	0x00040000	/* Management Mode: Read	*/
#define CSR9_MMD_WR1	0x00020000	/* Management Mode: Write 1	*/
#define CSR9_MMD_WR0	0x00000000	/* Management Mode: Write 0	*/
#define CSR9_MDC	0x00010000	/* Management Clock		*/

#define CSR9_SRO	0x00004000	/* ROM/Ext Reg Read Operation	*/
#define CSR9_SWO	0x00002000	/* ROM/Ext Reg Write Operation	*/
#define CSR9_SBR	0x00041000	/* Select Boot ROM		*/
#define CSR9_SSR	0x00040800	/* Select Serial ROM		*/
#define CSR9_SREG	0x00040400	/* Select External Register	*/
#define CSR9_DATA	0x000000FF	/* Boot ROM or Ext. Reg Data	*/
#define CSR9_SDO	0x00000008	/* Serial ROM Data Out		*/
#define CSR9_SDI	0x00000004	/* Serial ROM Data In		*/
#define CSR9_SCLK	0x00000002	/* Serial ROM Serial Clock	*/
#define CSR9_SCS	0x00000001	/* Serial ROM Chip Select	*/
#define CSR9_IDLE	CSR9_MMD_RD	/* Tri-state MD IO pin		*/

/* CSR10: General Purpose Register (21140 pass 1 only) */
#define CSR10		0x50
#define CSR10_GPC	0x00000100	/* General Purpose Control	*/
#define CSR10_MD_MASK	0x000000FF	/* General Purpose Mode/Data	*/

/* CSR11: Full-Duplex Register (21040, never implemented) */
/*#define CSR11_MASK	0x0000FFFF*/	/* Full Duplex Auto Config Val	*/

/* CSR11: General-Purpose Timer (21041?, 21142/3) */
#define CSR11		0x58
#define CSR11_CON	0x00010000	/* Continuous mode		*/
#define CSR11_MASK	0x0000FFFF	/* Full Duplex Auto Config Val	*/
#define CSR11_HZ_SIA10	4882		/* 204.8 usec			*/
#define CSR11_HZ_MII100 12207		/* 81.92 usec			*/
#define CSR11_HZ_MII10	1220		/* 819.2 usec			*/

/* CSR12: SIA Status Register (21040) */
#define CSR12		0x60
#define CSR12_DAO	0x00000080	/* DPLL all one 		*/
#define CSR12_DAZ	0x00000040	/* DPLL all zero		*/
#define CSR12_DSP	0x00000020	/* DPLL self test pass		*/
#define CSR12_DSD	0x00000010	/* DPLL self test done		*/
#define CSR12_APS	0x00000008	/* Auto Polarity State		*/
#define CSR12_LKF	0x00000004	/* Linkfail Status		*/
#define CSR12_NCR	0x00000002	/* Network Connection Error	*/
#define CSR12_PAUI	0x00000001	/* PIN AUI/TP Indication	*/

/* CSR12: SIA Status Register (21041, old version) */
#define CSR12_LPN	0x00008000	/* Link Partner Negotiable	*/
#define CSR12_ANS_MASK	0x00007000	/* AN Arbitration State 	*/
#define CSR12_ANS_COMPL 0x00005000	/* AN Complete			*/
#define CSR12_ANS_DET	0x00002000	/* Ability Detect		*/
#define CSR12_ANS_DIS	0x00000000	/* AN Disabled			*/
#define CSR12_NSN	0x00000800	/* Non-Stable NLPs Detected	*/
#define CSR12_ANRFDS	0x00000400	/* AN Restart/FD Selected	*/
#define CSR12_NRA	0x00000200	/* Nonselected Port RX Activity */
#define CSR12_SRA	0x00000100	/* Selected Port RX Activity	*/

/* CSR12: SIA Status Register (21041) */
#define CSR12_041_LPCM	0xFFFF0000	/* Link Partner Code Word Mask	*/
#define CSR12_041_LPCS	16		/* Link Partner Code Word Shift */
#define CSR12_041_LPN	0x00008000	/* Link Partner Negotiable	*/
#define CSR12_041_ANMSK 0x00007000	/* AN Arbitration State 	*/
#define CSR12_041_ANCPL 0x00005000	/* AN Complete			*/
#define CSR12_041_ANDET 0x00002000	/* Ability Detect		*/
#define CSR12_041_ANDIS 0x00000000	/* AN Disabled			*/
#define CSR12_041_NSN	0x00000800	/* Non-Stable NLPs Detected	*/
#define CSR12_041_ANRFD 0x00000400	/* AN Restart/FD Selected	*/
#define CSR12_041_NRA	0x00000200	/* Nonselected Port RX Activity */
#define CSR12_041_SRA	0x00000100	/* Selected Port RX Activity	*/
#define CSR12_041_DAO	0x00000080	/* DPLL all one 		*/
#define CSR12_041_DAZ	0x00000040	/* DPLL all zero		*/
#define CSR12_041_DSP	0x00000020	/* DPLL self test pass		*/
#define CSR12_041_DSD	0x00000010	/* DPLL self test done		*/
#define CSR12_041_APS	0x00000008	/* Auto Polarity State		*/
#define CSR12_041_LKF	0x00000004	/* Linkfail Status		*/
#define CSR12_041_NCR	0x00000002	/* Network Connection Error	*/

/* CSR12: General Purpose Register (21140) */
#define CSR12_GPC	0x00000100	/* General Purpose Control	*/
#define CSR12_MD_MASK	0x000000FF	/* General Purpose Mode/Data	*/
#define CSR12_140_GPC	0x00000100	/* General Purpose Control	*/
#define CSR12_140_MDMSK 0x000000FF	/* General Purpose Mode/Data	*/

/* CSR12: SIA Status Register (21142/3) */
#define CSR12_142_LPCM	0xFFFF0000	/* Link Partner Code Word Mask	*/
#define CSR12_142_LPCS	16		/* Link Partner Code Word Shift */
#define CSR12_142_NP	0x80000000	/* Next Page			*/
#define CSR12_142_ACK	0x40000000	/* Acknowledge			*/
#define CSR12_142_RF	0x20000000	/* Remote Fault 		*/
#define CSR12_142_T4	0x02000000	/* 100 Mbps T4			*/
#define CSR12_142_TXFD	0x01000000	/* 100 Mbps full duplex 	*/
#define CSR12_142_TXHD	0x00800000	/* 100 Mbps half duplex 	*/
#define CSR12_142_TPFD	0x00400000	/* 10 Mbps full duplex		*/
#define CSR12_142_TPHD	0x00200000	/* 10 Mbps half duplex		*/
#define CSR12_142_LPN	0x00008000	/* Link Partner Negotiable	*/
#define CSR12_142_ANMSK 0x00007000	/* AN Arbitration State 	*/
#define CSR12_142_ANCPL 0x00005000	/* AN Complete			*/
#define CSR12_142_ANACK 0x00004000	/* AN Complete Ack		*/
#define CSR12_142_ANDET 0x00002000	/* Ability Detect		*/
#define CSR12_142_LNKCK 0x00006000	/* Ability Detect		*/
#define CSR12_142_ANDIS 0x00000000	/* AN Disabled			*/
#define CSR12_142_TRF	0x00000800	/* Transmit Remote Fault	*/
#define CSR12_142_NSN	0x00000400	/* Non-Stable NLPs Detected	*/
#define CSR12_142_TRA	0x00000200	/* 10Base-T Receive Port Activ. */
#define CSR12_142_ARA	0x00000100	/* AUI Receive Port Activity	*/
#define CSR12_142_APS	0x00000008	/* Autopolarity State Positive	*/
#define CSR12_142_LS10	0x00000004	/* 10Base-T Link Status 	*/
#define CSR12_143_LS100 0x00000002	/* 143: 100Base-T Link Status	*/
#define CSR12_142_MRA	0x00000001	/* MII Receive Port Activity	*/

/* CSR13: SIA Connectivity Register (21040) */
#define CSR13		0x68
#define CSR13_OE57	0x00008000	/* Output Enable 5 6 7		*/
#define CSR13_OE24	0x00004000	/* Output Enable 2 4		*/
#define CSR13_OE13	0x00002000	/* Output Enable 1 3		*/
#define CSR13_IE	0x00001000	/* Input Enable 		*/
#define CSR13_SEL_MASK	0x00000F00	/* Ext Port Output Mux Select	*/
#define CSR13_ASE	0x00000080	/* APLL Start Enable		*/
#define CSR13_SIM	0x00000040	/* Serial Interface Input Mux	*/
#define CSR13_ENI	0x00000020	/* Encoder Input Mux		*/
#define CSR13_EDP	0x00000010	/* SIA DPLL External Input Ena	*/
#define CSR13_AUI	0x00000008	/* 10Base T or AUI		*/
#define CSR13_CAC	0x00000004	/* CSR Auto Configuration	*/
#define CSR13_PS	0x00000002	/* Pin AUI/TP Selection 	*/
#define CSR13_SRL	0x00000001	/* SIA Reset			*/

/* CSR13: SIA Connectivity Register (21041) */
#define CSR13_041_SDM	0x0000EF00	/* SIA Diagnostic Mode		*/
#define CSR13_041_AUIT	0x00000008	/* 10Base T or AUI		*/
#define CSR13_041_CAC	0x00000004	/* CSR Auto Configuration	*/
#define CSR13_041_SRL	0x00000001	/* SIA Reset			*/

/* CSR13: SIA Connectivity Register (21142/3) */
#define CSR13_142_AUI	0x00000008	/* 10Base T or AUI		*/
#define CSR13_142_RST	0x00000001	/* SIA Reset			*/

/* CSR14: Special SIA Register */
#define CSR14		0x70
#define CSR14_SPP	0x00004000	/* Set Polarity Plus		*/
#define CSR14_APE	0x00002000	/* Auto Polarity Enable 	*/
#define CSR14_LTE	0x00001000	/* Link Test Enable		*/
#define CSR14_SQE	0x00000800	/* Signal Quality Enable	*/
#define CSR14_CLD	0x00000400	/* Collision Detect Enable	*/
#define CSR14_CSQ	0x00000200	/* Collision Squelch Enable	*/
#define CSR14_RSQ	0x00000100	/* Receive Squelch Enable	*/
#define CSR14_CPEN_MASK 0x00000030	/* Compensation Enable		*/
#define CSR14_LSE	0x00000008	/* Link Pulse Send Enable	*/
#define CSR14_DREN	0x00000004	/* Driver Enable		*/
#define CSR14_LBK	0x00000002	/* Loopback Enable		*/
#define CSR14_ECEN	0x00000001	/* Encoder Enable		*/

/* CSR14: Special SIA Register (21041) */
#define CSR14_041_TAS	0x00008000	/* 10Base-T/AUI Autosensing EN	*/
#define CSR14_041_SPP	0x00004000	/* Set Polarity Plus		*/
#define CSR14_041_APE	0x00002000	/* Auto Polarity Enable 	*/
#define CSR14_041_LTE	0x00001000	/* Link Test Enable		*/
#define CSR14_041_SQE	0x00000800	/* Signal Quality Enable	*/
#define CSR14_041_CLD	0x00000400	/* Collision Detect Enable	*/
#define CSR14_041_CSQ	0x00000200	/* Collision Squelch Enable	*/
#define CSR14_041_RSQ	0x00000100	/* Receive Squelch Enable	*/
#define CSR14_041_ANE	0x00000080	/* Autonegotiation Enable	*/
#define CSR14_041_HDE	0x00000040	/* Half-Duplex Enable		*/
#define CSR14_041_CPEN	0x00000030	/* Compensation Enable		*/
#define CSR14_041_LSE	0x00000008	/* Link Pulse Send Enable	*/
#define CSR14_041_DREN	0x00000004	/* Driver Enable		*/
#define CSR14_041_LBK	0x00000002	/* Loopback Enable		*/
#define CSR14_041_ECEN	0x00000001	/* Encoder Enable		*/

/* CSR14: Special SIA Register (21142/3) */
#define CSR14_142_T4	0x00040000	/* Advertise T4 Capability	*/
#define CSR14_142_TXF	0x00020000	/* Advertise TX/FD Capability	*/
#define CSR14_142_TXH	0x00010000	/* Advertise TX/HD Capability	*/
#define CSR14_142_TAS	0x00008000	/* 10Base-T/AUI Autosensing EN	*/
#define CSR14_142_SPP	0x00004000	/* Set Polarity Plus		*/
#define CSR14_142_APE	0x00002000	/* Auto Polarity Enable 	*/
#define CSR14_142_LTE	0x00001000	/* Link Test Enable		*/
#define CSR14_142_SQE	0x00000800	/* Signal Quality Enable	*/
#define CSR14_142_CLD	0x00000400	/* Collision Detect Enable	*/
#define CSR14_142_CSQ	0x00000200	/* Collision Squelch Enable	*/
#define CSR14_142_RSQ	0x00000100	/* Receive Squelch Enable	*/
#define CSR14_142_ANE	0x00000080	/* Autonegotiation Enable	*/
#define CSR14_142_HDE	0x00000040	/* Half-Duplex Enable		*/
#define CSR14_142_CPENM 0x00000030	/* Compensation Enable		*/
#define CSR14_142_LSE	0x00000008	/* Link Pulse Send Enable	*/
#define CSR14_142_DREN	0x00000004	/* Driver Enable		*/
#define CSR14_142_LBK	0x00000002	/* Loopback Enable		*/
#define CSR14_142_ECEN	0x00000001	/* Encoder Enable		*/

/* CSR15: Special SIA Register */
#define CSR15		0x78
#define CSR15_FRL	0x00002000	/* Force Receiver Low		*/
#define CSR15_DPST	0x00001000	/* DPLL Self Test StarT 	*/
#define CSR15_FLF	0x00000400	/* Force Link Fail		*/
#define CSR15_FUSQ	0x00000200	/* Force Unsquelch		*/
#define CSR15_TSCK	0x00000100	/* Test Clock			*/
#define CSR15_RWR	0x00000020	/* Receive Watchdog Release	*/
#define CSR15_RWD	0x00000010	/* Receive Watchdog Disable	*/
#define CSR15_JCK	0x00000004	/* Jabber Clock 		*/
#define CSR15_HUJ	0x00000002	/* Host Unjab			*/
#define CSR15_JBD	0x00000001	/* Jabber Disable		*/

/* CSR15: SIA and General Purpose Port Register (21142/3) */
#define CSR15_142_RMI	0x40000000	/* Receive Match Interrupt	*/
#define CSR15_142_GI1	0x20000000	/* General Port Interrupt 1	*/
#define CSR15_142_GI0	0x10000000	/* General Port Interrupt 0	*/
#define CSR15_142_CWE	0x08000000	/* Control Write Enable 	*/
#define CSR15_142_RME	0x04000000	/* Receive Match Enable 	*/
#define CSR15_142_GEI1	0x02000000	/* General Port Enable IRQ 1	*/
#define CSR15_142_GEI0	0x01000000	/* General Port Enable IRQ 0	*/
#define CSR15_142_LGS3	0x00800000	/* LED/GP3 Select		*/
#define CSR15_142_LGS2	0x00400000	/* LED/GP2 Select		*/
#define CSR15_142_LGS1	0x00200000	/* LED/GP1 Select		*/
#define CSR15_142_LGS0	0x00100000	/* LED/GP0 Select		*/
#define CSR15_142_MDMSK 0x000F0000	/* General Purpose Mode/Data	*/
#define CSR15_142_RWR	0x00000020	/* Receive Watchdog Release	*/
#define CSR15_142_RWD	0x00000010	/* Receive Watchdog Disable	*/
#define CSR15_142_ABM	0x00000008	/* AUI/BNC Mode 		*/
#define CSR15_142_JCK	0x00000004	/* Jabber Clock 		*/
#define CSR15_142_HUJ	0x00000002	/* Host Unjabber		*/
#define CSR15_142_JBD	0x00000001	/* Jabber Disable		*/

/* Media setup for 21040 MAC */
#define CSR13_040_TP	0x8F01		/* 10Base-T			*/
#define CSR14_040_TP	0xFFFF
#define CSR15_040_TP	0x0000
#define CSR13_040_AUI	0x8F09		/* 10Base-5 (AUI)		*/
#define CSR14_040_AUI	0x0705
#define CSR15_040_AUI	0x0006
#define CSR13_040_BNC	0xEF09		/* 10Base-2 (BNC)		*/
#define CSR14_040_BNC	0x0705
#define CSR15_040_BNC	0x0006
#define CSR13_040_TPFD	0x8F01		/* 10Base-T Full Duplex 	*/
#define CSR14_040_TPFD	0xFFFD
#define CSR15_040_TPFD	0x0000
#define CSR13_040_TPILT 0x8F01		/* 10Base-T Ignore Link Test	*/
#define CSR14_040_TPILT 0xCFFF
#define CSR15_040_TPILT 0x0000
#define CSR13_040_TPFDILT 0x8F01	/* 10Base-T Full Duplex ILT	*/
#define CSR14_040_TPFDILT 0xC3FD
#define CSR15_040_TPFDILT 0x0000

/* Media setup for 21041 MAC */
#define CSR13_041_TP	0xEF01		/* 10Base-T			*/
#define CSR14_041_TP	0x7F3F		/* Auto-negotiation disabled	*/
#define CSR15_041_TP	0x0008
#define CSR13_041_AUI	0xEF09		/* 10Base-5 (AUI)		*/
#define CSR14_041_AUI	0x0705
#define CSR15_041_AUI	0x000E
#define CSR13_041_BNC	0xEF09		/* 10Base-2 (BNC)		*/
#define CSR14_041_BNC	0x0705
#define CSR15_041_BNC	0x0006
#define CSR13_041_TPFD	0xEF01		/* 10Base-T Full Duplex forced	*/
#define CSR14_041_TPFD	0x7F3D		/* AN disabled			*/
#define CSR15_041_TPFD	0x0008		/* Set CSR6_FD := 1		*/
#define CSR13_041_TPILT 0xEF01		/* 10Base-T Ignore Link Test	*/
#define CSR14_041_TPILT 0x4F3F		/* AN disabled			*/
#define CSR15_041_TPILT 0x0008
#define CSR13_041_AN	0xEF01		/* 10Base-T Autonegotiation	*/
#define CSR14_041_AN	0x7FFF		/* AN HD/FD advertised		*/
#define CSR15_041_AN	0x0008		/* Set CSR6_FD := 1		*/


#if (PDK_BUS_ORDER == 1234)
/* Bits for RDES0 */
#define RDES0_OWN	0x80000000	/* Ownership bit		*/
#define RDES0_FL_MASK	0x3FFF0000	/* Length mask			*/
#define RDES0_ES	0x00008000	/* Error summary		*/
#define RDES0_LE	0x00004000	/* Length error 		*/
#define RDES0_DTH	0x00002000	/* Data type high bit		*/
#define RDES0_DTL	0x00001000	/* Data type low bit		*/
#define RDES0_RF	0x00000800	/* Runt Frame			*/
#define RDES0_MF	0x00000400	/* Multicast frame		*/
#define RDES0_FS	0x00000200	/* First Descriptor		*/
#define RDES0_LS	0x00000100	/* Last Descriptor		*/
#define RDES0_TL	0x00000080	/* Frame too long		*/
#define RDES0_CS	0x00000040	/* Collision seen		*/
#define RDES0_FT	0x00000020	/* Frame type			*/
#define RDES0_RJ	0x00000010	/* Receive watchdog		*/
#define RDES0_RE	0x00000008	/* CRC/MII Error		*/
#define RDES0_DB	0x00000004	/* Dribbling bit		*/
#define RDES0_CE	0x00000002	/* CRC error			*/
#define RDES0_OF	0x00000001	/* Overflow			*/

/* Bits for RDES1 */
#define RDES1_RER	0x02000000	/* Receive End-of-Ring		*/
#define RDES1_RCH	0x01000000	/* Second Address chained	*/
#define RDES1_BS_MASK	0x000007FF	/* Buffer size fills 11 bits	*/
#define RDES1_BS1_MASK	0x000007FF	/* Buffer 1 size mask		*/
#define RDES1_BS1_SHIFT 0		/* Shift count for BS1		*/
#define RDES1_BS2_MASK	0x003FF800	/* Buffer 2 size mask		*/
#define RDES1_BS2_SHIFT 11		/* Shift count for BS2		*/


/* Bits for TDES0 */
#define TDES0_OWN	0x80000000	/* Ownership bit		*/
#define TDES0_ES	0x00008000	/* Error Summary		*/
#define TDES0_TO	0x00004000	/* Transmit Jabber		*/
#define TDES0_LO	0x00000800	/* Loss of carrier		*/
#define TDES0_NC	0x00000400	/* No carrier			*/
#define TDES0_LC	0x00000200	/* Late collision		*/
#define TDES0_EC	0x00000100	/* Excessive collisions 	*/
#define TDES0_HF	0x00000080	/* Heartbeat fail		*/
#define TDES0_CC_MASK	0x00000078	/* Collision count bits 	*/
#define TDES0_CC_SHIFT	3
#define TDES0_LF	0x00000004	/* Link fail			*/
#define TDES0_UF	0x00000002	/* Underflow error		*/
#define TDES0_DE	0x00000001	/* Deferred			*/

/* Bits for TDES1 */
#define TDES1_IC	0x80000000	/* Interrupt on completion	*/
#define TDES1_LS	0x40000000	/* Last segment 		*/
#define TDES1_FS	0x20000000	/* First segment		*/
#define TDES1_IV	0x10000000	/* Inverse filtering		*/
#define TDES1_FT1	0x10000000	/* Filter bit 1 		*/
#define TDES1_SET	0x08000000	/* Setup packet 		*/
#define TDES1_AC	0x04000000	/* Add CRC disable		*/
#define TDES1_TER	0x02000000	/* Transmit End-of-Ring 	*/
#define TDES1_TCH	0x01000000	/* Second Address chained	*/
#define TDES1_DPD	0x00800000	/* Disabled padding		*/
#define TDES1_HP	0x00400000	/* Hash/perfect filtering	*/
#define TDES1_FT0	0x00400000	/* Filter bit 0 		*/

#define TDES1_BS_MASK	0x000007FF	/* Buffer size fills 11 bits	*/
#define TDES1_BS1_MASK	0x000007FF	/* Buffer 1 size mask		*/
#define TDES1_BS1_SHIFT 0		/* Shift count for BS1		*/
#define TDES1_BS2_MASK	0x003FF800	/* Buffer 2 size mask		*/
#define TDES1_BS2_SHIFT 11		/* Shift count for BS2		*/
#else /* PDK_BUS_ORDER = 4321 */
/* Reversed */
/* Bits for RDES0 */
#define RDES0_OWN	0x00000080	/* Ownership bit		*/
#define RDES0_FL_MASK	0x0000FF3F	/* Length mask			*/
#define RDES0_ES	0x00800000	/* Error summary		*/
#define RDES0_LE	0x00400000	/* Length error 		*/
#define RDES0_DTH	0x00200000	/* Data type high bit		*/
#define RDES0_DTL	0x00100000	/* Data type low bit		*/
#define RDES0_RF	0x00080000	/* Runt Frame			*/
#define RDES0_MF	0x00040000	/* Multicast frame		*/
#define RDES0_FS	0x00020000	/* First Descriptor		*/
#define RDES0_LS	0x00010000	/* Last Descriptor		*/
#define RDES0_TL	0x80000000	/* Frame too long		*/
#define RDES0_CS	0x40000000	/* Collision seen		*/
#define RDES0_FT	0x20000000	/* Frame type			*/
#define RDES0_RJ	0x10000000	/* Receive watchdog		*/
#define RDES0_RE	0x08000000	/* CRC/MII Error		*/
#define RDES0_DB	0x04000000	/* Dribbling bit		*/
#define RDES0_CE	0x02000000	/* CRC error			*/
#define RDES0_OF	0x01000000	/* Overflow			*/

/* Bits for RDES1 */
#define RDES1_RER	0x00000002	/* Receive End-of-Ring		*/
#define RDES1_RCH	0x00000001	/* Second Address chained	*/
#define RDES1_BS_MASK	0xFF070000	/* Buffer size fills 11 bits	*/
#define RDES1_BS1_MASK	0xFF070000	/* Buffer 1 size mask		*/
#define RDES1_BS1_SHIFT 0		/* Shift count for BS1		*/
#define RDES1_BS2_MASK	0x00F83f00	/* Buffer 2 size mask		*/
#define RDES1_BS2_SHIFT 11		/* Shift count for BS2		*/


/* Bits for TDES0 */
#define TDES0_OWN	0x00000080	/* Ownership bit		*/
#define TDES0_ES	0x00800000	/* Error Summary		*/
#define TDES0_TO	0x00400000	/* Transmit Jabber		*/
#define TDES0_LO	0x00080000	/* Loss of carrier		*/
#define TDES0_NC	0x00040000	/* No carrier			*/
#define TDES0_LC	0x00020000	/* Late collision		*/
#define TDES0_EC	0x00010000	/* Excessive collisions 	*/
#define TDES0_HF	0x80000000	/* Heartbeat fail		*/
#define TDES0_CC_MASK	0x78000000	/* Collision count bits 	*/
#define TDES0_CC_SHIFT	3
#define TDES0_LF	0x04000000	/* Link fail			*/
#define TDES0_UF	0x02000000	/* Underflow error		*/
#define TDES0_DE	0x01000000	/* Deferred			*/

/* Bits for TDES1 */
#define TDES1_IC	0x00000080	/* Interrupt on completion	*/
#define TDES1_LS	0x00000040	/* Last segment 		*/
#define TDES1_FS	0x00000020	/* First segment		*/
#define TDES1_IV	0x00000010	/* Inverse filtering		*/
#define TDES1_FT1	0x00000010	/* Filter bit 1 		*/
#define TDES1_SET	0x00000008	/* Setup packet 		*/
#define TDES1_AC	0x00000004	/* Add CRC disable		*/
#define TDES1_TER	0x00000002	/* Transmit End-of-Ring 	*/
#define TDES1_TCH	0x00000001	/* Second Address chained	*/
#define TDES1_DPD	0x00008000	/* Disabled padding		*/
#define TDES1_HP	0x00004000	/* Hash/perfect filtering	*/
#define TDES1_FT0	0x00004000	/* Filter bit 0 		*/

#define TDES1_BS_MASK	0xFF070000	/* Buffer size fills 11 bits	*/
#define TDES1_BS1_MASK	0xFF070000	/* Buffer 1 size mask		*/
#define TDES1_BS1_SHIFT 0		/* Shift count for BS1		*/
#define TDES1_BS2_MASK	0x00F83F00	/* Buffer 2 size mask		*/
#define TDES1_BS2_SHIFT 11		/* Shift count for BS2		*/
#endif /* PDK_BUS_ORDER */

/* Board-level data */

#if 1
#define ZX342X2_CSR12_IOCTRL	0x11F	/* <0-4> outputs, <5-7> inputs	*/
#define ZX342X2_CSR12_NLB101	0x001	/* O- PDT/PDR LB		*/
#define ZX342X2_CSR12_LB102	0x002	/* O+ Twister LB		*/
#define ZX342X2_CSR12_LB10	0x004	/* O+ LXT901 LB 		*/
#define ZX342X2_CSR12_COLENA	0x008	/* O+ Collision Det Enable	*/
#define ZX342X2_CSR12_SIGDET	0x020	/* I+ 100Mb Signal Detect	*/
#define ZX342X2_CSR12_SYMDET	0x040	/* I+ 100Mb Symbol Detect	*/
#define ZX342X2_CSR12_NLNKPASS	0x080	/* I- 10Mb Link Pass		*/

#define ZX344X2_CSR12_IOCTRL	0x10B	/* <0,1,3> outp, <2,4-7> inp	*/
#define ZX344X2_CSR12_NLB101	0x001	/* O- PDT/PDR LB		*/
#define ZX344X2_CSR12_LB102	0x002	/* O+ Twister LB		*/
#define ZX344X2_CSR12_RXMATCH	0x004	/* I+ MAC receive match 	*/
#define ZX344X2_CSR12_ROTINT	0x008	/* O+ Rotated IRQ enable	*/
#define ZX344X2_CSR12_GP4	0x010	/* -- Unused, strapped high	*/
#define ZX344X2_CSR12_SIGDET	0x020	/* I+ 100Mb Signal Detect	*/
#define ZX344X2_CSR12_SYMDET	0x040	/* I+ 100Mb Symbol Detect	*/
#define ZX344X2_CSR12_GP7	0x080	/* -- Unused, strapped high	*/

#define ZX345X1_CSR12_IOCTRL	0x103	/* <0-1> unused, <2-7> inputs	*/
#define ZX345X1_CSR12_NLED4	0x004	/* I- LED4 signal		*/
#define ZX345X1_CSR12_SPEED10	0x008	/* I+ 10 Mbps Mode		*/
#define ZX345X1_CSR12_RXMATCH	0x010	/* I+ MAC receive match 	*/
#define ZX345X1_CSR12_SIGDET	0x020	/* I+ 100Mb Signal Detect	*/
#define ZX345X1_CSR12_PHYACT	0x040	/* I+ PHY activity		*/
#define ZX345X1_CSR12_NLNKPASS	0x080	/* I- 10/100Mb Link Pass	*/

#define ZX351X1_CSR12_IOCTRL	0x12F	/* <0-3,5> outp, <4,6,7> inp	*/
#define ZX351X1_CSR12_PHYLB	0x001	/* O+ PHY loopback		*/
#define ZX351X1_CSR12_PHYRST	0x002	/* O+ PHY reset 		*/
#define ZX351X1_CSR12_AUTOSPSEL 0x004	/* O+ NWay enable		*/
#define ZX351X1_CSR12_HISPEED	0x008	/* O+ 100Mb mode (if GPP2==0)	*/
#define ZX351X1_CSR12_RXMATCH	0x010	/* I+ MAC receive match 	*/
#define ZX351X1_CSR12_LED	0x020	/* O+ LED			*/
#define ZX351X1_CSR12_NPHYACT	0x040	/* I- PHY activity		*/
#define ZX351X1_CSR12_NLNKPASS	0x080	/* I- Link Pass 		*/
#endif


