/*==========================================================================
**
**	znyx/hw/dec21554.h
**
**	Definitions for DEC 21554-AA
**
**==========================================================================
**
**	(c) Copyright 1998 ZNYX Corporation
**	All Rights Reserved.
**
**==========================================================================
**
**	Note: All DWORD/WORD ordering in this header is little-endian !
**
**	Modification History:
**
**==========================================================================
*/



/* PCI IDs */
#define	DEC_21554_PCI_ID	0x00461011
#define	DEC_21555_PCI_ID	0xB5558086

#define BR554_21143_WINDOW	0x400

/* Configuration Registers */
/*  Additional names for base registers */
#define B554_PCSR	0x04	/* [31:16] Primary CSR, [15:0] Primary CMD */
#define B554_DMBR0	0x10	/* Primary CSR and Downstream Memory 0 BAR */
#define B554_PCIOBR	0x14	/* Primary CSR I/O BAR */
#define B554_DMBR1	0x18	/* Downstream I/O or Memory 1 BAR */
#define B554_DMBR2	0x1C	/* Downstream Memory 2 BAR */
#define B554_DMBR3	0x20	/* Downstream Memory 3 BAR */
#define B554_DMBR3U	0x24	/* Upper 32 Bits Dnstrm Mem. 3 BAR */
#define B554_SCSR	0x44	/* [31:16] Secondary CSR, [15:0] Secondary CMD */
#define B554_SCMBR	0x50	/* Secondary CSR Memory BAR */
#define B554_SCIOBR	0x54	/* Secondary CSR I/O BAR */
#define B554_UMBR0	0x58	/* Upstream I/O or Memory 0 BAR */
#define B554_UMBR1	0x5C	/* Upstream Memory 1 BAR */
#define B554_UMBR2	0x60	/* Upstream Memory 2 BAR */

/*	These are in addition to the 64 byte Type 0 Configuration Header */

#define B554_DCA	0x80	/* Downstream Configuration Address */
#define B554_DCD	0x84	/* Downstream Configuration Data */
#define B554_UCA	0x88	/* Upstream Configuration Address */
#define B554_UCD	0x8C	/* Upstream Configuration Data */
#define B554_CS		0x90	/* Configuration CSR and Own Bits */
#define B554_DMTB0	0x94	/* Downstream Memory 0 Translated Base */
#define B554_DMTB1	0x98	/* Downstream I/O or Memory 1 Translated Base */
#define B554_DMTB2	0x9C	/* Downstream Memory 2 Translated Base */
#define B554_DMTB3	0xA0	/* Downstream Memory 3 Translated Base */
#define B554_UMTB0	0xA4	/* Upstream I/O or Memory 0 Translated Base */
#define B554_UMTB1	0xA8	/* Upstream Memory 1 Translated Base */
#define B554_DMSR0	0xAC	/* Downstream Memory 0 Setup Register */
#define B554_DMSR1	0xB0	/* Downstream I/O or Memory 1 Setup Register */
#define B554_DMSR2	0xB4	/* Downstream Memory 2 Setup Register */
#define B554_DMSR3	0xB8	/* Downstream Memory 3 Setup Register */
#define B554_DMSR3U	0xBC	/* Upper 32 Bits Dnstrm Mem. 3 Setup Register */
#define B554_ROMSR	0xC0	/* Primary Expansion ROM Setup Register */
#define B554_UMSR0	0xC4	/* Upstream I/O or Memory 0 Setup Register */
#define B554_UMSR1	0xC8	/* Upstream Memory 1 Setup Register */
#define B554_CHIPC	0xCC	/* Chip Control 1 and 0 */
#define B554_ACCHS	0xD0	/* Arbiter Control and Chip Status */
#define B554_SERRD	0xD4	/* Secondary and primary SERR# disables */
#define B554_RESET	0xD8	/* Reset Control */
#define B554_PMCAP	0xDC	/* Power Management Capabilities */
#define B554_PMCSR	0xE0	/* Power Management Data, BSE and CSR */
#define B554_VPD	0xE4	/* VPD Address and capabilities */
#define B554_VPDDTA	0xE8	/* VPD Data */
#define B554_HTSWP	0xEC	/* Hot Swap Control and capability */


/* Control and Status Registers (Memory Mapped, some I/O Mapped) */

#define B554_DCACSR	0x00	/* Downstream Configuration Address */
#define B554_DCDCSR	0x04	/* Downstream Configuration Data */
#define B554_UCACSR	0x08	/* Upstream Configuration Address */
#define B554_UCDCSR	0x0C	/* Upstream Configuration Data */
#define B554_CSCSR	0x10	/* Configuration CSR and Own Bits */
#define B554_DIACSR	0x14	/* Downstream I/O Address */
#define B554_DIDCSR	0x18	/* Downstream I/O Data */
#define B554_UIACSR	0x1C	/* Upstream I/O Address */
#define B554_UIDCSR	0x20	/* Upstream I/O Data */
#define B554_ISCSR	0x24	/* I/O CSR and Own Bits */
#define B554_LUTOFF	0x28	/* 8:0 Lookup Table Offset */
#define B554_LUTD	0x2C	/* Lookup Table Data */
#define B554_I2OOS	0x30	/* I2O Outbound Post_List Status */
/*  Left out a bunch of I2O registers here */
#define B554_DMTB0CSR	0x68	/* Downstream Memory 0 Translated Base */
#define B554_DMTB1CSR	0x6C	/* Dnstrm I/O or Memory 1 Translated Base */
#define B554_DMTB2CSR	0x70	/* Downstream Memory 2 Translated Base */
#define B554_DMTB3CSR	0x74	/* Downstream Memory 3 Translated Base */
#define B554_UMTB0CSR	0x78	/* Upstrm I/O or Memory 0 Translated Base */
#define B554_UMTB1CSR	0x7C	/* Upstream Memory 1 Translated Base */
#define B554_CHIPSCSR	0x80	/* 31:16 Chip Status CSR */
#define B554_IRQMSKCS	0x84	/* 31:16 Chip Clear IRQ Mask Register,
								   15:0 Chip Set IRQ Mask Register */
#define B554_UPBIRQ0	0x88	/* Upstream Page Boundary IRQ 0 Register */
#define B554_UPBIRQ1	0x8C	/* Upstream Page Boundary IRQ 1 Register */
#define B554_UPBIRQM0	0x90	/* Upstrm Page Boundary IRQ Mask 0 Register */
#define B554_UPBIRQM1	0x94	/* Upstrm Page Boundary IRQ Mask 1 Register */
#define B554_SPCLRIRQ	0x98	/* [31:16 Secondary, 15:0 Primary] Clear IRQ*/
#define B554_SPSETIRQ	0x9C	/* [31:16 Secondary, 15:0 Primary] Set IRQ */
#define B554_SPCLRIRQM	0xA0	/* [31:16 Secdry, 15:0 Prim] Clear IRQ MASK*/
#define B554_SPSETIRQM	0xA4	/* [31:16 Secdry, 15:0 Prim] Set IRQ MASK */
#define B554_SCRATCH	0xA8	/* Scratchpad 0-7 */
#define B554_ROMDSET	0xC8 	/* [23:16] ROM Data, [15:0] Rom Setup */
#define B554_ROMCA		0xCC	/* [31:24] ROM Control,[23:0] ROM Address */
#define B554_UM2LUT		0x100	/* Upstream Memory 2 Lookup Table (-0x1FF) */

/* Field Definitions for Control and Status Registers */

/* Indirect Configuration and I/O Enables */
#define B554_CFG_ENA	0x20000	/* Configuration CSR Dnstrm Config enable */
#define B554_DIO_ENA	0x20000	/* I/O CSR Downstream transaction enable */
#define B554_UIO_ENA	0x2000000	/* I/O CSR Upstream transaction enable */

/* ROM registers */
#define B554_ROMA_8		0		/* 8 times p_clk cycle time */
#define B554_ROMA_16	1		/* 16 times p_clk cycle time */
#define B554_ROMA_64	2		/* 64 times p_clk cycle time */
#define B554_ROMA_256	3		/* 256 times p_clk cycle time */
#define B554_ROMS_1		0x000	/* 1 p_clk cycle per bit */
#define B554_ROMS_2		0x100	/* 2 p_clk cycles per bit */
#define B554_ROMS_8		0x200	/* 8 p_clk cycles per bit */
#define B554_ROMS_32	0x300	/* 32 p_clk cycles per bit */
#define B554_SR_BUSY	0x1000000	/* Serial ROM Start/Busy */
#define B554_PR_BUSY	0x2000000	/* Parallel ROM Start/Busy */
#define B554_PR_WRT		0x4000000	/* Parallel ROM Read/Write Control */
#define B554_SR_POLL	0x8000000	/* Serial ROM polling status */

