/*==========================================================================
**
**	znyx/hw/dp83840.h
**
**	Definitions for NS DP83840 PHY part
**
**==========================================================================
**
**	(c) Copyright 1995 ZNYX Corporation
**	(c) Copyright 2001 ZNYX Networks
**	All Rights Reserved.
**
**==========================================================================
**
**	Modification History:
**	jr	08/23/95	Created
**	jr	10/09/95	Added DP83840_ prefix
**	jr	09/26/01	Added PCR register bits
**
**==========================================================================
*/



/* Basic Mode Control Register (BMCR) */

#define	DP83840_BMCR_REG	0x00
#define	DP83840_BMCR_RESET	0x8000	/* Reset PHY to default		*/
#define	DP83840_BMCR_LOOPBACK	0x4000	/* Enable loopback mode		*/
#define	DP83840_BMCR_100	0x2000	/* Speed select 10/100		*/
#define	DP83840_BMCR_ANENA	0x1000	/* Auto-Negotiation Enable	*/
#define	DP83840_BMCR_PWRDN	0x0800	/* Power down mode enable	*/
#define	DP83840_BMCR_ISOLATE	0x0400	/* Isolate PHY from MII data	*/
#define	DP83840_BMCR_ANRST	0x0200	/* Restart auto-negotiation	*/
#define	DP83840_BMCR_FD		0x0100	/* Full duplex mode enable	*/
#define	DP83840_BMCR_COLTEST	0x0080	/* Collision test mode enable	*/


/* Basic Mode Status Register (BMSR) */

#define	DP83840_BMSR_REG	0x01
#define	DP83840_BMSR_100T4	0x8000	/* 100Base-T4 capable		*/
#define	DP83840_BMSR_100TXFD	0x4000	/* 100Base-TX/FD capable	*/
#define	DP83840_BMSR_100TX	0x2000	/* 100Base-TX capable		*/
#define	DP83840_BMSR_10TPFD	0x1000	/* 100Base-TP/FD capable	*/
#define	DP83840_BMSR_10TP	0x0800	/* 100Base-TP capable		*/
#define	DP83840_BMSR_ANCPL	0x0020	/* Auto-negotiation complete	*/
#define	DP83840_BMSR_RFLT	0x0010	/* Remote fault			*/
#define	DP83840_BMSR_ANABL	0x0008	/* Able to perform auto-neg.	*/
#define	DP83840_BMSR_LNKST	0x0004	/* Valid link status		*/
#define	DP83840_BMSR_JAB	0x0002	/* Jabber detect		*/
#define	DP83840_BMSR_XR		0x0001	/* Extended register capable	*/


/* PHY Identifier Register #1/#2 (PHYIDR1/PHYIDR2) */

#define	DP83840_PHYIDR1_REG	0x02
#define	DP83840_PHYIDR1		0x2000
#define	DP83840_PHYIDR2_REG	0x03
#define	DP83840_PHYIDR2		0x5C00


/* Auto-Negotiation Advertisement Register (ANAR) */

#define	DP83840_ANAR_REG	0x04
#define	DP83840_ANAR_NP		0x8000
#define	DP83840_ANAR_ACK	0x4000
#define	DP83840_ANAR_RF		0x2000
#define	DP83840_ANAR_T4		0x0200
#define	DP83840_ANAR_TXFD	0x0100
#define	DP83840_ANAR_TX		0x0080
#define	DP83840_ANAR_TPFD	0x0040
#define	DP83840_ANAR_TP		0x0020
#define	DP83840_ANAR_PS_MASK	0x001F
#define	DP83840_ANAR_PS_8023	0x0001


/* Auto-Negotiation Link Partner Ability Register (ANLPAR) */

#define	DP83840_ANLPAR_REG	0x05
#define	DP83840_ANLPAR_NP	0x8000
#define	DP83840_ANLPAR_ACK	0x4000
#define	DP83840_ANLPAR_RF	0x2000
#define	DP83840_ANLPAR_T4	0x0200
#define	DP83840_ANLPAR_TXFD	0x0100
#define	DP83840_ANLPAR_TX	0x0080
#define	DP83840_ANLPAR_TPFD	0x0040
#define	DP83840_ANLPAR_TP	0x0020
#define	DP83840_ANLPAR_PS_MASK	0x001F
#define	DP83840_ANLPAR_PS_8023	0x0001


/* Auto-Negotiation Expansion Register (ANER) */

#define	DP83840_ANER_REG	0x06
#define	DP83840_ANER_MLF	0x0010
#define	DP83840_ANER_LPNPABLE	0x0008
#define	DP83840_ANER_NPABLE	0x0004
#define	DP83840_ANER_PAGE_RX	0x0002
#define	DP83840_ANER_LPANABLE	0x0001


/* Disconnect Counter Register (DCR) */

#define	DP83840_DCR_REG		0x12


/* False Carrier Sense Counter Register (FCSCR) */

#define	DP83840_FCSCR_REG	0x13


/* Receiver Error Counter Register (RECR) */

#define	DP83840_RECR_REG	0x15


/* Silicon Revision Register (SRR) */

#define	DP83840_SRR_REG		0x16


/* PCS Configuration Register (PCR) */

#define	DP83840_PCR_REG		0x17
#define	DP83840_PCR_TRS		0x0400		/* TX ready select	*/
#define	DP83840_PCR_CCE		0x0100		/* Congestion control	*/
#define	DP83840_PCR_FC		0x0020		/* Force connect	*/


/* Loopback, Bypass & Receiver Error Mask Register (LBREMR) */

#define	DP83840_LBREMR_REG	0x18
#define	DP83840_LBREMR_BP_4B5B	0x4000
#define	DP83840_LBREMR_BP_SCR	0x2000
#define	DP83840_LBREMR_BP_ALIGN	0x1000
#define	DP83840_LBREMR_10BT_LB	0x0800
#define	DP83840_LBREMR_LB_MASK	0x0300
#define	DP83840_LBREMR_LB_REM	0x0200
#define	DP83840_LBREMR_LB_TWSTR	0x0100
#define	DP83840_LBREMR_LB_OFF	0x0000
#define	DP83840_LBREMR_CODERR	0x0010
#define	DP83840_LBREMR_PEERR	0x0008
#define	DP83840_LBREMR_LINKERR	0x0004
#define	DP83840_LBREMR_PKTERR	0x0002


/* PHY Address Register (PAR) */

#define	DP83840_PAR_REG		0x19
#define DP83840_PAR_AN_EN_STAT	0x0400
#define	DP83840_PAR_SPEED10	0x0040
#define	DP83840_PAR_CONSTAT	0x0020
#define	DP83840_PAR_PHYAD_MASK	0x001F


/* 10Base-T Status Register (10BTSR) */

#define	DP83840_TENBTSR_REG	0x1B
#define	DP83840_TENBTSR_SER	0x0200


/* 10Base-T Configuration Register (10BTCR) */

#define	DP83840_TENBTCR_REG	0x1C
#define	DP83840_TENBTCR_LPEN	0x0020
#define	DP83840_TENBTCR_HBE	0x0010
#define	DP83840_TENBTCR_UTP	0x0008
#define	DP83840_TENBTCR_LSS	0x0004
#define	DP83840_TENBTCR_JABEN	0x0001



