/*==========================================================================
**
**	znyx/hw/i82544.h
**
**	Definitions for Intel 82544
**
**==========================================================================
**
**	(c) Copyright 2002 ZNYX Networks
**	All Rights Reserved.
**
**==========================================================================
**
**	Modification History:
**	jr	03/04/02	New
**
**==========================================================================
**
**
**	double-check counter registers
**
**	TXDCTL reserved bits unclear. The spec is inconsistent in itself.
**	Maybe a 82543/544 change, RXDCTL probably the same.
**
**==========================================================================
*/



/* PCI configuration space macros */

#ifndef INTEL_VENDOR_ID
#define INTEL_VENDOR_ID			0x8086
#endif

#define INTEL_DEVICE_ID_82542		0x1000
#define INTEL_DEVICE_ID_82543GC_FIBER	0x1001
#define INTEL_DEVICE_ID_82543GC_COPPER	0x1004
#define INTEL_DEVICE_ID_82544EI_COPPER	0x1008
#define INTEL_DEVICE_ID_82544EI_FIBER	0x1009
#define INTEL_DEVICE_ID_82544GC_COPPER	0x100C
#define INTEL_DEVICE_ID_82544GC_LOM	0x100D
#define INTEL_DEVICE_ID_82546GC 	0x1010
#define INTEL_DEVICE_ID_82546GC_LOM 	0x1012

#define I82544_32BIT_REG_BAR		0x10
#define I82544_32BIT_FLASH_BAR		0x14
#define I82544_32BIT_IO_REG_BAR		0x18
#define I82544_64BIT_REG_BAR_LO		0x10
#define I82544_64BIT_REG_BAR_HI		0x14
#define I82544_64BIT_FLASH_BAR_LO	0x18
#define I82544_64BIT_FLASH_BAR_HI	0x1C
#define I82544_64BIT_IO_REG_BAR		0x20




/* Device Control Register (R/W) */

#define I82544_CTRL_REG		0x00000
#define I82544_CTRL_FD		0x00000001	/* Full Duplex			*/
#define I82544_CTRL_BEM		0x00000002	/* Big Endian Mode		*/
#define I82544_CTRL_PRIOR	0x00000004	/* Reserved (Priority on PCI)	*/
#define I82544_CTRL_LRST	0x00000008	/* Link Reset			*/
#define I82544_CTRL_TME		0x00000010	/* Reserved (Test mode)		*/
#define I82544_CTRL_ASDE	0x00000020	/* Auto-Speed Detection Enable	*/
#define I82544_CTRL_SLU		0x00000040	/* Set Link Up (mb 1 for PHY)	*/
#define I82544_CTRL_ILOS	0x00000080	/* Invert Loss-of-Signal	*/
#define I82544_CTRL_SPEED_MASK	0x00000300	/* Speed Selection		*/
#define I82544_CTRL_SPEED_10	0x00000000
#define I82544_CTRL_SPEED_100	0x00000100
#define I82544_CTRL_SPEED_1000	0x00000200
#define I82544_CTRL_BEM32	0x00000400	/* Reserved (Big Endian 32bit)	*/
#define I82544_CTRL_FRCSPD	0x00000800	/* Force Speed			*/
#define I82544_CTRL_FRCDPLX	0x00001000	/* Force Duplex			*/
#define I82544_CTRL_SWDPINSLO0	0x00040000	/* SDP 0 Data			*/
#define I82544_CTRL_SWDPINSLO1	0x00080000	/* SDP 1 Data			*/
#define I82544_CTRL_SWDPINSLO2	0x00100000	/* SDP 2 Data			*/
#define I82544_CTRL_SWDPINSLO3	0x00200000	/* SDP 3 Data			*/
#define I82544_CTRL_SWDPIOLO0	0x00400000	/* SDP 0 Direction (0=in,1=out)	*/
#define I82544_CTRL_SWDPIOLO1	0x00800000	/* SDP 1 Direction		*/
#define I82544_CTRL_SWDPIOLO2	0x01000000	/* SDP 2 Direction		*/
#define I82544_CTRL_SWDPIOLO3	0x02000000	/* SDP 3 Direction		*/
#define I82544_CTRL_RST		0x04000000	/* Device Reset			*/
#define I82544_CTRL_RFCE	0x08000000	/* Receive Flow Control Enable	*/
#define I82544_CTRL_TFCE	0x10000000	/* Transmit Flow Control Enable	*/
#define I82544_CTRL_RTE		0x20000000	/* Reserved (Routing Tag Ena)	*/
#define I82544_CTRL_VME		0x40000000	/* VLAN Mode Enable		*/
#define I82544_CTRL_PHY_RESET	0x80000000	/* PHY Reset			*/

/* Device Status Register (R/O) */

#define I82544_STATUS_REG	0x00008
#define I82544_STATUS_FD	0x00000001	/* Link Full Duplex Config Ind	*/
#define I82544_STATUS_LU	0x00000002	/* Link Up Indication		*/
#define I82544_STATUS_RSVD2	0x00000004
#define I82544_STATUS_RSVD3	0x00000008
#define I82544_STATUS_TXOFF	0x00000010	/* Transmission Paused		*/
#define I82544_STATUS_TBIMODE	0x00000020	/* TBI Mode Indication		*/
#define I82544_STATUS_SPEED_MASK 0x000000C0	/* Link Speed Setting		*/
#define	I82544_STATUS_SPEED_10	0x00000000      /* 10 Mbps			*/
#define I82544_STATUS_SPEED_100	0x00000040	/* 100 Mbps			*/
#define I82544_STATUS_SPEED_1000 0x00000080	/* 1000 Mbps			*/
#define I82544_STATUS_ASDV_MASK	0x00000300	/* Auto Speed Detection Value	*/
#define I82544_STATUS_MTXCKOK	0x00000400	/* Rsvd (MTX Clock Running OK)	*/
#define I82544_STATUS_PCI66	0x00000800	/* PCI Bus Speed Indication	*/
#define I82544_STATUS_BUS64	0x00001000	/* PCI Bus Width Indication	*/
#define I82544_STATUS_PCIX_MODE	0x00002000	/* PCI-X Mode Indication	*/
#define I82544_STATUS_PCIXSPD	0x0000C000	/* PCI-X Bus Speed Indication	*/

/* EEPROM/Flash Control & Data Register (R/W) */

#define I82544_EECD_REG		0x00010
#define I82546_EECD_REQ		0x00000040        /* Request for access to 82546 chip*/
#define I82546_EECD_GNT		0x00000080        /* EEPROM Access Grant from the 82546 chip*/

#define I82544_EECD_SK		0x00000001	/* Clock Input To EEPROM	*/
#define I82544_EECD_CS		0x00000002	/* Chip Select Input To EEPROM	*/
#define I82544_EECD_DI		0x00000004	/* Data In To EEPROM		*/
#define I82544_EECD_DO		0x00000008	/* Data Out From(!) EEPROM	*/
#define I82544_EECD_FWE_MASK	0x00000030
#define I82544_EECD_FWE_DIS	0x00000010	/* FLASH Writes Disabled	*/
#define I82544_EECD_FWE_EN	0x00000020	/* FLASH Writes Enabled		*/
#define I82544_EECD_FWE_SHIFT	4
#define	I82544_EECD_SIZE	0x00000200	/* Reserved (EEPROM Size: 0=64 words 1=256 words) */

/* Extended Device Control Register (R/W) */

/* fixme: */
#define I82544_CTRL_EXT_REG		0x00018
#define I82544_CTRL_EXT_GPI_EN0		0x00000001	/* Map SDP4 to GPI0		*/
#define I82544_CTRL_EXT_GPI_EN1		0x00000002	/* Map SDP5 to GPI1		*/
#define	I82544_CTRL_EXT_GPI_EN2		0x00000004	/* Map SDP6 to GPI2		*/
#define I82544_CTRL_EXT_GPI_EN3		0x00000008	/* Map SDP7 to GPI3		*/
#define I82544_CTRL_EXT_SWDPINSHI4	0x00000010	/* SDP 4 Data			*/
#define I82544_CTRL_EXT_SWDPINSHI5	0x00000020	/* Reserved			*/
#define I82544_CTRL_EXT_SWDPINSHI6	0x00000040	/* SDP 6 Data			*/
#define I82544_CTRL_EXT_SWDPINSHI7	0x00000080	/* SDP 7 Data			*/
#define I82544_CTRL_EXT_SWDPIOHI4	0x00000100	/* SDP 4 Direction (0=in,1=out)	*/
#define I82544_CTRL_EXT_SWDPIOHI5	0x00000200	/* Reserved			*/
#define I82544_CTRL_EXT_SWDPIOHI6	0x00000400	/* SDP 6 Direction		*/
#define I82544_CTRL_EXT_SWDPIOHI7	0x00000800	/* SDP 7 Direction		*/
#define I82544_CTRL_EXT_ASDCHK		0x00001000	/* ASD Check			*/
#define I82544_CTRL_EXT_EE_RST		0x00002000	/* EEPROM Reset			*/
#define I82544_CTRL_EXT_IPS		0x00004000	/* Invert Power State Bit 0	*/
#define I82544_CTRL_EXT_SPD_BYPS	0x00008000	/* Speed Select Bypass		*/
#define I82544_CTRL_EXT_IPS1		0x00010000	/* Invert Power State Bit 1	*/
#define I82544_CTRL_EXT_RO_DIS		0x00020000	/* Relaxed Ordering Disabled	*/

/* MDI Control Register (R/W) */

#define I82544_MDIC_REG		0x00020
#define I82544_MDIC_DATA_MASK	0x0000FFFF	/* Data			*/
#define I82544_MDIC_REG_MASK	0x001F0000	/* PHY Register Address	*/
#define I82544_MDIC_REG_SHIFT	16
#define I82544_MDIC_PHY_MASK	0x03E00000	/* PHY Address		*/
#define I82544_MDIC_PHY_SHIFT	21
#define I82544_MDIC_OP_MASK	0x0C000000	/* Opcode		*/
#define I82544_MDIC_WRITE	0x04000000	/* MDI Write		*/
#define I82544_MDIC_READ	0x08000000	/* MDI Read		*/
#define I82544_MDIC_READY	0x10000000	/* Ready Bit		*/
#define I82544_MDIC_IE		0x20000000	/* Interrupt Enable	*/
#define I82544_MDIC_ERROR	0x40000000	/* Error		*/

/* Flow Control Address Low Register (R/W) */

#define I82544_FCAL_REG		0x00028
#define	I82544_FCAL_BITS	0x00C28001	/* FC Multicast Bits	*/

/* Flow Control Address High Register (R/W) */

#define I82544_FCAH_REG		0x0002C
#define	I82544_FCAH_BITS	0x00000100	/* FC Multicast Bits	*/

/* Flow Control Type Register (R/W) */

#define I82544_FCT_REG		0x00030
#define	I82544_FCT_BITS		0x00008808	/* FC Ethertype Bits 	*/

/* VLAN Ether Type Register (R/W) */

#define I82544_VET_REG		0x00038
#define	I82544_VET_BITS		0x00008100	/* 802.1q Ethertype	*/

/* Interrupt Cause Read Register (R/O, clear on read) pg 161 */

#define I82544_ICR_REG		0x000C0
#define I82544_ICR_TXDW		0x00000001	/* Transmit Descriptor Written Back		*/
#define I82544_ICR_TXQE		0x00000002	/* Transmit Queue Empty				*/
#define I82544_ICR_LSC		0x00000004	/* Link Status Change				*/
#define I82544_ICR_RXSEQ	0x00000008	/* Receive Sequence Error			*/
#define I82544_ICR_RXDMT0	0x00000010	/* Receive Descriptor Minimum Threshold Reached	*/
#define I82544_ICR_RSVD20	0x00000020	/* Reserved					*/
#define I82544_ICR_RXO		0x00000040	/* Receiver Overrun				*/
#define I82544_ICR_RXT0		0x00000080	/* Receiver Timer Interrupt			*/
#define I82544_ICR_RSVD100	0x00000100	/* Reserved					*/
#define I82544_ICR_MDAC		0x00000200	/* MDIO Access Complete				*/
#define I82544_ICR_RXCFG	0x00000400	/* Receiving /C/ ordered sets			*/
#define I82544_ICR_GPI0		0x00000800	/* General Purpose Interrupt 0			*/
#define I82544_ICR_GPI1		0x00001000	/* Reserved (GPI 1)				*/
#define I82544_ICR_GPI2		0x00002000	/* General Purpose Interrupt 2			*/
#define I82544_ICR_GPI3		0x00004000	/* General Purpose Interrupt 3			*/
#define I82544_ICR_ALL		0x00007FFF	/* All Those Bits				*/
#define I82544_ICR_RSVD		0xFFFF8000	/* All Other Bits				*/

/* Interrupt Cause Set Register (W/O) pg 162 */

#define I82544_ICS_REG		0x000C8
#define I82544_ICS_TXDW		0x00000001	/* Transmit Descriptor Written Back		*/
#define I82544_ICS_TXQE		0x00000002	/* Transmit Queue Empty				*/
#define I82544_ICS_LSC		0x00000004	/* Link Status Change				*/
#define I82544_ICS_RXSEQ	0x00000008	/* Receive Sequence Error			*/
#define I82544_ICS_RXDMT0	0x00000010	/* Receive Descriptor Minimum Threshold Reached	*/
#define I82544_ICS_RSVD20	0x00000020	/* Reserved					*/
#define I82544_ICS_RXO		0x00000040	/* Receiver Overrun				*/
#define I82544_ICS_RXT0		0x00000080	/* Receiver Timer Interrupt			*/
#define I82544_ICS_RSVD100	0x00000100	/* Reserved					*/
#define I82544_ICS_MDAC		0x00000200	/* MDIO Access Complete				*/
#define I82544_ICS_RXCFG	0x00000400	/* Receiving /C/ ordered sets			*/
#define I82544_ICS_GPI0		0x00000800	/* General Purpose Interrupt 0			*/
#define I82544_ICS_GPI1		0x00001000	/* Reserved (GPI 1)				*/
#define I82544_ICS_GPI2		0x00002000	/* General Purpose Interrupt 2			*/
#define I82544_ICS_GPI3		0x00004000	/* General Purpose Interrupt 3			*/
#define I82544_ICS_ALL		0x00007FFF	/* All Those Bits				*/
#define I82544_ICS_RSVD		0xFFFF8000	/* All Other Bits				*/

/* Interrupt Mask Set/Read Register (R/W) pg 163 */

#define I82544_IMS_REG		0x000D0
#define I82544_IMS_TXDW		0x00000001	/* Transmit Descriptor Written Back		*/
#define I82544_IMS_TXQE		0x00000002	/* Transmit Queue Empty				*/
#define I82544_IMS_LSC		0x00000004	/* Link Status Change				*/
#define I82544_IMS_RXSEQ	0x00000008	/* Receive Sequence Error			*/
#define I82544_IMS_RXDMT0	0x00000010	/* Receive Descriptor Minimum Threshold Reached	*/
#define I82544_IMS_RSVD20	0x00000020	/* Reserved					*/
#define I82544_IMS_RXO		0x00000040	/* Receiver Overrun				*/
#define I82544_IMS_RXT0		0x00000080	/* Receiver Timer Interrupt			*/
#define I82544_IMS_RSVD100	0x00000100	/* Reserved					*/
#define I82544_IMS_MDAC		0x00000200	/* MDIO Access Complete				*/
#define I82544_IMS_RXCFG	0x00000400	/* Receiving /C/ ordered sets			*/
#define I82544_IMS_GPI0		0x00000800	/* General Purpose Interrupt 0			*/
#define I82544_IMS_GPI1		0x00001000	/* Reserved (GPI 1)				*/
#define I82544_IMS_GPI2		0x00002000	/* General Purpose Interrupt 2			*/
#define I82544_IMS_GPI3		0x00004000	/* General Purpose Interrupt 3			*/
#define I82544_IMS_RSVD		0xFFFF8000	/* All Other Bits				*/

/* Interrupt Mask Clear Register (W/O) pg 164 */

#define I82544_IMC_REG		0x000D8
#define I82544_IMC_TXDW		0x00000001	/* Transmit Descriptor Written Back		*/
#define I82544_IMC_TXQE		0x00000002	/* Transmit Queue Empty				*/
#define I82544_IMC_LSC		0x00000004	/* Link Status Change				*/
#define I82544_IMC_RXSEQ	0x00000008	/* Receive Sequence Error			*/
#define I82544_IMC_RXDMT0	0x00000010	/* Receive Descriptor Minimum Threshold Reached	*/
#define I82544_IMC_RSVD20	0x00000020	/* Reserved					*/
#define I82544_IMC_RXO		0x00000040	/* Receiver Overrun				*/
#define I82544_IMC_RXT0		0x00000080	/* Receiver Timer Interrupt			*/
#define I82544_IMC_RSVD100	0x00000100	/* Reserved					*/
#define I82544_IMC_MDAC		0x00000200	/* MDIO Access Complete				*/
#define I82544_IMC_RXCFG	0x00000400	/* Receiving /C/ ordered sets			*/
#define I82544_IMC_GPI0		0x00000800	/* General Purpose Interrupt 0			*/
#define I82544_IMC_GPI1		0x00001000	/* Reserved (GPI 1)				*/
#define I82544_IMC_GPI2		0x00002000	/* General Purpose Interrupt 2			*/
#define I82544_IMC_GPI3		0x00004000	/* General Purpose Interrupt 3			*/
#define I82544_IMC_ALL		0x00007FFF	/* All Those Bits				*/
#define I82544_IMC_RSVD		0xFFFF8000	/* All Other Bits				*/

/* Receive Control Register (R/W) pg 166 */

#define I82544_RCTL_REG		0x00100
#define I82544_RCTL_RST		0x00000001	/* Reserved (Software Reset)			*/
#define I82544_RCTL_EN		0x00000002	/* Receiver Enable				*/
#define I82544_RCTL_SBP		0x00000004	/* Store Bad Packets				*/
#define I82544_RCTL_UPE		0x00000008	/* Unicast Promiscuous Enabled			*/
#define I82544_RCTL_MPE		0x00000010	/* Multicast Promiscuous Enabled		*/
#define I82544_RCTL_LPE		0x00000020	/* Long Packet Reception Enable			*/
#define I82544_RCTL_LBM_MASK	0x000000C0	/* Loopback Mode Mask				*/
#define I82544_RCTL_LBM_NONE	0x00000000	/* No Loopback					*/
#define I82544_RCTL_LBM_MAC	0x00000040	/* Undefined (MAC Loopback)			*/
#define I82544_RCTL_LBM_SLP	0x00000080	/* Undefined (Serial Link Loopback)		*/
#define I82544_RCTL_LBM_TCVR	0x000000C0	/* PHY or External SERDES Loopback		*/
#define I82544_RCTL_RDMTS_MASK	0x00000300	/* Receive Descriptor Minimum Threshold Size	*/
#define I82544_RCTL_RDMTS_12	0x00000000	/* 1/2 of RDLEN					*/
#define I82544_RCTL_RDMTS_14	0x00000100	/* 1/4 of RDLEN					*/
#define I82544_RCTL_RDMTS_18	0x00000200	/* 1/8 of RDLEN					*/
#define I82544_RCTL_MO_MASK	0x00003000	/* Multicast Offset Bits			*/
#define I82544_RCTL_MO_SHIFT	12
#define I82544_RCTL_MO_47_36	0x00000000
#define I82544_RCTL_MO_46_35	0x00001000
#define I82544_RCTL_MO_45_34	0x00002000
#define I82544_RCTL_MO_43_32	0x00003000
#define I82544_RCTL_MDR		0x00004000	/* Reserved (MDR, Multicast Descriptor Ring 0)	*/
#define I82544_RCTL_BAM		0x00008000	/* Broadcast Accept Mode			*/
#define I82544_RCTL_BSIZE_MASK	0x02030000	/* Receive Buffer Size Mask Including BSEX	*/
/* I82544_RCTL_BSEX == 0 */
#define I82544_RCTL_BSIZE_256	0x00030000
#define I82544_RCTL_BSIZE_512	0x00020000
#define I82544_RCTL_BSIZE_1024	0x00010000
#define I82544_RCTL_BSIZE_2048	0x00000000
/* I82544_RCTL_BSEX == 1 */
#define I82544_RCTL_BSIZE_4096	0x02030000
#define I82544_RCTL_BSIZE_8192	0x02020000
#define I82544_RCTL_BSIZE_16384	0x02010000
#define I82544_RCTL_VFE		0x00040000	/* VLAN Filter Enable				*/
#define I82544_RCTL_CFIEN	0x00080000	/* Canonical Form Indicator Enable		*/
#define I82544_RCTL_CFI		0x00100000	/* Canonical Form Indicator Bit Value		*/
#define I82544_RCTL_DPF		0x00400000	/* Discard Pause Frames				*/
#define I82544_RCTL_PMCF	0x00800000	/* Pass MAC Control Frames			*/
#define I82544_RCTL_BSEX	0x02000000	/* Buffer Size Extension			*/
#define I82544_RCTL_SECRC	0x04000000	/* Strip Ethernet CRC				*/

/* Flow Control Transmit Timer Value Register (R/W) pg 156 */

#define I82544_FCTTV_REG	0x00170
#define	I82544_FCTTV_TTV	0x0000FFFF	/* Transmit Timer Value	*/

/* Transmit Configuration Word Register (R/W) pg 157 */

#define I82544_TXCW_REG		0x00178
#define I82544_TXCW_TCW_MASK	0x0000ffff	/* Transmit Configuration Word	*/
#define I82544_TXCW_TCW_FD	0x00000020	/* Full Duplex			*/
#define I82544_TXCW_TCW_HD	0x00000040	/* Half Duplex			*/
#define I82544_TXCW_TCW_PAUSE_S	0x00000080	/* Sym Pause			*/
#define I82544_TXCW_TCW_PAUSE_A	0x00000100	/* Asym Pause			*/
#define I82544_TXCW_TCW_RFI	0x00003000	/* Remote Fault Indication	*/
#define I82544_TXCW_TCW_NP	0x00008000	/* Next Page			*/
#define I82544_TXCW_TC		0x40000000	/* Transmit Config Control Bit	*/
#define I82544_TXCW_ANE		0x80000000	/* Auto-Negotiation Enable	*/

/* Receive Configuration Word Register (R/O) pg 159 */

#define I82544_RXCW_REG		0x00180
#define I82544_RXCW_RCW_MASK	0x0000ffff	/* Receive Configuration Word	*/
#define I82544_RXCW_CSI		0x04000000	/* Carrier Sense Indication	*/
#define I82544_RXCW_IS		0x08000000	/* Invalid Symbol		*/
#define I82544_RXCW_CH		0x10000000	/* Change			*/
#define I82544_RXCW_RC		0x20000000	/* Receiving /C/ ordered sets	*/
#define I82544_RXCW_BS		0x40000000	/* Bit Synchronization		*/
#define I82544_RXCW_ANC		0x80000000	/* Auto Negotiation Complete	*/

/* Transmit Control Register (R/W) pg 175 */

#define I82544_TCTL_REG		0x00400
#define I82544_TCTL_RST		0x00000001	/* Reserved (SW reset?)			*/
#define I82544_TCTL_EN		0x00000002	/* Transmit Enable			*/
#define I82544_TCTL_BCE		0x00000004	/* Reserved (Busy Check Enable)		*/
#define I82544_TCTL_PSP		0x00000008	/* Pad Short Packets			*/
#define I82544_TCTL_CT_MASK	0x00000ff0	/* Collision Threshold			*/
#define I82544_TCTL_CT_SHIFT	4
#define I82544_TCTL_CT_DEFAULT	0x000000f0	/* 16 Retries				*/
#define I82544_TCTL_COLD_MASK	0x003ff000	/* Collision Distance			*/
#define I82544_TCTL_COLD_SHIFT	12
#define I82544_TCTL_COLD_HD	0x00200000	/* 1000 Half Duplex			*/
#define I82544_TCTL_COLD_FD	0x00040000	/* Full Duplex or 10/100 Half Duplex	*/
#define I82544_TCTL_SWXOFF	0x00400000	/* Software XOFF Transmission		*/
#define I82544_TCTL_PBE		0x00800000	/* Reserved (Packet Burst Enable)	*/
#define I82544_TCTL_RTLC	0x01000000	/* Retransmit On Late Collision		*/
#define I82544_TCTL_NRTU	0x02000000	/* No Retransmit On Underrun		*/

/* Transmit IPG Register (R/W) pg 177 */

#define I82544_TIPG_REG		0x00410
#define	I82544_TIPG_IPGT_MASK	0x000003FF	/* IPG Transmit Time	*/
#define	I82544_TIPG_IPGT_SHIFT	0
#define	I82544_TIPG_IPGR1_MASK	0x000FFC00	/* IPG Receive Time 1	*/
#define	I82544_TIPG_IPGR1_SHIFT	10
#define	I82544_TIPG_IPGR2_MASK	0x3FF00000	/* IPG Receive Time 2	*/
#define	I82544_TIPG_IPGR2_SHIFT	20

/* Transmit Burst Timer Register (R/W) not documented */

#define I82544_TBT_REG		0x00448

/* Adaptive IFS Throttle Register (R/W) pg 179 */

#define I82544_AIT_REG		0x00458
#define	I82544_AIT_AIFS		0x0000FFFF	/* Adaptive IFS Value	*/
#define	I82544_AIT_BIFS		0xFFFF0000	/* Reserved (Burst IFS)	*/

/* Packet Buffer Allocation Register (R/W) pg160 */

#define I82544_PBA_REG		0x01000
#define	I82544_PBA_RXA_MASK	0x0000003F	/* Receive Packet Buffer Allocation	*/
#define	I82544_PBA_TXA_MASK	0x007F0000	/* Transmit Packet Buffer Allocation	*/
#define	I82544_PBA_DEFAULT	0x00000030	/* 48KB Receive, 16KB Transmit	*/

/* Flow Control Receive Threshold Low Register (R/W) pg169 */

#define I82544_FCRTL_REG	0x02160
#define I82544_FCRTL_RTL	0x0000FFF8	/* Receive Threshold Low	*/
#define I82544_FCRTL_XONE	0x80000000	/* XON Enable			*/

/* Flow Control Receive Threshold High Register (R/W) pg 170 */

#define I82544_FCRTH_REG	0x02168
#define I82544_FCRTH_RTH	0x0000FFF8	/* Receive Threshold High	*/
#define I82544_FCRTH_XFCE	0x80000000	/* External Flow Control Enabled */

/* Receive Descriptor Base Address Low Register (R/W) pg 171 */

#define I82544_RDBAL_REG	0x02800

/* Receive Descriptor Base Address High Register (R/W) */

#define I82544_RDBAH_REG	0x02804

/* Receive Descriptor Length Register (R/W) */

#define I82544_RDLEN_REG	0x02808

/* Receive Descriptor Head Register (R/W) */

#define I82544_RDH_REG		0x02810

/* Receive Descriptor Tail Register (R/W) */

#define I82544_RDT_REG		0x02818

/* Receive Delay Timer Register (R/W) pg 173 */

#define I82544_RDTR_REG		0x02820
#define	I82544_RDTR_DELAY	0x0000FFFF	/* Delay				*/
#define	I82544_RDTR_FPD		0x80000000	/* Flush Partial Descriptor Block	*/

/* Receive Descriptor Control Register (R/W) pg 174 */

#define I82544_RXDCTL_REG	0x02828
#define I82544_RXDCTL_PTHRESH	0x0000003F	/* Prefetch Threshold	*/
#define I82544_RXDCTL_PTHRESH_SHIFT 0
#define I82544_RXDCTL_HTHRESH	0x00003F00	/* Host Threshold	*/
#define I82544_RXDCTL_HTHRESH_SHIFT 8
#define I82544_RXDCTL_WTHRESH	0x003F0000	/* Writeback Threshold	*/
#define I82544_RXDCTL_WTHRESH_SHIFT 16
#define I82544_RXDCTL_GRAN	0x01000000	/* Granularity		*/

/* Transmit DMA Control Register (R/W) pg 179 */

#define I82544_TXDMAC_REG	0x03000
#define	I82544_TXDMAC_DPP	0x00000001	/* Disable Packet Prefetching	*/
#define	I82544_TXDMAC_DPRE	0x00000002	/* Reserved (DPRE ???)		*/

/* Transmit Descriptor Base Address Low Register (R/W) pg 180 */

#define I82544_TDBAL_REG	0x03800

/* Transmit Descriptor Base Address High Register (R/W) */

#define I82544_TDBAH_REG	0x03804

/* Transmit Descriptor Length Register (R/W) */

#define I82544_TDLEN_REG	0x03808

/* Transmit Descriptor Head Register (R/W) */

#define I82544_TDH_REG		0x03810

/* Transmit Descriptor Tail Register (R/W) */

#define I82544_TDT_REG		0x03818

/* Transmit Interrupt Delay Value Register (R/W) pg182 */

#define I82544_TIDV_REG		0x03820
#define	I82544_TIDV_IDV		0x0000FFFF	/* Interrupt Delay Value	*/

/* Transmit Descriptor Control Register (R/W) pg 183 */

#define I82544_TXDCTL_REG	0x03828
#define I82544_TXDCTL_PTHRESH	0x000000FF	/* Prefetch Threshold		*/
#define I82544_TXDCTL_PTHRESH_SHIFT 0
#define I82544_TXDCTL_HTHRESH	0x0000FF00	/* Host Threshold		*/
#define I82544_TXDCTL_HTHRESH_SHIFT 8
#define I82544_TXDCTL_WTHRESH	0x00FF0000	/* Write Back Threshold		*/
#define I82544_TXDCTL_WTHRESH_SHIFT 16
#define I82544_TXDCTL_GRAN	0x01000000	/* Granularity			*/

/* TCP Segmentation PAD And Minimum Threshold Register (R/W) pg 184 */

#define I82544_TSPMT_REG	0x03830
#define	I82544_TSPMT_TSMT	0x0000FFFF	/* TCP Segmentation Minimum Transfer		*/
#define	I82544_TSPMT_TSPBP	0xFFFF0000	/* TCP Segmentation Packet Buffer Padding	*/

/* CRC Error Count Register (R/O, clear on read) pg 219 */

#define I82544_CRCERRS_REG	0x04000

/* Alignment Error Count Register (R/O, clear on read) */

#define I82544_ALGNERRC_REG	0x04004

/* Symbol Error Count Register (R/O, clear on read) */

#define I82544_SYMERRS_REG	0x04008

/* Receive Error Count Register (R/O, clear on read) */

#define I82544_RXERRC_REG	0x0400C

/* Missed Packet Count Register (R/O, clear on read) */

#define I82544_MPC_REG		0x04010

/* Single Collision Count Register (R/O, clear on read) */

#define I82544_SCC_REG		0x04014

/* Excessive Collision Count Register (R/O, clear on read) */

#define I82544_ECOL_REG		0x04018

/* Multiple Collision Count Register (R/O, clear on read) */

#define I82544_MCC_REG		0x0401C

/* Late Collision Count Register (R/O, clear on read) */

#define I82544_LATECOL_REG	0x04020

/* Collision Count Register (R/O, clear on read) */

#define I82544_COLC_REG		0x04028

/* Defer Count Register (R/O, clear on read) */

#define I82544_DC_REG		0x04030

/* Transmit with no CRS Register (R/O, clear on read) */

#define I82544_TNCRS_REG	0x04034

/* Sequence Error Count Register (R/O, clear on read) */

#define I82544_SEC_REG		0x04038

/* Carrier Extension Error Count Register (R/O, clear on read) */

#define I82544_CEXTERR_REG	0x0403C

/* Receive Length Error Count Register (R/O, clear on read) */

#define I82544_RLEC_REG		0x04040

/* XON Received Count Register (R/O, clear on read) */

#define I82544_XONRXC_REG	0x04048

/* XON Transmitted Count Register (R/O, clear on read) */

#define I82544_XONTXC_REG	0x0404C

/* XOFF Received Count Register (R/O, clear on read) */

#define I82544_XOFFRXC_REG	0x04050

/* XOFF Transmitted Count Register (R/O, clear on read) */

#define I82544_XOFFTXC_REG	0x04054

/* Flow Control Received Unsupported Count Register (R/O, clear on read) */

#define I82544_FCRUC_REG	0x04058

/* Packets Received (64 Bytes) Count Register (R/O, clear on read) */

#define I82544_PRC64_REG	0x0405C

/* Packets Received (65 - 127 Bytes) Count Register (R/O, clear on read) */

#define I82544_PRC127_REG	0x04060

/* Packets Received (128 - 255 Bytes) Count Register (R/O, clear on read) */

#define I82544_PRC255_REG	0x04064

/* Packets Received (255 - 511 Bytes) Count Register (R/O, clear on read) */

#define I82544_PRC511_REG	0x04068

/* Packets Received (512 - 1023 Bytes) Count Register (R/O, clear on read) */

#define I82544_PRC1023_REG	0x0406C

/* Packets Received (1024 to Max Bytes) Count Register (R/O, clear on read) */

#define I82544_PRC1522_REG	0x04070

/* Good Packets Received Count Register (R/O, clear on read) */

#define I82544_GPRC_REG		0x04074

/* Broadcast Packets Received Count Register (R/O, clear on read) */

#define I82544_BPRC_REG		0x04078

/* Multicast Packets Received Count Register (R/O, clear on read) */

#define I82544_MPRC_REG		0x0407C

/* Good Packets Transmitted Count Register (R/O, clear on read) */

#define I82544_GPTC_REG		0x04080

/* Good Octets Received Count Low Register (R/O, clear on read) */

#define I82544_GORCL_REG	0x04088

/* Good Octets Received Count High Register (R/O, clear on read) */

#define I82544_GORCH_REG	0x0408C

/* Good Octets Transmitted Count Low Register (R/O, clear on read) */

#define I82544_GOTCL_REG	0x04090

/* Good Octets Transmitted Count High Register (R/O, clear on read) */

#define I82544_GOTCH_REG	0x04094

/* Receive No Buffers Count Register (R/O, clear on read) */

#define I82544_RNBC_REG		0x040A0

/* Receive Undersize Count Register (R/O, clear on read) */

#define I82544_RUC_REG		0x040A4

/* Receive Fragment Count Register (R/O, clear on read) */

#define I82544_RFC_REG		0x040A8

/* Receive Oversize Count Register (R/O, clear on read) */

#define I82544_ROC_REG		0x040AC

/* Receive Jabber Count Register (R/O, clear on read) */

#define I82544_RJC_REG		0x040B0

/* Total Octets Received Low Register (R/O, clear on read of High Reg) */

#define I82544_TORL_REG		0x040C0

/* Total Octets Received High Register (R/O, clear on read) */

#define I82544_TORH_REG		0x040C4

/* Total Octets Transmitted Low Register (R/O, clear on read of High Reg) */

#define I82544_TOTL_REG		0x040C8

/* Total Octets Transmitted High Register (R/O, clear on read) */

#define I82544_TOTH_REG		0x040CC

/* Total Packets Received Register (R/O, clear on read) */

#define I82544_TPR_REG		0x040D0

/* Total Packets Transmitted Register (R/O, clear on read) */

#define I82544_TPT_REG		0x040D4

/* Packets Transmitted (64 Bytes) Count Register (R/O, clear on read) */

#define I82544_PTC64_REG	0x040D8

/* Packets Transmitted (65 - 127 Bytes) Count Register (R/O, clear on read) */

#define I82544_PTC127_REG	0x040DC

/* Packets Transmitted (128 - 255 Bytes) Count Register (R/O, clear on read) */

#define I82544_PTC255_REG	0x040E0

/* Packets Transmitted (256 - 511 Bytes) Count Register (R/O, clear on read) */

#define I82544_PTC511_REG	0x040E4

/* Packets Transmitted (512 - 1023 Bytes) Count Register (R/O, clear on read) */

#define I82544_PTC1023_REG	0x040E8

/* Packets Transmitted (Greater than 1024 Bytes) Count Register (R/O, clear on read) */

#define I82544_PTC1522_REG	0x040EC

/* Multicast Packets Transmitted Count Register (R/O, clear on read) */

#define I82544_MPTC_REG		0x040F0

/* Broadcast Packets Transmitted Count Register (R/O, clear on read) */

#define I82544_BPTC_REG		0x040F4

/* TCP Segmentation Context Transmitted Count Register (R/O, clear on read) */

#define I82544_TSCTC_REG	0x040F8

/* TCP Segmentation Context Transmit Fail Count Register (R/O, clear on read) */

#define I82544_TSCTFC_REG	0x040FC

/* Receive Checksum Control Register (R/W) pg 185 */

#define I82544_RXCSUM_REG	0x05000
#define I82544_RXCSUM_PCSS_MASK	0x000000FF	/* Packet Checksum Start		*/
#define I82544_RXCSUM_IPOFL	0x00000100	/* IP Checksum Offload Enable		*/
#define I82544_RXCSUM_TUOFL	0x00000200	/* TCP/UDP Checksum Offload Enable	*/

/* Multicast Table Array Register (R/W) pg 187 */

#define I82544_MTA_REG		0x05200
#define	I82544_MTA_SIZE		128

/* Receive Address Register (R/W) pg 188 */

#define I82544_RAL_REG		0x05400
#define I82544_RAH_REG		0x05404
#define	I82544_RA_COUNT		16
#define	I82544_RAL_MASK		0xFFFFFFFF	/* Receive Address Low	*/
#define	I82544_RAH_AV		0x80000000	/* Address Valid	*/
#define	I82544_RAH_AS_MASK	0x00030000	/* Address Select Mask	*/
#define	I82544_RAH_AS_DST	0x00000000	/* Destination Address	*/
#define	I82544_RAH_AS_SRC	0x00010000	/* Source Address	*/
#define	I82544_RAH_MASK		0x0000FFFF	/* Receive Address High	*/

/* VLAN Filter Table Array Register (R/W) pg 189 */

#define I82544_VFTA_REG		0x05600
#define	I82544_VFTA_SIZE	128

/* Wake Up Control Register (R/W) pg 212 */

#define I82544_WUC_REG		0x05800
#define I82544_WUC_APME		0x00000001	/* Advanced Power Management Enable	*/
#define I82544_WUC_PME_EN	0x00000002	/* PME Enable				*/
#define I82544_WUC_PME_STATUS	0x00000004	/* PME Status				*/
#define I82544_WUC_APMPME	0x00000008	/* Assert PME On APM Wakeup		*/

/* Wake Up Filter Control Register (R/W) pg 213 */

#define I82544_WUFC_REG		0x05808
#define I82544_WUFC_LNKC	0x00000001	/* Link Status Change Wake Up Enable	*/
#define I82544_WUFC_MAG		0x00000002	/* Magic Packet Wake Up Enable		*/
#define I82544_WUFC_EX		0x00000004	/* Directed Exact Wake Up Enable	*/
#define I82544_WUFC_MC		0x00000008	/* Directed Multicast Wake Up Enable	*/
#define I82544_WUFC_BC		0x00000010	/* Broadcast Wake Up Enable		*/
#define I82544_WUFC_ARP		0x00000020	/* ARP Request Packet Wake Up Enable	*/
#define I82544_WUFC_IP		0x00000040	/* Directed IP Packet Wake Up Enable	*/
#define I82544_WUFC_FLX0	0x00010000	/* Flexible Filter 0 Enable		*/
#define I82544_WUFC_FLX1	0x00020000	/* Flexible Filter 1 Enable		*/
#define I82544_WUFC_FLX2	0x00040000	/* Flexible Filter 2 Enable		*/
#define I82544_WUFC_FLX3	0x00080000	/* Flexible Filter 3 Enable		*/

/* Wake Up Status Register (R/O) pg 214 */

#define I82544_WUS_REG		0x05810
#define I82544_WUS_LNKC		0x00000001	/* Link Status Changed			*/
#define I82544_WUS_MAG		0x00000002	/* Magic Packet Received		*/
#define I82544_WUS_EX		0x00000004	/* Directed Exact Packet Received	*/
#define I82544_WUS_MC		0x00000008	/* Directed Multicast Packet Received	*/
#define I82544_WUS_BC		0x00000010	/* Broadcast Packet Received		*/
#define I82544_WUS_ARP		0x00000020	/* ARP Request Packet Received		*/
#define I82544_WUS_IP		0x00000040	/* Directed IP Packet Received		*/
#define I82544_WUS_FLX0		0x00010000	/* Flexible Filter 0 Match		*/
#define I82544_WUS_FLX1		0x00020000	/* Flexible Filter 1 Match		*/
#define I82544_WUS_FLX2		0x00040000	/* Flexible Filter 2 Match		*/
#define I82544_WUS_FLX3		0x00080000	/* Flexible Filter 3 Match		*/

/* IP Address Valid Register (R/W) pg 215 */

#define I82544_IPAV_REG		0x05838
#define	I82544_IPAV_V0		0x00000001	/* IP Address 0 Valid	*/
#define	I82544_IPAV_V1		0x00000002	/* IP Address 1 Valid	*/
#define	I82544_IPAV_V2		0x00000004	/* IP Address 2 Valid	*/
#define	I82544_IPAV_V3		0x00000008	/* IP Address 3 Valid	*/

/* IP Address Table Register (R/W) pg 215 */

#define I82544_IPAT_REG		0x05840

/* Wake Up Packet Length Register (R/W) pg 216 */

#define I82544_WUPL_REG		0x05900
#define	I82544_WUPL_MASK	0x00000FFF

/* Wake Up Packet Memory Register (R/O) pg 216 */

#define I82544_WUPM_REG		0x05A00

/* Flexible Filter Length Table Register (R/W) pg 217 */

#define I82544_FFLT_REG		0x05F00

/* Flexible Filter Mask Table Register (R/W) */

#define I82544_FFMT_REG		0x09000

/* Flexible Filter Value Table Register (R/W) pg 218 */

#define I82544_FFVT_REG		0x09800





/* Receive Descriptor */

typedef struct {
	uint32_t	rd_buf_addr_lo;
	uint32_t	rd_buf_addr_hi;
	uint16_t	rd_length;
	uint16_t	rd_checksum;
	uint8_t		rd_status;
	uint8_t		rd_errors;
	uint16_t	rd_special;
} i82544_rdesc_t;

#define I82544_RD_BUNDLING	8	/* Need multiple of 8 RDs	*/
#define I82544_RD_ALIGNMENT	16	/* Aligned on Descriptor Size	*/

#define I82544_RD_STATUS_PIF	0x80	/* Passed In-exact Filter	*/
#define I82544_RD_STATUS_IPCS	0x40	/* IP Checksum Calculated	*/
#define I82544_RD_STATUS_TCPCS	0x20	/* TCP Checksum Calculated	*/
#define I82544_RD_STATUS_RSV	0x10	/* Reserved (Router Tag?)	*/
#define I82544_RD_STATUS_VP	0x08	/* Packet is 802.1Q		*/
#define I82544_RD_STATUS_IXSM	0x04	/* Ignore Checksum Indication	*/
#define I82544_RD_STATUS_EOP	0x02	/* End Of Packet		*/
#define I82544_RD_STATUS_DD	0x01	/* Descriptor Done		*/

#define I82544_RD_ERR_RXE	0x80	/* RX Data Error		*/
#define I82544_RD_ERR_IPE	0x40	/* IP Checksum Error		*/
#define I82544_RD_ERR_TCPE	0x20	/* TCP/UDP Checksum Error	*/
#define I82544_RD_ERR_CXE	0x10	/* Carrier Extension Error	*/
#define I82544_RD_ERR_RSV	0x08	/* Reserved			*/
#define I82544_RD_ERR_SEQ	0x04	/* Sequence Error		*/
#define I82544_RD_ERR_SE	0x02	/* Symbol Error			*/
#define I82544_RD_ERR_CE	0x01	/* CRC Error or Alignment Error	*/

#define I82544_RD_SF_VLAN_MASK	0x0FFF	/* VLAN Identifier		*/
#define I82544_RD_SF_CFI_MASK	0x1000	/* Canonical Form Indicator	*/
#define I82544_RD_SF_CFI_SHIFT	12
#define I82544_RD_SF_PRI_MASK	0xE000	/* User Priority		*/
#define I82544_RD_SF_PRI_SHIFT	13




/* Transmit Descriptors */

/* Legacy Transmit Descriptor */

typedef struct {
	uint32_t	td_buf_addr_lo;
	uint32_t	td_buf_addr_hi;
	uint16_t	td_length;
	uint8_t		td_cso;
	uint8_t		td_cmd;
	uint8_t		td_status;
	uint8_t		td_css;
	uint16_t	td_special;
} i82544_tdesc_t;

#define I82544_TD_BUNDLING	8	/* Need multiple of 8 TDs	*/
#define I82544_TD_ALIGNMENT	16	/* Aligned on Descriptor Size	*/

#define I82544_TD_CMD_IDE	0x80	/* Interrupt Delay Enable	*/
#define I82544_TD_CMD_VLE	0x40	/* VLAN Packet Enable		*/
#define I82544_TD_CMD_DEXT	0x20	/* Extension			*/
#define I82544_TD_CMD_RPS	0x10	/* Report Packet Sent		*/
#define I82544_TD_CMD_RS	0x08	/* Report Status		*/
#define I82544_TD_CMD_IC	0x04	/* Insert Checksum		*/
#define I82544_TD_CMD_IFCS	0x02	/* Insert FCS			*/
#define I82544_TD_CMD_EOP	0x01	/* End of Packet		*/

#define I82544_TD_STATUS_TU	0x08	/* Transmit Underrun		*/
#define I82544_TD_STATUS_LC	0x04	/* Late Collisions		*/
#define I82544_TD_STATUS_EC	0x02	/* Excess Collisions		*/
#define I82544_TD_STATUS_DD	0x01	/* Descriptor Done		*/

#define I82544_TD_SF_VLAN_MASK	0x0FFF	/* VLAN Identifier		*/
#define I82544_TD_SF_CFI_MASK	0x1000	/* Canonical Form Indicator	*/
#define I82544_TD_SF_CFI_SHIFT	12
#define I82544_TD_SF_PRI_MASK	0xE000	/* User Priority		*/
#define I82544_TD_SF_PRI_SHIFT	13




/* EEPROM Commands */

#define I82544_EEPROM_READ_OPCODE	0x6	/* EERPOM read opcode */
#define I82544_EEPROM_WRITE_OPCODE	0x5	/* EERPOM write opcode */
#define I82544_EEPROM_ERASE_OPCODE	0x7	/* EERPOM erase opcode */
#define I82544_EEPROM_EWEN_OPCODE	0x13	/* EERPOM erase/write enable */
#define I82544_EEPROM_EWDS_OPCODE	0x10	/* EERPOM erase/write disable */


/* EEPROM data information */

typedef struct {
	uint8_t		eeprom_ia[6];			/* word 0 - 2	*/
	uint8_t		eeprom_compat0;
	uint8_t		eeprom_compat1;
	uint8_t		eeprom_reserved[8];		/* word 4 - 7	*/
	uint8_t		eeprom_pba[4];
	uint16_t	eeprom_init_control1;		/* 0x0a */
	uint16_t	eeprom_subsystem_id;
	uint16_t	eeprom_subsystem_vendor_id;
	uint16_t	eeprom_device_id;
	uint16_t	eeprom_vendor_id;
	uint16_t	eeprom_init_control2;		/* 0x0f */
	uint16_t	eeprom_oem_res[0x10];
	uint16_t	eeprom_swdp_ctrl;
	uint16_t	eeprom_circuit_control;
	uint8_t		eeprom_d3_power;
	uint8_t		eeprom_d0_power;
	uint16_t	eeprom_res2[0x0d];
	uint16_t	eeprom_pxe_config[3];		/* 0x30 - 0x32 */
	uint16_t	eeprom_res3[12];
	uint16_t	eeprom_chksum;
} i82544_eeprom_t;

#define I82544_ICW1_SIGNATURE	0x4000
#define I82544_ICW1_32BIT_BAR	0x2000
#define I82544_ICW1_IPS0	0x1000
#define I82544_ICW1_FRCSPD	0x0800		/* 66 MHz ??? */
#define I82544_ICW1_FD		0x0400
#define I82544_ICW1_LRST	0x0200
#define I82544_ICW1_IPS1	0x0100
#define I82544_ICW1_SWDPIO_MASK	0x01E0
#define I82544_ICW1_SWDPIO_SHIFT 5
#define I82544_ICW1_ILOS	0x0010
#define I82544_ICW1_PM		0x0008
#define I82544_ICW1_PME_CLK	0x0004
#define I82544_ICW1_SUBSYS_ID	0x0002
#define I82544_ICW1_VENDEV_ID	0x0001

#define I82544_ICW2_APM_PME_EN	0x8000
#define I82544_ICW2_ASDE	0x4000
#define I82544_ICW2_PC_MASK	0x3000
#define I82544_ICW2_ANE		0x0800
#define I82544_ICW2_FLASH_64K	0x0000
#define I82544_ICW2_FLASH_128K	0x0200
#define I82544_ICW2_FLASH_256K	0x0400
#define I82544_ICW2_FLASH_512K	0x0600
#define I82544_ICW2_FLASH_MASK	0x0600
#define I82544_ICW2_FLASH_DIS	0x0100
#define I82544_ICW2_MSI_DIS	0x0080
#define I82544_ICW2_133MHZ_CAP	0x0040
#define I82544_ICW2_DMCR_MAP	0x0020
#define I82544_ICW2_MAX_READ	0x0010
#define I82544_ICW2_PCIX_64BIT	0x0008
#define I82544_ICW2_APM_ENABLE	0x0004
#define I82544_ICW2_FCRS	0x0002

#define I82544_SWDPC_DL_MASK	0x0F00
#define I82544_SWDPC_DL_SHIFT	8
#define I82544_SWDPC_DH_MASK	0xD000
#define I82544_SWDPC_DH_SHIFT	12
#define I82544_SWDPC_VL_MASK	0x000F
#define I82544_SWDPC_VL_SHIFT	0
#define I82544_SWDPC_VH_MASK	0x00D0
#define I82544_SWDPC_VH_SHIFT	4

#define I82544_EEPROM_CHECKSUM	0xBABA
#define EEPROM_CHECKSUM_REG        0x003F


