/*==========================================================================
**
**	znyx/hw/i82555.h
**
**	Definitions for Intel 82555 PHY part
**
**==========================================================================
**
**	(c) Copyright 2001 ZNYX Networks
**	All Rights Reserved.
**
**==========================================================================
**
**	Modification History:
**	jr	09/16/01	New
**
**==========================================================================
*/



/* Control Register (CR) */

#define	I82555_CR_REG		0x00
#define	I82555_CR_RESET		0x8000	/* Reset PHY to default		*/
#define	I82555_CR_LOOPBACK	0x4000	/* Enable loopback mode		*/
#define	I82555_CR_100		0x2000	/* Speed select 10/100		*/
#define	I82555_CR_ANENA		0x1000	/* Auto-Negotiation Enable	*/
#define	I82555_CR_PWRDN		0x0800	/* Power down mode enable	*/
#define	I82555_CR_ISOLATE	0x0400	/* Isolate PHY from MII data	*/
#define	I82555_CR_ANRST		0x0200	/* Restart auto-negotiation	*/
#define	I82555_CR_FD		0x0100	/* Full duplex mode enable	*/
#define	I82555_CR_COLTEST	0x0080	/* Collision test mode enable	*/


/* Status Register (SR) */

#define	I82555_SR_REG		0x01
#define	I82555_SR_100T4		0x8000	/* 100Base-T4 capable		*/
#define	I82555_SR_100TXFD	0x4000	/* 100Base-TX/FD capable	*/
#define	I82555_SR_100TX		0x2000	/* 100Base-TX capable		*/
#define	I82555_SR_10TPFD	0x1000	/* 100Base-TP/FD capable	*/
#define	I82555_SR_10TP		0x0800	/* 100Base-TP capable		*/
#define	I82555_SR_ANCPL		0x0020	/* Auto-negotiation complete	*/
#define	I82555_SR_RFLT		0x0010	/* Remote fault			*/
#define	I82555_SR_ANABL		0x0008	/* Able to perform auto-neg.	*/
#define	I82555_SR_LNKST		0x0004	/* Valid link status		*/
#define	I82555_SR_JAB		0x0002	/* Jabber detect		*/
#define	I82555_SR_XR		0x0001	/* Extended register capable	*/


/* PHY Identifier Register #1/#2 (PHYIDR1/PHYIDR2) */

#define	I82555_PHYIDR1_REG	0x02
#define	I82555_PHYIDR1		0x02A8
#define	I82555_PHYIDR2_REG	0x03
#define	I82555_PHYIDR2		0x0150


/* Auto-Negotiation Advertisement Register (ANAR) */

#define	I82555_ANAR_REG		0x04
#define	I82555_ANAR_NP		0x8000
#define	I82555_ANAR_ACK		0x4000
#define	I82555_ANAR_RF		0x2000
#define	I82555_ANAR_T4		0x0200
#define	I82555_ANAR_TXFD	0x0100
#define	I82555_ANAR_TX		0x0080
#define	I82555_ANAR_TPFD	0x0040
#define	I82555_ANAR_TP		0x0020
#define	I82555_ANAR_PS_MASK	0x001F
#define	I82555_ANAR_PS_8023	0x0001


/* Auto-Negotiation Link Partner Ability Register (ANLPAR) */

#define	I82555_ANLPAR_REG	0x05
#define	I82555_ANLPAR_NP	0x8000
#define	I82555_ANLPAR_ACK	0x4000
#define	I82555_ANLPAR_RF	0x2000
#define	I82555_ANLPAR_T4	0x0200
#define	I82555_ANLPAR_TXFD	0x0100
#define	I82555_ANLPAR_TX	0x0080
#define	I82555_ANLPAR_TPFD	0x0040
#define	I82555_ANLPAR_TP	0x0020
#define	I82555_ANLPAR_PS_MASK	0x001F
#define	I82555_ANLPAR_PS_8023	0x0001


/* Auto-Negotiation Expansion Register (ANER) */

#define	I82555_ANER_REG		0x06
#define	I82555_ANER_MLF		0x0010
#define	I82555_ANER_LPNPABLE	0x0008
#define	I82555_ANER_NPABLE	0x0004
#define	I82555_ANER_PAGE_RX	0x0002
#define	I82555_ANER_LPANABLE	0x0001


/* 82555 Status and Control (SAC) */

#define	I82555_SAC_REG		0x10
#define	I82555_SAC_BAY_FC	0x8000	/* Bay/82557 flow control ena	*/
#define	I82555_SAC_T4_ENA	0x4000	/* Enable T4 with AN disabled	*/
#define	I82555_SAC_CRS_DISC	0x2000
#define	I82555_SAC_TX_FC_DIS	0x1000	/* Transmit flow control disable*/
#define	I82555_SAC_RDS_SYNC	0x0800	/* Rcv Deserializer in sync	*/
#define	I82555_SAC_100_PD	0x0400	/* 100 mbps power down		*/
#define	I82555_SAC_10_PD	0x0200	/* 10 mbps power down		*/
#define	I82555_SAC_POL		0x0100	/* 10 mbps reverse polarity	*/
#define	I82555_SAC_T4		0x0004	/* AN result is T4		*/
#define	I82555_SAC_SPEED	0x0002	/* 100 mbps if set		*/
#define	I82555_SAC_FD		0x0001	/* Full duplex if set		*/


/* 82555 Special Control (SPC) */
#define	I82555_SPC_REG		0x11
#define	I82555_SPC_BYPASS_SCR	0x8000
#define	I82555_SPC_BYPASS_4T5	0x4000
#define	I82555_SPC_FORCE_H	0x2000
#define	I82555_SPC_FORCE_34	0x1000
#define	I82555_SPC_GL		0x0800	/* Force good link condition	*/
#define	I82555_SPC_TCSD		0x0200	/* Transmit carrier sense disa	*/
#define	I82555_SPC_DDPD		0x0100	/* Disable dynamic power down	*/
#define	I82555_SPC_ANLB		0x0080	/* Autonegotiation loopback	*/
#define	I82555_SPC_MDI3ST	0x0040	/* MDI interface tristate	*/
#define	I82555_SPC_FBP		0x0020	/* Filter bypass		*/
#define	I82555_SPC_APD		0x0010	/* Auto polarity disable	*/
#define	I82555_SPC_SQED		0x0008	/* SQE test disable		*/
#define	I82555_SPC_ES		0x0004
#define	I82555_SPC_LID		0x0002	/* Link integrity disable	*/
#define	I82555_SPC_JFD		0x0001	/* Jabber function disable	*/


/* 82555 Special Control, lets call it LED Control (LC) */
#define	I82555_LC_REG		0x1b
#define	I82555_LC_FORCED	0x0004	/* LED state forced on or off	*/
#define	I82555_LC_FORCED_ACT	0x0006	/* Activity LED forced on	*/
#define	I82555_LC_FORCED_LNK	0x0005	/* Link LED forced on		*/
#define	I82555_LC_ACT_COL	0x0003	/* Activity and Collision	*/
#define	I82555_LC_SPEED_LNK	0x0002	/* etc.				*/
#define	I82555_LC_SPEED_COL	0x0001
#define	I82555_LC_ACT_LNK	0x0000



