/*==========================================================================
**
**	znyx/hw/i82558.h
**
**	Definitions for Intel 82557 and 82558
**
**==========================================================================
**
**	(c) Copyright 2001 ZNYX Networks
**	All Rights Reserved.
**
**==========================================================================
**
**	Modification History:
**	jr	09/16/01	New
**
**==========================================================================
*/



/* PCI configuration space macros */

#ifndef INTEL_VENDOR_ID
#define INTEL_VENDOR_ID		0x8086
#endif
#define INTEL_82557_DEVICE_ID	0x1229		/* also 558, 559	*/
#define INTEL_82559ER_DEVICE_ID	0x1209

#define I82558_MMBA	0x10
#define I82558_IOBA	0x14



/* SCB Status Word Register, RU/CU Status (ST) */

#define	I82558_ST_REG		0
#define I82558_ST_RUS_MASK	0x3C
#define I82558_ST_RUS_SHIFT	2
#define I82558_ST_RUS_IDLE	0x00
#define I82558_ST_RUS_SUSP	0x04
#define I82558_ST_RUS_NORES	0x08
#define I82558_ST_RUS_READY	0x10
#define I82558_ST_RUS_NO_RBDS	0x20	/* a flag	*/
#define I82558_ST_RUS_SUSP_NR	0x24
#define I82558_ST_RUS_NORES_NR	0x28
#define I82558_ST_RUS_READY_NR	0x30
#define I82558_ST_CUS_MASK	0xC0
#define I82558_ST_CUS_SHIFT	6
#define I82558_ST_CUS_IDLE	0x00
#define I82558_ST_CUS_SUSP	0x40
#define I82558_ST_CUS_ACTIVE	0x80

/* SCB Status Word Register, Interrupt Status (IS) */

#define	I82558_IS_REG		1
#define I82558_IS_FCP		0x01	/* 558++: flow control	*/
#define I82558_IS_ER		0x02	/* 558++: early recv	*/
#define I82558_IS_SWI		0x04	/* software generated	*/
#define I82558_IS_MDI		0x08	/* mdi read/write compl	*/
#define I82558_IS_RNR		0x10	/* recv unit not ready	*/
#define I82558_IS_CNA		0x20	/* command unit idle	*/
#define I82558_IS_FR		0x40	/* frame received	*/
#define I82558_IS_CXTNO		0x80	/* cu compl/tx not ok	*/

/* SCB Command Word Register, RU/CU Command (CMD) */

#define	I82558_CMD_REG		2
#define I82558_CMD_NOP		0x00
#define I82558_CMD_CU_NOP	0x00	/* $$$ superfluous */
#define I82558_CMD_CU_START	0x10
#define I82558_CMD_CU_RESUME	0x20
#define I82558_CMD_CU_DUMP_LA	0x40
#define I82558_CMD_CU_DSC	0x50	/* dump statistical counters	*/
#define I82558_CMD_CU_BASE	0x60
#define I82558_CMD_CU_DRSC	0x70	/* dump & reset stat. counters	*/
#define I82558_CMD_RU_NOP	0x00	/* $$$ superfluous */
#define I82558_CMD_RU_START	0x01
#define I82558_CMD_RU_RESUME	0x02
#define I82558_CMD_RU_ABORT	0x04
#define I82558_CMD_RU_LOAD_HDS	0x05
#define I82558_CMD_RU_BASE	0x06
#define I82558_CMD_RU_RBD_RESUME 0x07

/* SCB Command Word Register, Interrupt Control (IC) */

#define	I82558_IC_REG		3
#define I82558_IC_MASK		0x01	/* Disable all interrupts	*/
#define I82558_IC_SI		0x02	/* Generate software interrupt	*/
#define _I82558_IC_FCP		0x04
#define _I82558_IC_ER		0x08
#define _I82558_IC_RNR		0x10
#define _I82558_IC_CNA		0x20
#define _I82558_IC_FR		0x40
#define _I82558_IC_CXTNO	0x80

/* SCB General Pointer Register (GP) */

#define	I82558_GP_REG		4

/* PORT Interface Register (PI) */

#define	I82558_PI_REG		8
#define I82558_PI_SOFT_RESET	0x00000000
#define I82558_PI_SELF_TEST	0x00000001
#define I82558_PI_SEL_RESET	0x00000002
#define I82558_PI_DUMP		0x00000003

/* Flash Control Register (FC) */

#define	I82558_FC_REG		0x0c

/* EEPROM Control Register (EC) */

#define	I82558_EC_REG		0x0e
#define I82558_EC_EESK		0x01 		/* shift clock		*/
#define I82558_EC_EECS		0x02 		/* chip select		*/
#define I82558_EC_EEDI		0x04 		/* data in		*/
#define I82558_EC_EEDO		0x08 		/* data out		*/

#define I82558_EOP_ERASE	0x4		/* should be 93c46.h	*/
#define I82558_EOP_WRITE	0x5
#define I82558_EOP_READ		0x6

/* MDI Control Register (MC) */

#define	I82558_MC_REG		0x10		/* mdi control		*/
#define I82558_MC_WRITE		0x04000000
#define I82558_MC_READ		0x08000000
#define	I82558_MC_READY		0x10000000
#define	I82558_MC_IE		0x20000000
/* fixme: define shift counts for phy, reg */

/* RX DMA Byte Count Register (RDBC) (82558,9) */

#define	I82558_RDBC_REG		0x14

/* Early RX Interrupt Register (ERI) (82558,9) */

#define	I82558_ERI_REG		0x18

/* Flow Control Threshold Register (FCT) (82558,9) */

#define	I82558_FCT_REG		0x19

/* Flow Control Xon/Xoff Register (FCX) (82558,9) */

#define	I82558_FCX_REG		0x1a

/* Power Management Register (PMDR) (82558,9) */

#define	I82558_PMDR_REG		0x1b

/* General Control Register (GC) (82559) */

#define	I82558_GC_REG		0x1c

/* General Status Register (GS) (82559) */

#define	I82558_GS_REG		0x1d

/* Cardbus Function Event Register (CFE) (82559) */

#define	I82558_CFE_REG		0x20

/* Cardbus Function Mask Register (CFM) (82559) */

#define	I82558_CFM_REG		0x24

/* Cardbus Function State Register (CFS) (82559) */

#define	I82558_CFS_REG		0x28

/* Cardbus Force Event Register (CFO) (82559) */

#define	I82558_CFO_REG		0x2c




/* Command blocks */

typedef struct i82558_nop {
	volatile uint16_t nop_status;
	volatile uint16_t nop_command;
	uint32_t	nop_link_addr;
} i82558_nop_t;

typedef struct i82558_ias {
	volatile uint16_t ias_status;
	volatile uint16_t ias_command;
	uint32_t	ias_link_addr;
	uint8_t		ias_ia[6];
} i82558_ias_t;

typedef struct i82558_config {
	volatile uint16_t	cf_status;
	volatile uint16_t	cf_command;
	uint32_t		cf_link_addr;
	uint8_t			cf_bytes[22];
} i82558_config_t;

/* Transmit Control Block, Transmit Buffer Descriptor */

typedef struct {
	uint32_t	tbd_addr;
	uint32_t	tbd_size;
} i82558_tbd_t;

/* Flexible Transmit Structure */
typedef struct i82558_tx {
	volatile uint16_t tcb_status;
	volatile uint16_t tcb_command;
	uint32_t	tcb_link_addr;
	uint32_t	tcb_tbd_array_addr;
	uint16_t	tcb_byte_count;
	uint8_t		tcb_tx_threshold;
	uint8_t		tcb_tbd_number;
	/* Extended Transmit Structure is followed
	   immediately by two TBDs */
} i82558_tx_t;

/* for now the mc setup command block is defined with the
   address list (intel term, really an array) for sizing. */

#define I82558_MAX_MCA	64
typedef struct i82558_mcs {
	volatile uint16_t mcs_status;
	volatile uint16_t mcs_command;
	uint32_t	mcs_link_addr;
	uint16_t	mcs_count;		/* 14 bits only */
	uint8_t		mcs_addr[I82558_MAX_MCA][6];
} i82558_mcs_t;

typedef union i82558_union {
	i82558_nop_t	nop;
	i82558_ias_t	ias;
	i82558_config_t	config;
	i82558_mcs_t	mcs;
	i82558_tx_t	tx;
} i82558_union_t;

/* status */
#define I82558_CB_STATUS_OK	0x2000
#define I82558_CB_STATUS_C	0x8000

/* commands */
#define I82558_CB_COMMAND_NOP	0x0
#define I82558_CB_COMMAND_IAS	0x1
#define I82558_CB_COMMAND_CONFIGURE	0x2
#define I82558_CB_COMMAND_MCS	0x3
#define I82558_CB_COMMAND_SMTX	0x4	/* simple mode transmit */
#define I82558_CB_COMMAND_DUMP	0x6
#define I82558_CB_COMMAND_DIAG	0x7
#define I82558_CB_COMMAND_FMTX	0xc	/* flexible mode transmit */

/* command flags */
#define I82558_CB_COMMAND_I	0x2000	/* generate interrupt on completion */
#define I82558_CB_COMMAND_S	0x4000	/* suspend on completion */
#define I82558_CB_COMMAND_EL	0x8000	/* end of list */

/* special link_addr value */
#define	I82558_CB_NULL		0xffffffff




/* receive frame area */

typedef struct i82558_rfa {
	volatile uint16_t rfa_status;
	volatile uint16_t rfa_control;
	uint32_t	rfa_link_addr;
	uint32_t	rfa_rbd_addr;
	volatile uint16_t rfa_actual_count;
	uint16_t	rfa_size;
} i82558_rfa_t;

#define I82558_RFA_STATUS_RC	0x0001	/* receive collision */
#define I82558_RFA_STATUS_IAMB	0x0002	/* 0 = matches station address */
#define I82558_RFA_STATUS_RE	0x0010	/* receive error from PHY */
#define I82558_RFA_STATUS_TL	0x0020	/* type/length */
#define I82558_RFA_STATUS_TS	0x0080	/* frame too short */
#define I82558_RFA_STATUS_DOR	0x0100	/* DMA overrun */
#define I82558_RFA_STATUS_NR	0x0200	/* no resources */
#define I82558_RFA_STATUS_AE	0x0400	/* alignment error */
#define I82558_RFA_STATUS_CE	0x0800	/* CRC error */
#define I82558_RFA_STATUS_OK	0x2000	/* packet received okay */
#define I82558_RFA_STATUS_C	0x8000	/* packet reception complete */
#define I82558_RFA_CONTROL_SF	0x08	/* simple/flexible memory mode */
#define I82558_RFA_CONTROL_H	0x10	/* header RFD */
#define I82558_RFA_CONTROL_S	0x4000	/* suspend after reception */
#define I82558_RFA_CONTROL_EL	0x8000	/* end of list */
#define	I82558_RFA_AC_MASK	0x3fff




/* statistics dump */

typedef struct i82558_stats {
	uint32_t	stats_transmit_good;
	uint32_t	stats_transmit_maxcols;
	uint32_t	stats_transmit_latecols;
	uint32_t	stats_transmit_underruns;
	uint32_t	stats_transmit_lost_crs;
	uint32_t	stats_transmit_deferred;
	uint32_t	stats_transmit_single_collisions;
	uint32_t	stats_transmit_multiple_collisions;
	uint32_t	stats_transmit_total_collisions;
	uint32_t	stats_receive_good;
	uint32_t	stats_receive_crc_errors;
	uint32_t	stats_receive_alignment_errors;
	uint32_t	stats_receive_rnr_errors;
	uint32_t	stats_receive_overrun_errors;
	uint32_t	stats_receive_cdt_errors;
	uint32_t	stats_receive_short_frames;
	uint32_t	stats_completion_status;
} i82558_stats_t;

#define I82558_STAT_DUMP_C	0x8000
#define I82558_STAT_DUMP_OK	0x2000
#define I82558_STATS_COMPL_DSC	0xa005
#define I82558_STATS_COMPL_DRSC	0xa007




/* eeprom data information (intel AP-369) */

typedef struct {
	uint8_t		eeprom_ia[6];			/* word 0 - 2	*/
	uint8_t		eeprom_compat0;
	uint8_t		eeprom_compat1;
	uint8_t		eeprom_reserved[2];		/* 4		*/
	uint8_t		eeprom_connectors;		/* 5l		*/
	uint8_t		eeprom_controller;		/* 5h		*/
	uint8_t		eeprom_pri_phy_address;
	uint8_t		eeprom_pri_phy_type;
	uint8_t		eeprom_sec_phy_address;
	uint8_t		eeprom_sec_phy_type;
	uint8_t		eeprom_pwa[4];
	uint16_t	eeprom_product_id;		/* 0x0a */
	uint16_t	eeprom_device_id;
	uint16_t	eeprom_vendor_id;
	uint16_t	eeprom_res2[0x23];
	uint16_t	eeprom_rpl_config[2];
	uint16_t	eeprom_res3[13];
	uint16_t	eeprom_chksum;
	} i82558_eeprom_t;

#define	I82558_ED_CONN_RJ45	0x01
#define	I82558_ED_CONN_BNC	0x02
#define	I82558_ED_CONN_AUI	0x04
#define	I82558_ED_CONN_MII	0x08

#define	I82555_ED_CP1_OEM	0x01

#define	I82558_ED_CT_557	1		/* eeprom_controller	*/
#define	I82558_ED_CT_558	2

#define I82558_ED_PHY_DC_MASK	0x3f		/* phy device code mask	*/
#define	I82558_ED_PHY_VSCR	0x40		/* vendor-specific code	*/
#define I82558_ED_PHY_SERIAL	0x80		/* phy is serial	*/

#define I82558_ED_PHY_NONE	0
#define I82558_ED_PHY_82553A	1
#define I82558_ED_PHY_82553C	2
#define I82558_ED_PHY_82503	3
#define I82558_ED_PHY_DP83840	4
#define I82558_ED_PHY_80C240	5
#define I82558_ED_PHY_80C24	6
#define I82558_ED_PHY_82555	7
#define I82558_ED_PHY_ML	8		/* probably ML6692	*/
#define I82558_ED_PHY_LXT	9		/* probably LXT970	*/
#define I82558_ED_PHY_DP83840A	10
#define I82558_ED_PHY_ICS1890	11
#define I82558_ED_PHY_82555B	11


#define I82558_ED_PID_SIG_MASK	0xC000
#define I82558_ED_PID_SIG	0x4000
#define I82558_ED_PID_ID	0x2000
#define I82558_ED_PID_BRD	0x0800		/* boot rom disable	*/
#define I82558_ED_PID_REV	0x0700
#define I82558_ED_PID_REV_SHIFT	8
#define I82558_ED_PID_PM	0x0080
#define I82558_ED_PID_WOL	0x0020
#define I82558_ED_PID_PA	0x0007


