/*==========================================================================
**
**	znyx/hw/ics1890.h
**
**	Definitions for ICS 1890 part
**
**==========================================================================
**
**	(c) Copyright 1995 ZNYX Corporation
**	All Rights Reserved.
**
**==========================================================================
**
**	Modification History:
**	jr	12/18/95	Created
**
**==========================================================================
*/



/* MII Control Register (MIICR) */

#define	ICS1890_MIICR_REG	0x00
#define	ICS1890_MIICR_RESET	0x8000	/* Reset PHY to default		*/
#define	ICS1890_MIICR_LOOPBACK	0x4000	/* Enable loopback mode		*/
#define	ICS1890_MIICR_100	0x2000	/* Speed select 10/100		*/
#define	ICS1890_MIICR_ANENA	0x1000	/* Auto-Negotiation Enable	*/
#define	ICS1890_MIICR_PWRDN	0x0800	/* Power down mode enable	*/
#define	ICS1890_MIICR_ISOLATE	0x0400	/* Isolate PHY from MII data	*/
#define	ICS1890_MIICR_ANRST	0x0200	/* Restart auto-negotiation	*/
#define	ICS1890_MIICR_FD	0x0100	/* Full duplex mode enable	*/
#define	ICS1890_MIICR_COLTEST	0x0080	/* Collision test mode enable	*/


/* MII Status Register (MIISR) */

#define	ICS1890_MIISR_REG	0x01
#define	ICS1890_MIISR_100T4	0x8000	/* 100Base-T4 capable		*/
#define	ICS1890_MIISR_100TXFD	0x4000	/* 100Base-TX/FD capable	*/
#define	ICS1890_MIISR_100TX	0x2000	/* 100Base-TX capable		*/
#define	ICS1890_MIISR_10TPFD	0x1000	/* 100Base-TP/FD capable	*/
#define	ICS1890_MIISR_10TP	0x0800	/* 100Base-TP capable		*/
#define	ICS1890_MIISR_ANCPL	0x0020	/* Auto-negotiation complete	*/
#define	ICS1890_MIISR_RFLT	0x0010	/* Remote fault			*/
#define	ICS1890_MIISR_ANABL	0x0008	/* Able to perform auto-neg.	*/
#define	ICS1890_MIISR_LNKST	0x0004	/* Valid link status		*/
#define	ICS1890_MIISR_JAB	0x0002	/* Jabber detect		*/
#define	ICS1890_MIISR_XR	0x0001	/* Extended register capable	*/


/* PHY Identifier Register #1/#2 (PHYIDR1/PHYIDR2) */

#define	ICS1890_PHYIDR1_REG	0x02
#define	ICS1890_PHYIDR1		0x0015
#define	ICS1890_PHYIDR2_REG	0x03
#define	ICS1890_PHYIDR2		0xF420


/* Auto-Negotiation Advertisement Register (ANAR) */

#define	ICS1890_ANAR_REG	0x04
#define	ICS1890_ANAR_NP		0x8000
#define	ICS1890_ANAR_ACK	0x4000
#define	ICS1890_ANAR_RF		0x2000
#define	ICS1890_ANAR_T4		0x0200
#define	ICS1890_ANAR_TXFD	0x0100
#define	ICS1890_ANAR_TX		0x0080
#define	ICS1890_ANAR_TPFD	0x0040
#define	ICS1890_ANAR_TP		0x0020
#define	ICS1890_ANAR_PS_MASK	0x001F
#define	ICS1890_ANAR_PS_8023	0x0001


/* Auto-Negotiation Link Partner Ability Register (ANLPAR) */

#define	ICS1890_ANLPAR_REG	0x05
#define	ICS1890_ANLPAR_NP	0x8000
#define	ICS1890_ANLPAR_ACK	0x4000
#define	ICS1890_ANLPAR_RF	0x2000
#define	ICS1890_ANLPAR_T4	0x0200
#define	ICS1890_ANLPAR_TXFD	0x0100
#define	ICS1890_ANLPAR_TX	0x0080
#define	ICS1890_ANLPAR_TPFD	0x0040
#define	ICS1890_ANLPAR_TP	0x0020
#define	ICS1890_ANLPAR_PS_MASK	0x001F
#define	ICS1890_ANLPAR_PS_8023	0x0001


/* Auto-Negotiation Expansion Register (ANER) */

#define	ICS1890_ANER_REG	0x06
#define	ICS1890_ANER_MLF	0x0010
#define	ICS1890_ANER_LPNPABLE	0x0008
#define	ICS1890_ANER_NPABLE	0x0004
#define	ICS1890_ANER_PAGE_RX	0x0002
#define	ICS1890_ANER_LPANABLE	0x0001


/* MII Extended Register 0 (MIIXR0) */

#define	ICS1890_MIIXR0_REG	0x10


/* Quick Poll Detailed Status Register */

#define	ICS1890_QPSR_REG	0x11


/* 10Base-T Operations Register */

#define	ICS1890_TPOP_REG	0x12


/* Extended Control Register 2 */

#define	ICS1890_XR2_REG		0x13



