/*==========================================================================
**
**	znyx/hw/m88e1000.h
**
**	Definitions for Marvell M88E1000 PHY (based on intel docs)
**
**==========================================================================
**
**	(c) Copyright 2002 ZNYX Networks
**	All Rights Reserved.
**
**==========================================================================
**
**	Modification History:
**	jr	03/10/02	New
**
**==========================================================================
*/



/* Control Register (CR) */

#define	M88E1000_CR_REG		0x00
#define	M88E1000_CR_RESET	0x8000	/* Reset PHY to default		*/
#define	M88E1000_CR_LOOPBACK	0x4000	/* Enable loopback mode		*/
#define	M88E1000_CR_100		0x2000	/* Speed select 10/100		*/
#define	M88E1000_CR_ANENA	0x1000	/* Auto-Negotiation Enable	*/
#define	M88E1000_CR_PWRDN	0x0800	/* Power down mode enable	*/
#define	M88E1000_CR_ISOLATE	0x0400	/* Isolate PHY from MII data	*/
#define	M88E1000_CR_ANRST	0x0200	/* Restart auto-negotiation	*/
#define	M88E1000_CR_FD		0x0100	/* Full duplex mode enable	*/
#define	M88E1000_CR_COLTEST	0x0080	/* Collision test mode enable	*/
#define M88E1000_CR_1000	0x0040	/*++ Speed select 1000		*/


/* Status Register (SR) */

#define	M88E1000_SR_REG		0x01
#define	M88E1000_SR_100T4	0x8000	/* 100Base-T4 capable		*/
#define	M88E1000_SR_100TXFD	0x4000	/* 100Base-TX/FD capable	*/
#define	M88E1000_SR_100TX	0x2000	/* 100Base-TX capable		*/
#define	M88E1000_SR_10TPFD	0x1000	/* 100Base-TP/FD capable	*/
#define	M88E1000_SR_10TP	0x0800	/* 100Base-TP capable		*/
#define M88E1000_SR_EXT_STATUS	0x0100	/*++ extended status in reg 15	*/
#define M88E1000_SR_PRE_SUP	0x0040	/*++ Preamble may be suppressed */
#define	M88E1000_SR_ANCPL	0x0020	/* Auto-negotiation complete	*/
#define	M88E1000_SR_RFLT	0x0010	/* Remote fault			*/
#define	M88E1000_SR_ANABL	0x0008	/* Able to perform auto-neg.	*/
#define	M88E1000_SR_LNKST	0x0004	/* Valid link status		*/
#define	M88E1000_SR_JAB		0x0002	/* Jabber detect		*/
#define	M88E1000_SR_XR		0x0001	/* Extended register capable	*/


/* PHY Identifier Register #1/#2 (PHYIDR1/PHYIDR2) */

#define	M88E1000_PHYIDR1_REG	0x02
#define	M88E1000_PHYIDR1	0x0141
#define	M88E1000_PHYIDR2_REG	0x03
#define	M88E1000_PHYIDR2_I	0x0C30
#define	M88E1000_PHYIDR2_14	0x0C40
#define	M88E1000_PHYIDR2_12	0x0C50
#define M88E1011_PHYIDR2_I	0x0C20


/* Auto-Negotiation Advertisement Register (ANAR) */

#define	M88E1000_ANAR_REG	0x04
#define	M88E1000_ANAR_NP	0x8000
#define	M88E1000_ANAR_ACK	0x4000	/* ???				*/
#define	M88E1000_ANAR_RF	0x2000
#define	M88E1000_ANAR_AS_PAUSE	0x0800	/*++ Asymmetric Pause		*/
#define	M88E1000_ANAR_PAUSE	0x0400	/*++ Pause			*/
#define	M88E1000_ANAR_T4	0x0200
#define	M88E1000_ANAR_TXFD	0x0100
#define	M88E1000_ANAR_TX	0x0080
#define	M88E1000_ANAR_TPFD	0x0040
#define	M88E1000_ANAR_TP	0x0020
#define	M88E1000_ANAR_PS_MASK	0x001F
#define	M88E1000_ANAR_PS_8023	0x0001


/* Auto-Negotiation Link Partner Ability Register (ANLPAR) */

#define	M88E1000_ANLPAR_REG	0x05
#define	M88E1000_ANLPAR_NP	0x8000
#define	M88E1000_ANLPAR_ACK	0x4000
#define	M88E1000_ANLPAR_RF	0x2000
#define	M88E1000_ANLPAR_T4	0x0200
#define	M88E1000_ANLPAR_TXFD	0x0100
#define	M88E1000_ANLPAR_TX	0x0080
#define	M88E1000_ANLPAR_TPFD	0x0040
#define	M88E1000_ANLPAR_TP	0x0020
#define	M88E1000_ANLPAR_PS_MASK	0x001F
#define	M88E1000_ANLPAR_PS_8023	0x0001


/* Auto-Negotiation Expansion Register (ANER) */

#define	M88E1000_ANER_REG	0x06
#define M88E1000_ANER_PAR_DET	0x0100	/*++ parallel detection failed	*/
#define	M88E1000_ANER_MLF	0x0010
#define	M88E1000_ANER_LPNPABLE	0x0008
#define	M88E1000_ANER_NPABLE	0x0004
#define	M88E1000_ANER_PAGE_RX	0x0002
#define	M88E1000_ANER_LPANABLE	0x0001


/* Auto-Negotiation Advertisement Register, Second Page (ANAR2) */

#define	M88E1000_ANAR2_REG	0x07
#define	M88E1000_ANAR2_NP	0x8000
#define	M88E1000_ANAR2_MSG	0x2000	/*++ formatted page		*/
#define	M88E1000_ANAR2_ACK	0x1000
#define	M88E1000_ANAR2_TOGGLE	0x0800


/* Auto-Negotiation Link Partner Ability Register, Second Page (ANLPAR2) */

#define	M88E1000_ANLPAR2_REG	0x08
#define	M88E1000_ANLPAR2_NP	0x8000
#define	M88E1000_ANLPAR2_ACK	0x4000
#define	M88E1000_ANLPAR2_MSG	0x2000
#define	M88E1000_ANLPAR2_ACK2	0x1000
#define	M88E1000_ANLPAR2_TOGGLE	0x0800


/* 1000Base-T Control Register, (GCR) */

#define	M88E1000_GCR_REG	0x09
#define	M88E1000_GCR_MS_MCEN	0x1000	/*++ M/S manual conf enable	*/
#define	M88E1000_GCR_MS_MASTER	0x0800	/*++ Master			*/
#define	M88E1000_GCR_PORT_TYPE	0x0400	/*++ Port type			*/
#define	M88E1000_GCR_1000T_FD	0x0200
#define	M88E1000_GCR_1000T_HD	0x0100


/* 1000Base-T Status Register, (GSR) */

#define	M88E1000_GSR_REG	0x0A
#define	M88E1000_GSR_MS_FAULT	0x8000
#define	M88E1000_GSR_MS_MASTER	0x4000
#define	M88E1000_GSR_LOC_RCV_OK	0x2000
#define	M88E1000_GSR_REM_RCV_OK	0x1000
#define	M88E1000_GSR_1000T_FD	0x0800	/* Link partner capable		*/
#define	M88E1000_GSR_1000T_HD	0x0400
#define	M88E1000_GSR_IEC_MASK	0x00FF	/* Idle error counter mask	*/


/* Extended PHY Status Register, (EPSR) */

#define	M88E1000_EPSR_REG	0x0F
#define	M88E1000_EPSR_1000X_FD	0x8000
#define	M88E1000_EPSR_1000X_HD	0x4000
#define	M88E1000_EPSR_1000T_FD	0x2000
#define	M88E1000_EPSR_1000T_HD	0x1000


/* PHY Specific Control Register, (PSCR) */

#define	M88E1000_PSCR_REG	0x10
#define	M88E1000_PSCR_TFD_MASK	0xC000
#define	M88E1000_PSCR_RFD_MASK	0x3000
#define	M88E1000_PSCR_CRS	0x0800	/* Assert CRS on transmit	*/
#define	M88E1000_PSCR_FORCE_LG	0x0400
#define	M88E1000_PSCR_WEIRD_WEIRD	0x0300
#define	M88E1000_PSCR_10BT_EED	0x0080
#define	M88E1000_PSCR_MCM_MDI	0x0000
#define	M88E1000_PSCR_MCM_MDIX	0x0020
#define	M88E1000_PSCR_MCM_AUTOG	0x0040
#define	M88E1000_PSCR_MCM_AUTO	0x0060
#define	M88E1000_PSCR_DIS125CLK	0x0010
#define	M88E1000_PSCR_MAC_UP	0x0008	/* Keep MAC powered up		*/
#define	M88E1000_PSCR_SQE_TEST	0x0004
#define	M88E1000_PSCR_PR_DIS	0x0002	/* Polarity reversal disabled	*/
#define	M88E1000_PSCR_JAB_DIS	0x0001


/* PHY Specific Status Register, (PSSR) pg 204 */

#define	M88E1000_PSSR_REG	0x11
#define	M88E1000_PSSR_1000	0x8000	/* 1000 Mbps			*/
#define	M88E1000_PSSR_100	0x4000
#define	M88E1000_PSSR_10	0x0000
#define	M88E1000_PSSR_FD	0x2000	/* Full duplex			*/
#define	M88E1000_PSSR_PR	0x1000	/* Page received		*/
#define	M88E1000_PSSR_ANCPL	0x0800	/* An complete			*/
#define	M88E1000_PSSR_LINK	0x0400	/* Link up			*/
#define	M88E1000_PSSR_MDIX	0x0040	/* MDIX crossover configuration	*/
#define	M88E1000_PSSR_POL	0x0002	/* Polarity reversed		*/
#define	M88E1000_PSSR_JAB	0x0001	/* Jabber detected		*/


/* PHY Interrupt Enable Register, (PIER) */

#define	M88E1000_PIER_REG	0x12
#define	M88E1000_PIER_ANE	0x8000	/* AN error interrupt enable	*/
#define	M88E1000_PIER_SPEED	0x4000	/* Speed changed int en		*/
#define	M88E1000_PIER_DUPLEX	0x2000	/* Duplex changed int en	*/
#define	M88E1000_PIER_PR	0x1000	/* Page received int en		*/
#define	M88E1000_PIER_ANCPL	0x0800	/* AN completet int en		*/
#define	M88E1000_PIER_LINK	0x0400	/* Link status changed int en	*/
#define	M88E1000_PIER_SE	0x0200	/* Symbol error int en		*/
#define	M88E1000_PIER_FC	0x0100	/* False carrier int en		*/
#define	M88E1000_PIER_FIFO	0x0080	/* FIFO overrun/underrun int en	*/
#define	M88E1000_PIER_MDIC	0x0040	/* MDI crossover changed int en	*/
#define	M88E1000_PIER_DS	0x0020	/* Downshift int en		*/
#define	M88E1000_PIER_POL	0x0002	/* Polarity changed int en	*/
#define	M88E1000_PIER_JAB	0x0001	/* Jabber int en		*/


/* PHY Interrupt Status Register, (PISR) */

#define	M88E1000_PISR_REG	0x13
#define	M88E1000_PISR_ANE	0x8000	/* AN error interrupt		*/
#define	M88E1000_PISR_SPEED	0x4000	/* Speed changed		*/
#define	M88E1000_PISR_DUPLEX	0x2000	/* Duplex changed		*/
#define	M88E1000_PISR_PR	0x1000	/* Page received		*/
#define	M88E1000_PISR_ANCPL	0x0800	/* AN completet			*/
#define	M88E1000_PISR_LINK	0x0400	/* Link status changed		*/
#define	M88E1000_PISR_SE	0x0200	/* Symbol error			*/
#define	M88E1000_PISR_FC	0x0100	/* False carrier		*/
#define	M88E1000_PISR_FIFO	0x0080	/* FIFO overrun/underrun	*/
#define	M88E1000_PISR_MDIC	0x0040	/* MDI crossover changed	*/
#define	M88E1000_PISR_DS	0x0020	/* Downshift			*/
#define	M88E1000_PISR_POL	0x0002	/* Polarity changed		*/
#define	M88E1000_PISR_JAB	0x0001	/* Jabber			*/


/* Extended PHY Specific Control Register, (EPSCR) */

#define	M88E1000_EPSCR_REG	0x14
#define	M88E1000_EPSCR_LDONI	0x8000	/* Link Down On No Idle		*/
#define	M88E1000_EPSCR_TXCLK25	0x0070	/* 25 MHz TX CLK on no link	*/


/* PHY Receive Error Counter Register, (PRECR) */

#define	M88E1000_PRECR_REG	0x15


/* PHY Global Status Register, (PGSR) */

#define	M88E1000_PGSR_REG	0x17


/* PHY LED Control Register, (PLCR) */

#define	M88E1000_PLCR_REG	0x18


/* Extended PHY Specific Status Register, (EPSSR) */

#define	M88E1000_EPSSR_REG	0x1B
#define	M88E1000_EPSSR_


