/*==========================================================================
**
**	./pdk/src/drivers/sal/pdk_buf.h
**
**	System abstraction layer for Linux
**
**==========================================================================
**
**	(c) Copyright 1998 ZNYX Corporation
**	All Rights Reserved.
**
**==========================================================================
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**==========================================================================
**
**	david	02/24/99 	Created
**	jr	09/15/01	OA version, namespace cleanup
**				added pdk_dumpskb proto
**	jr	02/18/02	added pdk_buf_reserve()
**
**==========================================================================
**
**	Notes:
**
**==========================================================================
*/

/* Linux buffer strucutres */

#ifndef PDK_BUF_H
#define PDK_BUF_H

#include <linux/skbuff.h>
#include <linux/netdevice.h>
#include <asm/io.h>

#if LINUX_VERSION_CODE < 0x20159 
#define dev_free_skb(skb) dev_kfree_skb(skb, FREE_WRITE)
#else
#if LINUX_VERSION_CODE < 0x20400
#define dev_free_skb(skb) dev_kfree_skb(skb)
#else
#define dev_free_skb(skb) dev_kfree_skb_any(skb)
#endif
#endif

/* no mapping required by Linux */
#define pdk_map_t pdk_buf_t

/* RLK: buf_fragment() converts a bp with huge skb into a queue
of bp's each with a pointer into the original skb data area,
and pointer to a header area.
Each bp needs a *copy* of the header, because the len and cksum
could be different for each.  Any other reason?
A reference count would tell buf_free() (or xmit_complete)
when the original skb could be freed.
*/


typedef struct pdk_buf_s {
	struct pdk_buf_s	*b_link;
	int			b_type;
#define PDK_BUF_TX 0
#define PDK_BUF_RX 1
	int			b_ppa;
	struct sk_buff		*b_skb;
	uint32_t			b_len;
	dma_addr_t	b_padr;
	int	history;
} pdk_buf_t;

/* for bp history debug */
#define NEWRX	0
#define NEWTX	1
#define TXING	2
#define RXING	3
#define RXHAL	4
#define RXERR	5
#define	TXDONE	6
#define	RXDONE	7

#define PDK_BUF_RECV	PDK_BUF_RX
#define PDK_BUF_XMIT	PDK_BUF_TX

#define PDK_BUF_READ	PDK_BUF_RX
#define PDK_BUF_WRITE	PDK_BUF_TX

/* buffer function prototypes */
uint32_t pdk_buf_global_init();
uint32_t pdk_buf_global_deinit();
uint32_t pdk_buf_init(int32_t ppa);
uint32_t pdk_buf_deinit(int32_t ppa);

pdk_buf_t *pdk_buf_alloc(int32_t ppa, uint32_t size, struct sk_buff *skb);
void pdk_buf_free(pdk_buf_t *bp);

uchar *pdk_buf_rptr(pdk_buf_t *bp);

/* Not used, but if it were, which skb field should it be
 * in which Linux version?
 *
 * uchar *pdk_buf_wptr(pdk_buf_t *bp);
 */

uint32_t pdk_buf_movef_rptr(pdk_buf_t *bp, uint32_t len);
uint32_t pdk_buf_moveb_rptr(pdk_buf_t *bp, uint32_t len);
uint32_t pdk_buf_movef_wptr(pdk_buf_t *bp, uint32_t len);
uint32_t pdk_buf_moveb_wptr(pdk_buf_t *bp, uint32_t len);

/* skb_put(bp->b_skb, len), is similar to changing a b_wptr,
 * but it increments pointers, which would be hazardous if done twice.
 * Do the skb_put() in znb_recv_complete();
 *
 * if(len > bp->b_skb->len) skb_put(bp->b_skb, len - bp->b_skb->len)
 */
void pdk_buf_reserve(pdk_buf_t *bp, uint32_t len);
uint32_t pdk_buf_set_len(pdk_buf_t *bp, uint32_t len);
uint32_t pdk_buf_get_len(pdk_buf_t *bp);

pdk_buf_t *pdk_buf_link(pdk_buf_t *bp, pdk_buf_t *bp1);
pdk_buf_t *pdk_buf_pullup(pdk_buf_t *bp, uint32_t len);
uint32_t pdk_buf_copy(pdk_buf_t *fbp, pdk_buf_t *tbp);
uint32_t pdk_buf_contiguous(pdk_buf_t *bp, uint32_t flags, uchar *p, uint32_t *lenp);

pdk_map_t *pdk_buf_map(pdk_buf_t *bp, uint32_t flags, int32_t *errp);
void pdk_buf_unmap(pdk_buf_t *bp);
pdk_map_t *pdk_buf_get_pmap(pdk_map_t *mp, uint32_t *paddrp, uint32_t *lenp, int32_t *errp);


int32_t pdk_buf_receive_init(int32_t ppa);
int32_t pdk_buf_receive_deinit(int32_t ppa);

pdk_buf_t *pdk_buf_fragment(int32_t ppa, pdk_buf_t *bp, int32_t num_frags, int32_t frag_len, int32_t header_len);

void pdk_dumpskb(int ppa, char *id, pdk_buf_t *bp, struct sk_buff *skb);

#endif /* PDK_BUF_H */
