/*==========================================================================
**
**	znyx/psdb/psdb.h
**
**	Programmable Switch Database file format
**
**==========================================================================
**
**	(c) Copyright 1996, 1997 ZNYX Corporation
**	All Rights Reserved.
**
**==========================================================================
**
**	Modification History:
**	jr	06/25/96	Created.
**	ad	06/25/96	Added type codes and expanded structures
**	ad	06/26/96	Added IfNumber
**	ad	06/30/96	Added file name, PSDB_OSD, and comments
**	ad	07/03/96	Added SNMP objects
**	ad	07/04/96	Changed license key and added Reserved fields
**	jr	07/19/96	Changed PSDB_SNMP
**	jr	09/06/96	Added bridge configuration record type,
**				changed port configuration record
**	ad	09/10/96	Removed non-conventional defines
**	jr	04/13/97	Changed SNMP records, added port flags,
**				added ACCOUNT record
**	jr	05/06/97	Changed port configuration record,
**				added IP filter
**	jr	06/30/97	Moved IP filter record to experimental group,
**				modified SNMP trap record
**	jr	07/07/97	Deprecated ConnectedTo field
**	jr	07/11/97	Added definitions for special port record
**				values, new bridge _AF flag
**	jr	08/01/97	Moved FEC static set record to system group
**	jr	10/16/97	Changed license record to use OSD string
**				Added description record, enumerated busses
**
**==========================================================================
*/


#ifndef __PSDB_H__
#define __PSDB_H__

/* Octet String Descriptor */

typedef struct _PSDB_OSD {
	UINT32		Length;		/* Length of string incl. '\0' */
	UINT32		Offset;		/* Offset from start of record */
	} PSDB_OSD, *PPSDB_OSD;


/* The file header */

typedef struct _PSDB_FHDR {
	UCHAR		Signature[4];
	UINT32		Version;
	} PSDB_FHDR, *PPSDB_FHDR;

#define	PSDB_SIGNATURE	"PSDB"
#define	PSDB_VERSION1	1


/* The record header */

typedef struct _PSDB_RHDR {
	UINT32		Size;		/* Total size of rec in bytes	*/
	UINT32		Type;
	} PSDB_RHDR, *PPSDB_RHDR;

#define PSDB_CLASS_SYSTEM	0x10000
#define PSDB_CLASS_APP		0x20000
#define PSDB_CLASS_EXPERIMENTAL	0x30000
#define	PSDB_CLASS_STATUS	0x40000
#define PSDB_CLASS_PDK_RLK	0x50000
#define PSDB_CLASS_PDK_HAL	0x60000
#define PSDB_CLASS_PDK_PAL	0x70000
#define PSDB_CLASS_PDK_IO	0x80000
#define PSDB_RECORD_TYPE(C, T)	(C | T)

/* PSDB data byte order is opposite to network byte order */
#if (PDK_NETWORK_ORDER == 1234)
#    define psdb_pton(l) (((((uint32_t)(l))>>24&0xff))|((((uint32_t)(l))>>8)&0xff00)|((((uint32_t)(l))<<8)&0xff0000)|((((uint32_t)(l))<<24)&0xff000000))
#else
#    define psdb_pton(l) (l)
#endif /* PDK_NETWORK_ORDER */

#define psdb_ntop(l) psdb_pton(l)

/* License key record */

#define PSDB_TYPE_LIC		PSDB_RECORD_TYPE(PSDB_CLASS_SYSTEM, 1)
typedef struct _PSDB_LIC {
	PSDB_RHDR	Header;
	PSDB_OSD	Key;
	} PSDB_LIC, *PPSDB_LIC;


/* Port configuration record */

#define PSDB_TYPE_PORTCFG	PSDB_RECORD_TYPE(PSDB_CLASS_SYSTEM, 2)
typedef struct _PSDB_PORTCFG {
	PSDB_RHDR	Header;
	UINT32		BoardType;	/* ZNYX Constant defined in znyx/deviceid.h */
	UINT32		BusType;
	UINT32		SlotNumber;
	UINT32		BusNumber;
	UINT32		DeviceNumber;
	UINT32		UnitNumber;	/* PCI function or other subdivision */
	UINT32		MACType;
	UINT32		MediaType;	/* bit-map value defined below */
	UINT32		Unused;		/* was: ConnectedTo */
	UINT32		Priority;	/* 0 (high) to 255 (low), default 128 */
	UINT32		PortId;		/* e.g. unit ^ device*256 ^ bus*64k */
	UINT32		Flags;
	PSDB_OSD	Name;
	UINT32		Reserved[4];
	} PSDB_PORTCFG, *PPSDB_PORTCFG;

#define	PSDB_PORTCFG_OLDSIZE	60

/* Bus Type Values */

#define PSDB_BUSTYPE_UNKNOWN		0
#define PSDB_BUSTYPE_PCI		1
#define	PSDB_BUSTYPE_ISA		2
#define PSDB_BUSTYPE_EISA		3
#define PSDB_BUSTYPE_MCA		4

/* Some special values */

#define	PSDB_PORTCFG_UNKNOWN_SLOT	0
#define	PSDB_PORTCFG_LOCAL_BUS		0xFFFFFFFF
#define	PSDB_PORTCFG_ENUMERATED_BUS	0x80000000
#define	PSDB_PORTCFG_FIRST_UNIT		0

/* MACType Values */

#define PSDB_MACTYPE_UNKNOWN		0
#define PSDB_MACTYPE_ETHERNET		1

/* MediaType values (combined bits) */

#define PSDB_MEDIATYPE_AUTONEGOTIATE	0x00000001
#define PSDB_MEDIATYPE_AUTOSENSE	0x00000002
#define PSDB_MEDIATYPE_AUI		0x00000004
#define PSDB_MEDIATYPE_10BASE2		0X00000008
#define PSDB_MEDIATYPE_10BASET		0x00000010
#define PSDB_MEDIATYPE_10BASETFD	0x00000020
#define PSDB_MEDIATYPE_100BASETX	0x00000040
#define PSDB_MEDIATYPE_100BASETXFD	0x00000080
#define PSDB_MEDIATYPE_100BASET4	0x00000100
#define PSDB_MEDIATYPE_OTHER		0x80000000

/* ConnectedTo values */

#ifdef NEED_PSDB_CONNECTEDTO
#define PSDB_CONNECTEDTO_UNKNOWN	0
#define PSDB_CONNECTEDTO_SINGLENODE	1
#define PSDB_CONNECTEDTO_HUBREPEATER	2
#define PSDB_CONNECTEDTO_SWITCH		3
#define PSDB_CONNECTEDTO_PCISWITCH	4
#define PSDB_CONNECTEDTO_OTHER		5
#endif

/* PortId reserved values */

#define	PSDB_PORTID_HOST		0
#define	PSDB_PORTID_MGMT		1
#define	PSDB_PORTID_ANY			0xFFFFFFFF
#define	PSDB_PORTID_REAL_MIN		0x100		/* 2 - 255 reserved */
#define	PSDB_PORTID_REAL_MAX		0xFFFFFFFE	/* (-1) reserved */

/* Flags values (combined bits) */

#define PSDB_PORTCFG_ENABLED		0x00000001
#define PSDB_PORTCFG_LINKTRAPS		0x00000002
#define PSDB_PORTCFG_SPANTREE		0x00000004
#define PSDB_PORTCFG_CLCP		0x00000008


/* System description record */

#define PSDB_TYPE_SYSTEM	PSDB_RECORD_TYPE(PSDB_CLASS_SYSTEM, 3)
typedef struct _PSDB_SYSTEM {
	PSDB_RHDR	Header;
	PSDB_OSD	Description;		/* sysName */
	PSDB_OSD	Location;		/* sysLocation */
	PSDB_OSD	Person;			/* sysContact */
	} PSDB_SYSTEM, *PPSDB_SYSTEM;


/* IP configuration record */

#define PSDB_TYPE_IPCFG		PSDB_RECORD_TYPE(PSDB_CLASS_SYSTEM, 4)
typedef struct _PSDB_IPCFG {
	PSDB_RHDR	Header;
	UINT32		IfNumber;		/* interface instance */
	UINT32		IpAddress;
	UINT32		IpNetMask;
	UINT32		IpBroadcast;
	UINT32		IpGateway;
	UINT32		IpFlags;
	UINT32		Reserved;
	} PSDB_IPCFG, *PPSDB_IPCFG;

/* Some IpFlags values */

#define	PSDB_IPCFG_RARP		0x01
#define	PSDB_IPCFG_BOOTP	0x02
#define	PSDB_IPCFG_DHCP		0x04


/* SNMP Community records */

#define PSDB_TYPE_SNMPC		PSDB_RECORD_TYPE(PSDB_CLASS_SYSTEM, 5)
typedef struct _PSDB_SNMPC {
	PSDB_RHDR	Header;
	PSDB_OSD	Community;		/* community name */
	UINT32		Protocol;		/* protocol type */
	UINT32		IpAddress;		/* address */
	UINT32		AddressExt;
	UINT32		IpMask;			/* mask */
	UINT32		Flags;			/* flags */
	UINT32		Reserved;
	} PSDB_SNMPC, *PPSDB_SNMPC;

/* SNMP community protocols */

#define	PSDB_SNMPC_PROT_IP	0
#define	PSDB_SNMPC_PROT_IPX	1

/* SNMP community flags */

#define PSDB_SNMPC_FLAGS_WA	0x00000001	/* read-write access */


/* SNMP Trap records */

#define PSDB_TYPE_SNMPTRAP	PSDB_RECORD_TYPE(PSDB_CLASS_SYSTEM, 6)
typedef struct _PSDB_SNMPTRAP {
	PSDB_RHDR	Header;
	PSDB_OSD	Community;		/* name of community */
	UINT32		Protocol;
	UINT32		IpAddress;		/* where to send traps */
	UINT32		AddressExt;
	UINT32		AddressExt2;
	UINT32		Type;
	UINT32		Flags;
	UINT32		Reserved;
	} PSDB_SNMPTRAP, *PPSDB_SNMPTRAP;

/* SNMP trap protocols */

#define	PSDB_SNMPTRAP_PROT_IP	0
#define	PSDB_SNMPTRAP_PROT_IPX	1

/* SNMP trap types */

#define	PSDB_SNMPTRAP_TYPE_ALL		0xFFFFFFFF
#define	PSDB_SNMPTRAP_TYPE_SYSTEM	0x00001
#define	PSDB_SNMPTRAP_TYPE_LINK		0x00002
#define	PSDB_SNMPTRAP_TYPE_AUTH		0x00004


/* Bridge configuration record */

#define PSDB_TYPE_BRIDGECFG	PSDB_RECORD_TYPE(PSDB_CLASS_SYSTEM, 7)
typedef struct _PSDB_BRIDGECFG {
	PSDB_RHDR	Header;
	UINT32		Flags;		/* See below */
	UINT32		FilterTime;	/* Filter ageing in seconds	*/
	UINT32		Priority;	/* 0(high) - 65535(low), default 32768 */
	UINT32		HelloTime;	/* Time in seconds or 1/256s	*/
	UINT32		MaxAge;		/* Time in seconds or 1/256s	*/
	UINT32		ForwardDelay;	/* Time in seconds or 1/256s	*/
	UINT32		Reserved;
	} PSDB_BRIDGECFG, *PPSDB_BRIDGECFG;

/* Bridge configuration flags */

#define	PSDB_BRIDGECFG_STP		0x0001	/* 802.1D enable	*/
#define	PSDB_BRIDGECFG_STP_TRAPS	0x0002	/* Spanning tree traps	*/
#define	PSDB_BRIDGECFG_STP_HIRES	0x0004	/* Times in 1/256 sec	*/
#define	PSDB_BRIDGECFG_STP_AF		0x0008	/* Accelerated fail-over*/


/* Account record */

#define PSDB_TYPE_ACCOUNT	PSDB_RECORD_TYPE(PSDB_CLASS_SYSTEM, 8)
typedef struct _PSDB_ACCOUNT {
	PSDB_RHDR	Header;
	PSDB_OSD	Name;
	UINT32		Auth[4];
	UINT32		Flags;
	UINT32		Reserved;
	} PSDB_ACCOUNT, *PPSDB_ACCOUNT;


/* IP filter configuration record */

/* The IP filter record type will be (SYSTEM, 9) */


/* Fast Etherchannel Static Set configuration record */

#define PSDB_TYPE_FECSS	PSDB_RECORD_TYPE(PSDB_CLASS_SYSTEM, 10)
typedef struct _PSDB_FECSS {
	PSDB_RHDR	Header;
	UINT32		Method;
	UINT32		PortCount;
	UINT32		PortId[8];
	UINT32		Flags;
	UINT32		Reserved;
	} PSDB_FECSS, *PPSDB_FECSS;

/* Flags */

#define	PSDB_FECSS_METHOD_SD	1	/* Use source/dest addresses */
#define	PSDB_FECSS_METHOD_L3P	2	/* Use layer 3 protocols */
#define	PSDB_FECSS_METHOD_CON	4	/* Use connections */


/* Database description record */

#define PSDB_TYPE_DBDESC	PSDB_RECORD_TYPE(PSDB_CLASS_SYSTEM, 11)
typedef struct _PSDB_DBDESC {
	PSDB_RHDR	Header;
	PSDB_OSD	Text;
	} PSDB_DBDESC, *PPSDB_DBDESC;


#endif

