/*==========================================================================
**
**      ./hal/zvsi.h
**
**	ZNYX Very Simple Interface
**
**==========================================================================
**
**      (c) Copyright 1998, 1999 ZNYX Corporation
**      All Rights Reserved.
**
**==========================================================================
**
**	Alan Deikman 99/05
**
**      Modification History:
**
**	ad	05/26/99	Original 
**	ad	06/29/99 	Added definitions, changed typedefs, added
**				memory map
**	ad	07/13/99 	Changed from ORCA to QuickLogic base
**				Added SEEQ stuff
**	ad	07/26/99 	Added CSR_MODE bits
**	ad	07/30/99 	Added MODE_TCQ and MODE_RCQ
**	ad	11/08/99 	Changed as per hw eng suggestions
**	ad	01/25/00 	Added RBD limit, Flash access, and FPGA access
**	jp	02/03/00 	added index values for TI flags
**	nap	02/21/00 	Updated to match "zvsi.v" from verilog FPGA
**				source code.
**	nap	03/22/00 	Added a failure bit to the status/IMR register.
**	jwp	03/23/00 	Added RCQ flag bit defines
**	nap	03/27/00 	Swapped the values of FLASHA and FLASHD.
**	jwp	03/28/00 	added union for TI struct
**	jwp	03/28/00 	added union for RBD struct
**	nap	03/30/00 	Removed bogus FPGA masks.
**	nap	04/12/00 	Added ZI_FLASH_SIZE
**	nap	04/25/00 	Added AUTO_TX register.
**	nap	06/07/00 	Changed DEVICEID.
**	nap	06/22/00 	Added some configuration bits for programming
**				the xilinx devices.
**	ram	08/10/00	Formatting changes to look like PDK
**
**==========================================================================
*/
#ifndef ZVSI_H
#define ZVSI_H

/* Global Defines */

#define ZI_VALUE_VENDORID	0x110D	/* ZNYX Vendor ID */
#define ZI_VALUE_DEVICEID	0x002a	/* ZVSI Device ID */
#define ZI_VALUE_REVISION	0x01	/* Revision code in PCI config space */
#define ZI_VALUE_CLASS		0x20000	/* Class Code */
#define ZI_VALUE_INTPIN		0x01	/* Interrupt pin */

#define ZI_BAR0_ADDR_BITS	19
/* Total memory footprint size */
#define ZI_SIZE_BAR0		(1 << ZI_BAR0_ADDR_BITS)

#define ZI_BASE_CSR		0x00200	/* Offset of CSR Window */
#define ZI_BASE_MAC		0x20000	/* Offset of MAC Device Buffer Window */
#define ZI_BASE_TIPW		0x40000	/* Offset of TI Posting Window */
#define ZI_BASE_RBDW		0x60000	/* Offset of RBD Posting Window */

#define ZI_SIZE_TIFIFO		32768	/* Size of TIQ (FIFO) in bytes */
#define ZI_SIZE_RBDFIFO		32768	/* Size of RBDQ (FIFO) in bytes */

#define ZI_MAX_RBATCHDLY	255	/* Maximum value of CSR_RBATCHDLY */
#define ZI_MAX_RGAPDLY		1023	/* Maximum value of CSR_RGAPDLY */
#define ZI_MAX_RMAXDLY		1023	/* Maximum value of CSR_RMAXDLY */

#define ZI_TIME_RGAPDLY_NS	100	/* CSR_RGAPDLY units in nanoseconds */
#define ZI_TIME_RMAXDLY_NS	400	/* CSR_RMAXDLY units in nanoseconds */

 /* PCI Configuration Space Offsets */

#define ZI_CFG_VENDORID		0x00	/* PCI Vendor ID */
#define ZI_CFG_DEVICEID		0x02	/* PCI Device ID */
#define ZI_CFG_COMMAND		0x04	/* Command Register */
#define ZI_CFG_STATUS		0x06	/* Status Register */
#define ZI_CFG_REVISION		0x08	/* Revision (ZI_REVISION) */
#define ZI_CFG_CLASSCODE	0x09	/* Device Class (ZI_PCITYPE) */
#define ZI_CFG_CACHELINE	0x0C	/* Cache Line Size */
#define ZI_CFG_LATENCY		0x0D	/* Latency Counter */
#define ZI_CFG_HEADERTYPE	0x0E	/* Header Type (0x00) */
#define ZI_CFG_BIST		0x0F	/* Built-in Self-test (0x00) */
#define ZI_CFG_BAR0		0x10	/* Base Address Register (64-bit) */
#define ZI_CFG_SUBVENDORID	0x2C	/* Sub-Vendor Vendor ID */
#define ZI_CFG_SUBDEVICEID	0x2E	/* Sub-Vendor Device ID */
#define ZI_CFG_ROMBAR		0x30	/* BAR for Expansion ROM */
#define ZI_CFG_INTLINE		0x3C	/* Interupt Line */
#define ZI_CFG_INTPIN		0x3D	/* Interrupt Pin (0x01) */
#define ZI_CFG_MINGNT		0x3E	/* Minimum Grant Time (0x00) */
#define ZI_CFG_MAXLAT		0x3F	/* Maximum Latency Timer (0x00) */

/* Receive Buffer Descriptor */

typedef struct {
	uint16_t	zrd_flags;		/* Flag bits */
	uint16_t	zrd_length;		/* Length Field */
	uint32_t	zrd_handle;		/* Driver-value */
	uint32_t	zrd_low_address;	/* Low 32-bit address bits */
	uint32_t	zrd_hi_address;		/* High 32-bit address bits */
} zi_rxbd_t;

typedef struct {
	uint32_t	fl_first;
	uint32_t	fl_second;
	uint32_t	fl_third;
	uint32_t	fl_fourth;
} fourlongs_t;

typedef union {
	zi_rxbd_t	rl_rbd;
	fourlongs_t	rl_ilongs;
} rbd_long_t;

/* limit constant */

#define ZI_RXBD_LENGTH_MAX	4096	/* Receive buffers max size */

/* values for ZI_RXBD.Flags */

#define ZI_RXBD_FLAGS_IOU	0x8000	/* Interrupt when used */
#define ZI_RXBD_FLAGS_CQ	0x4000	/* Write completion queue when used */
#define ZI_RXBD_FLAGS_NSF	0x2000	/* Skip if not used for frame start */

/* Receive Completion Queue Entry */

typedef struct {
	uint16_t	rcq_length;	/* Number of bytes used */
	uint16_t	rcq_flags;	/* Status Flags */
	uint32_t	rcq_handle;	/* Handle from Buffer Descriptor */
} zi_rcq_t;

/* values for ZI_RBDQ.Flags */

#define ZI_RCQ_FLAGS_SF_BIT	0	/* Buffer contains start of frame */
#define ZI_RCQ_FLAGS_EF_BIT	1	/* Buffer contains end of frame */
#define ZI_RCQ_FLAGS_FCS_BIT	2	/* Frame Checksum Error */
#define ZI_RCQ_FLAGS_SHORT_BIT	3	/* Frame shorter than standard */
#define ZI_RCQ_FLAGS_LONG_BIT	4	/* Frame longer than standard */
#define ZI_RCQ_FLAGS_ERR_BIT	5	/* Other Frame Error */
#define ZI_RCQ_FLAGS_SF		(0x0001 << ZI_RCQ_FLAGS_SF_BIT)	
#define ZI_RCQ_FLAGS_EF		(0x0001 << ZI_RCQ_FLAGS_EF_BIT)	
#define ZI_RCQ_FLAGS_FCS	(0x0001 << ZI_RCQ_FLAGS_FCS_BIT)
#define ZI_RCQ_FLAGS_SHORT	(0x0001 << ZI_RCQ_FLAGS_SHORT_BIT)
#define ZI_RCQ_FLAGS_LONG	(0x0001 << ZI_RCQ_FLAGS_LONG_BIT)
#define ZI_RCQ_FLAGS_ERR	(0x0001 << ZI_RCQ_FLAGS_ERR_BIT)

/* Transmit Instruction */

typedef struct {
	uint16_t	ti_instruction;		/* Instruction Opcode */
	uint16_t	ti_flags;		/* Flag bits */
	uint16_t	ti_length;		/* Length of buffer or data */
	uint16_t	ti_handle;		/* Host driver defined value */
} zi_ti_t;

typedef struct {
	uint32_t	tl_first;
	uint32_t	tl_second;
} twolongs_t;

typedef union {
	zi_ti_t		til_ti;
	twolongs_t	til_ilongs;
} ti_long_t;

/* Transmit Opcodes */

#define ZI_TI_DATA	0x0001	/* Transmit Data immediate */
#define ZI_TI_X32	0x0002	/* Transmit Data from 32-bit address */
#define ZI_TI_X64	0x0003	/* Transmit Data from 64-bit address */

/* Transmit Flags */

#define ZI_TI_FLAG_SF_BIT	0	/* Start of Frame */
#define ZI_TI_FLAG_EF_BIT	1	/* End of Frame */
#define ZI_TI_FLAG_RAW_BIT	2	/* Send Raw (no FCS) */
#define ZI_TI_FLAG_CQ_BIT	3	/* Write Completion Queue */
#define ZI_TI_FLAG_INT_BIT	4	/* Interrupt when complete */
#define ZI_TI_FLAG_SF		(0x0001 << ZI_TI_FLAG_SF_BIT)
#define ZI_TI_FLAG_EF		(0x0001 << ZI_TI_FLAG_EF_BIT)
#define ZI_TI_FLAG_RAW		(0x0001 << ZI_TI_FLAG_RAW_BIT)
#define ZI_TI_FLAG_CQ		(0x0001 << ZI_TI_FLAG_CQ_BIT)
#define ZI_TI_FLAG_INT		(0x0001 << ZI_TI_FLAG_INT_BIT)

/* Transmit Completion Queue Entry */

typedef struct {
	uint16_t	tcq_handle;	/* Handle from TI */
	uint16_t	tcq_status;	/* Status Flags */
} zi_tcq_t;

/* values for ZI_TCQ.Status */

#define ZI_TCQ_STATUS_OK	0x0001	/* Frame transmitted normally */
#define ZI_TCQ_STATUS_ERR	0x0002	/* Some Error happened on transmit */

/* ********************************************************************* */
/* Control/Status Register offsets */
/* ********************************************************************* */

#define ZI_CSR_CONTROL		(ZI_BASE_CSR+0x04) /* Control Register */
#define ZI_CSR_MODE		(ZI_BASE_CSR+0x0c) /* Mode Register */
#define ZI_CSR_SROM		(ZI_BASE_CSR+0x14) /* SROM access register */
#define ZI_CSR_FPGA 		(ZI_BASE_CSR+0x1c) /* FPGA Programming Port */
#define ZI_CSR_FLASHA		(ZI_BASE_CSR+0x24) /* Flash ROM Address */
#define ZI_CSR_FLASHD		(ZI_BASE_CSR+0x2c) /* Flash ROM Data */
#define ZI_CSR_STATUS		(ZI_BASE_CSR+0x44) /* Status Bits Register */
#define ZI_CSR_IMR		(ZI_BASE_CSR+0x4C) /* Interrupt Mask Register */
#define ZI_CSR_TCQBASE_LOW	(ZI_BASE_CSR+0x54) /* TCQ Base low 32-bits */
#define ZI_CSR_TCQBASE_HIGH	(ZI_BASE_CSR+0x5c) /* TCQ Base high 32-bits */
#define ZI_CSR_TCQMASK		(ZI_BASE_CSR+0x64) /* Size mask of TCQ */
#define ZI_CSR_TCQNEXT		(ZI_BASE_CSR+0x6c) /* Next TCQ entry to write */

/* Last transmit handle who's PCI data transfer has completed */
#define ZI_CSR_TCQLAST_HANDLE	(ZI_BASE_CSR+0x74)
#define ZI_CSR_RCQBASE_LOW	(ZI_BASE_CSR+0x7c) /* RCQ Base low 32-bits */
#define ZI_CSR_RCQBASE_HIGH	(ZI_BASE_CSR+0x84) /* RCQ Base high 32-bits */
#define ZI_CSR_RCQMASK		(ZI_BASE_CSR+0x8c) /* Size mask of RCQ */
#define ZI_CSR_RCQNEXT		(ZI_BASE_CSR+0x94) /* Next RCQ entry to write */
	/* Last receive handle who's PCI data transfer has completed */
#define ZI_CSR_RCQLAST_HANDLE	(ZI_BASE_CSR+0x9c)
	/* Address of host-copy CSR_STATUS low 32-bits */
#define ZI_CSR_STATUSADDR_LOW	(ZI_BASE_CSR+0xa4)
	/* Address of host-copy CSR_STATUS high 32-bits */
#define ZI_CSR_STATUSADDR_HIGH	(ZI_BASE_CSR+0xac)
	/* Delay RCV interrupt number of frames */
#define ZI_CSR_RBATCHDLY	(ZI_BASE_CSR+0xb4)
#define ZI_CSR_RGAPDLY		(ZI_BASE_CSR+0xbc) /* Delay RCV interrupt gap */
#define ZI_CSR_RMAXDLY		(ZI_BASE_CSR+0xc4) /* RCV Maximum delay */
	/* Automatic Transmit packet generation */
#define ZI_CSR_AUTO_TX		(ZI_BASE_CSR+0xcc)
#define ZI_CSR_TX_STATE 	(ZI_BASE_CSR+0xd4)
#define ZI_CSR_FPGA_VERSION 	(ZI_BASE_CSR+0xdc)
#define ZI_CSR_MODE2	 	(ZI_BASE_CSR+0xec)
/* ********************************************************************* */
/* Bit locations for CSRs */
/* ********************************************************************* */

/* bits in CSR_CONTROL */

#define ZI_CONTROL_RESET	0x00000001	/* Perform firm reset */

/* bits in ZI_CSR_STATUS and ZI_CSR_IMR */

#define ZI_STATUS_RCV		0x00000001	/* Frame received */
#define ZI_STATUS_RCVGAP	0x00000002	/* Receive gap was detected */
#define ZI_STATUS_XMT		0x00000004	/* Frame transmitted */
#define ZI_STATUS_EXT		0x00000008	/* External device interrupt */
#define ZI_STATUS_RCVERR	0x00000010	/* Receive error */
#define ZI_STATUS_TXERR		0x00000020	/* Transmit error */
#define ZI_STATUS_TIFIFO	0x00000040	/* TI FIFO Overflow */
#define ZI_STATUS_RBDFIFO	0x00000080	/* RBD FIFO Empty */
#define ZI_STATUS_FAILURE	0x00000100	/* Unrecoverable failure */

/* bits in CSR_MODE */

#define ZI_MODE_TEST		0x00000001	/* Test mode bit */

/* bits in CSR_SROM */

#define ZI_SROM_LED0		0x00000001	/* LED 0 */
#define ZI_SROM_LED1		0x00000002	/* LED 1 */
#define ZI_SROM_CLOCK		0x00000100	/* Serial ROM clock. */
#define ZI_SROM_DATAIN		0x00000400	/* Serial ROM data in. */
#define ZI_SROM_DATAOUT		0x00000200	/* Serial ROM data out. */

/* bits in CSR_TCQBASE_LOW */

#define ZI_TCQBASE_ENABLE	0x00000001	/* enable TCQ memory writing */

/* bits in CSR_RCQBASE_LOW */

#define ZI_RCQBASE_ENABLE	0x00000001	/* enable RCQ memory writing */

/* bits in CSR_STATUSADDR_LOW */

#define ZI_STATUSADDR_ENABLE	0x00000001	/* enable STATUS memory writing */

/* Removed 8101 Registers */

	// **************************************
	// ql5064 bit indexes into FPGACONFIG register
	// **************************************
/* bits in CSR_FPGA */

#define ZI_FPGACONFIG_DATA 0
#define ZI_FPGACONFIG_CCLK 8
#define ZI_FPGACONFIG_PROGRAM 9
#define ZI_FPGACONFIG_INIT 10
#define ZI_FPGACONFIG_DONE 11
#define ZI_FPGACONFIG_FPGADISABLE 12

#define ZI_FPGACONFIG_JENABLE 16
#define ZI_FPGACONFIG_JTDI 17
#define ZI_FPGACONFIG_JTCK 18
#define ZI_FPGACONFIG_JTMS 19
#define ZI_FPGACONFIG_JTDO 20

#define ZI_FLASH_SIZE (512*1024)

/* bits in CSR_MODE2 */
#define ZI_MODE2_LED_OFF	0x0
#define ZI_MODE2_LED_ON		0x2

/* end of zvsi.h */

#endif
