/*==========================================================================
**
**	./pdk/src/drivers/pal/rmapi.c
**
**	PAL RMAPI Routines for IOCTL based interfaces
**
**==========================================================================
**
**	(c) Copyright 1998 ZNYX Corporation
**	All Rights Reserved.
**
**==========================================================================
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**==========================================================================
**
**	Modification History:
**	Tim Hayes tim.hayes@znyx.com Spring 2K
**
**==========================================================================
**
**	Notes:
**==========================================================================
*/
#include <pdk_port.h>
#include <pdk_global.h>
#include <pdk_types.h>
#include <pdk_pal.h>
#include <pdk_constant.h>
#include <pdk_errno.h>
#include <pdk_print.h>
#include <pdk_queue.h>
#include <pdk_psdb.h>
#include <pdk_linux.h>
#include <pdk_hal.h>
#include <pdk_rlk.h>

#include <pio.h>

#ifndef STATIC
#define STATIC 
#endif

extern int zxe_debug;
#define DEBUG1 if (zxe_debug>0) pdk_print
#define DEBUG2 if (zxe_debug>1) pdk_print
#define DEBUG3 if (zxe_debug>2) pdk_print
#define DEBUG4 if (zxe_debug>3) pdk_print

typedef struct rmapi_znb_s {
	int32_t		pz_trunk_built;
	int32_t		pz_trunk_ppa;
	int32_t		pz_is_trunk_member;
	int32_t		pz_failover_built;
	int32_t		pz_failover_ppa;
	int32_t		pz_is_failover_member;
} rmapi_znb_t;

rmapi_znb_t rmapi_znb_array[NUM_PORTS];

void rmapi_write(int32_t stream_handle, pdk_psdb_rhdr_t *record);
int32_t rmapi_pal_write(int32_t stream_handle, uint32_t record_type, pdk_psdb_rhdr_t *record);
int32_t rmapi_rlk_write(uint32_t record_type, pdk_psdb_rhdr_t *record);
int32_t rmapi_hal_write(uint32_t record_type, pdk_psdb_rhdr_t *record);

void rmapi_psdb_error(int32_t stream_handle, uint32_t dev_id, uint32_t error_type, uint32_t error);
void rmapi_psdb_success(int32_t stream_handle, uint32_t dev_id, uint32_t success_type);
uint32_t rmapi_create_trunk(int32_t trunk_ppa, int32_t num_ppa, int32_t *ppa_array);
uint32_t rmapi_create_failover(int32_t failover_ppa, int32_t num_ppa, int32_t *ppa_array);
uint32_t rmapi_teardown_trunk(int32_t ppa);
uint32_t rmapi_teardown_failover(int32_t ppa);
int32_t rmapi_zrl_ppa_to_znb_ppa(int32_t zrl_ppa, int32_t pc_type);
int32_t rmapi_znb_ppa_to_zrl_ppa(int32_t znb_ppa);

void
rmapi_notification(record)
pdk_psdb_rhdr_t *record;
{
	int32_t ppa;
	uint32_t record_type;

	/* Reverse the translation */
	record_type = psdb_pton(record->ppr_header.Type);

	if ((record_type&0xffff0000) == PSDB_CLASS_PDK_RLK) {
		ppa = rmapi_znb_ppa_to_zrl_ppa(psdb_pton(record->ppr_ppa));
		record->ppr_dev_id = psdb_ntop(ppa);
	}

	pio_notification(record);
}

void
rmapi_write(stream_handle, record)
int32_t stream_handle;
pdk_psdb_rhdr_t *record;
{
	uint32_t record_type;
	uint32_t dev_id;
	int32_t err;

	/* this is temporary workaround need inline code */
	record_type = psdb_pton(record->ppr_header.Type);
	dev_id = psdb_pton(record->ppr_dev_id);

	DEBUG2("rmapi_write: type 0x%x of len %d\n", record_type, psdb_pton(record->ppr_header.Size));

	err = 0;
	switch (record_type&0xffff0000) {
		case PSDB_CLASS_PDK_PAL:
			err = rmapi_pal_write(stream_handle, record_type, record);
			break;

		case PSDB_CLASS_PDK_RLK:
			err = rmapi_rlk_write(record_type, record);
			break;

		case PSDB_CLASS_PDK_HAL:
			err = rmapi_hal_write(record_type, record);
			break;
	
		default:
			DEBUG1("rmapi_write: Unkown PSDB Class 0x%x\n", (record_type>>16)&0xffff);
			err = PSDB_BAD_PARAM;
			break;
	}

	if (err) {
		rmapi_psdb_error(stream_handle, dev_id, record_type, err);
		return;
	}

	rmapi_psdb_success(stream_handle, dev_id, record_type);

	if (PSDB_READ_FLAG(record_type))
		pio_deliver(stream_handle, record);
}

int32_t
rmapi_pal_write(stream_handle, record_type, record)
int32_t stream_handle;
uint32_t record_type;
pdk_psdb_rhdr_t *record;
{
	int32_t dev_id;
	uint32_t err;

	DEBUG2("rmapi_pal_write: type 0x%x of len %d\n", record_type, psdb_pton(record->ppr_header.Size));

	err = 0;
	dev_id = psdb_pton(record->ppr_dev_id);

	switch (record_type) {
		case PSDB_TYPE_PAL_SET_MODE: {
			pdk_psdb_pal_set_mode_t *ppsmp;

			ppsmp = (pdk_psdb_pal_set_mode_t *) record;

			err = pio_set_mode(stream_handle, psdb_pton(ppsmp->ppsm_mode), psdb_pton(ppsmp->ppsm_signal));

			break;
		}

		case PSDB_TYPE_PAL_CLEAR_MODE: {
			pdk_psdb_pal_clear_mode_t *ppcmp;

			ppcmp = (pdk_psdb_pal_clear_mode_t *) record;
			err = pio_clear_mode(stream_handle, psdb_pton(ppcmp->ppcm_mode));

			break;
		}

		default:
			err = pdk_pal_ctl(dev_id, PDK_PSDB_INLINE, record);
			break;
	}

	return(err);
}

int32_t
rmapi_rlk_write(record_type, record)
uint32_t record_type;
pdk_psdb_rhdr_t *record;
{
	uint32_t ppa, dev_id;
	uint32_t err;

	DEBUG2("rmapi_rlk_write: type 0x%x of len %d\n", record_type, psdb_pton(record->ppr_header.Size));

	err = 0;
	dev_id = psdb_pton(record->ppr_dev_id);

	ppa = rmapi_zrl_ppa_to_znb_ppa(dev_id, 0);

	switch (record_type) {
		case PSDB_TYPE_CONFIGURATION: {
			pdk_psdb_configuration_t *pcp;
	
			pcp = (pdk_psdb_configuration_t *) record;
			if (psdb_pton(pcp->pc_ppa) != -1)
				ppa = psdb_pton(pcp->pc_ppa);

			if ((ppa >= NUM_PORTS) || (zxe_array[ppa] == 0))
				err = PSDB_BAD_DEVICE_ID;


			break;
		}
		case PSDB_TYPE_CREATE_TRUNK: {
			pdk_psdb_create_trunk_t *pctp;

			pctp = (pdk_psdb_create_trunk_t *) record;

			if (ppa != -1) {
				err = PSDB_BAD_DEVICE_ID;
				break;
			}

			err = rmapi_create_trunk(dev_id, psdb_pton(pctp->pct_num_ppa), (int32_t *) pctp->pct_ppa_array);

			ppa = rmapi_zrl_ppa_to_znb_ppa(dev_id, 0);
			break;

		}
		case PSDB_TYPE_CREATE_FAILOVER: {
			pdk_psdb_create_failover_t *pcfp;

			pcfp = (pdk_psdb_create_failover_t *) record;

			if (ppa != -1)
				ppa = rmapi_zrl_ppa_to_znb_ppa(dev_id, PSDB_CONFIG_FAILOVER_TYPE);
			if (ppa != -1) {
				err = PSDB_BAD_DEVICE_ID;
				break;
			}

			err = rmapi_create_failover(dev_id, psdb_pton(pcfp->pcf_num_ppa), (int32_t *) pcfp->pcf_ppa_array);

			ppa = rmapi_zrl_ppa_to_znb_ppa(dev_id, 0);
			break;
		}
		case PSDB_TYPE_TEARDOWN_TRUNK:
			err = rmapi_teardown_trunk(ppa);
			break;

		case PSDB_TYPE_TEARDOWN_FAILOVER:
			err = rmapi_teardown_failover(ppa);
			break;

		default:
			break;
	}

	if (err != 0)
		return(err);

	if (ppa == -1) {
		return(PSDB_BAD_DEVICE_ID);
	}

	record->ppr_ppa = psdb_ntop(ppa);

	err = pdk_rlk_ctl(ppa, PDK_PSDB_INLINE, record);

	if (err != 0) {
		switch(record_type) {
			case PSDB_TYPE_CREATE_TRUNK:
				rmapi_teardown_trunk(ppa);
				break;

			case PSDB_TYPE_CREATE_FAILOVER:
				rmapi_teardown_failover(ppa);
				break;

			default:
				break;
		}
		return(err);
	}

	if (record_type == PSDB_TYPE_CONFIGURATION) {
		/* mp contains the configuration data from the INLINE call */
		/* Reverse the dev_id to ppa translation */
		ppa = rmapi_znb_ppa_to_zrl_ppa(dev_id);
		record->ppr_dev_id = psdb_ntop(ppa);
	}

	return(0);

}

int32_t
rmapi_hal_write(record_type, record)
uint32_t record_type;
pdk_psdb_rhdr_t *record;
{
	int32_t record_size;
	uint32_t ppa;
	uint32_t err;

	DEBUG2("rmapi_hal_write: type 0x%x of len %d\n", record_type, psdb_pton(record->ppr_header.Size));

	record_size = psdb_pton(record->ppr_header.Size);

	ppa = psdb_pton(record->ppr_ppa);

	if (ppa == -1)
		return(PSDB_BAD_DEVICE_ID);

	err = pdk_hal_ctl(ppa, PDK_PSDB_INLINE, record);

	return(err);
}

void
rmapi_psdb_success(stream_handle, dev_id, success_type)
int32_t stream_handle;
uint32_t dev_id;
uint32_t success_type;
{
	pdk_psdb_success_t ps;

	ps.ps_header.ppr_header.Size = psdb_ntop(sizeof(pdk_psdb_success_t));
	ps.ps_header.ppr_header.Type = psdb_ntop(PSDB_TYPE_SUCCESS);
	ps.ps_header.ppr_dev_id = psdb_ntop(dev_id);
	ps.ps_success_type = psdb_ntop(success_type);

	pio_deliver(stream_handle, (pdk_psdb_rhdr_t *) &ps);

	return;
}

void
rmapi_psdb_error(stream_handle, dev_id, error_type, error)
int32_t stream_handle;
uint32_t dev_id;
uint32_t error_type;
uint32_t error;
{
	pdk_psdb_error_t pe;

	pe.pe_header.ppr_header.Size = psdb_ntop(sizeof(pdk_psdb_error_t));
	pe.pe_header.ppr_header.Type = psdb_ntop(PSDB_TYPE_ERROR);
	pe.pe_header.ppr_dev_id = psdb_ntop(dev_id);
	pe.pe_error_type = psdb_ntop(error_type);
	pe.pe_error = psdb_ntop(error);

	pio_deliver(stream_handle, (pdk_psdb_rhdr_t *) &pe);

	return;
}

uint32_t
rmapi_create_trunk(trunk_ppa, num_ppa, ppa_array)
int32_t trunk_ppa;
int32_t num_ppa;
int32_t *ppa_array;
{
	rmapi_znb_t *pzp;
	int32_t i, ppa;
	int32_t lowest_ppa = NUM_PORTS;

	DEBUG2("rmapi_create_trunk(%d)\n", trunk_ppa);

	if (num_ppa >= NUM_PORTS)
		return(PSDB_BAD_PARAM);

	for (i=0;i<num_ppa;i++) {
		ppa = psdb_pton(ppa_array[i]);
		if ((ppa >= NUM_PORTS) || (pdk_pal_ctl(ppa, PDK_PAL_PORT_EXISTS, (void *) 0) == 0)) {
			DEBUG2("rmapi_create_trunk(%d):  HAL %d not initialized\n", trunk_ppa, ppa);
			return(PSDB_PPA_OUT_RANGE);
		}

		if (pdk_pal_ctl(ppa, PDK_PAL_PORT_CONFIGURED,(void *) 0)) {
			return(PSDB_TRUNK_IN_USE);
		}

		if ((rmapi_znb_array[ppa].pz_is_trunk_member) ||
		    (rmapi_znb_array[ppa].pz_is_failover_member)) {

			return(PSDB_PPA_OUT_RANGE);
		}

		lowest_ppa = (ppa < lowest_ppa) ? ppa : lowest_ppa;
	}

	if (lowest_ppa == NUM_PORTS)
		return(PSDB_PPA_OUT_RANGE);

	pzp = &rmapi_znb_array[lowest_ppa];

	if (pzp->pz_trunk_built)
		return(PSDB_TRUNK_IN_USE);

	for (i=0;i<num_ppa;i++) {
		ppa = psdb_pton(ppa_array[i]);

		if (rmapi_znb_array[ppa].pz_is_trunk_member)
			continue;

		rmapi_znb_array[ppa].pz_is_trunk_member = 1;
		rmapi_znb_array[ppa].pz_trunk_ppa = trunk_ppa;
		pdk_pal_ctl(ppa,PDK_PAL_DESTROY_ZNB_IF,(void *)ppa);
	}

	pzp->pz_trunk_built = 1;

	pdk_pal_ctl(lowest_ppa, PDK_PAL_CREATE_ZRL_IF, (void *)trunk_ppa);
	return(0);
}

uint32_t
rmapi_create_failover(failover_ppa, num_ppa, ppa_array)
int32_t failover_ppa;
int32_t num_ppa;
int32_t *ppa_array;
{
	rmapi_znb_t *pzp;
	int32_t i, ppa;
	int32_t lowest_ppa = NUM_PORTS;

	DEBUG2("rmapi_create_failover(%d)\n", failover_ppa);

	if (num_ppa >= NUM_PORTS)
		return(PSDB_BAD_PARAM);

	for (i=0;i<num_ppa;i++) {
		ppa = psdb_pton(ppa_array[i]);

		if ((ppa >= NUM_PORTS) || (pdk_pal_ctl(ppa, PDK_PAL_PORT_EXISTS, (void *) 0) == 0))
			return(PSDB_PPA_OUT_RANGE);

		if (pdk_pal_ctl(ppa, PDK_PAL_PORT_CONFIGURED,(void *) 0)) {
			return(PSDB_FAILOVER_IN_USE);
		}

		if (rmapi_znb_array[ppa].pz_is_failover_member)
			return(PSDB_PPA_OUT_RANGE);

		lowest_ppa = (ppa < lowest_ppa) ? ppa : lowest_ppa;
	}

	if (lowest_ppa == NUM_PORTS)
		return(PSDB_PPA_OUT_RANGE);

	pzp = &rmapi_znb_array[lowest_ppa];

	if (pzp->pz_failover_built)
		return(PSDB_FAILOVER_IN_USE);

	for (i=0;i<num_ppa;i++) {
		ppa = psdb_pton(ppa_array[i]);

		if (rmapi_znb_array[ppa].pz_is_failover_member)
			continue;

		rmapi_znb_array[ppa].pz_is_failover_member = 1;
		rmapi_znb_array[ppa].pz_failover_ppa = failover_ppa;
		if (rmapi_znb_array[ppa].pz_trunk_built)
			pdk_pal_ctl(ppa, PDK_PAL_DESTROY_ZRL_IF, (void *)rmapi_znb_array[ppa].pz_trunk_ppa);
		else
			pdk_pal_ctl(ppa, PDK_PAL_DESTROY_ZNB_IF, (void *)ppa);

	}

	pzp->pz_failover_built = 1;
	pdk_pal_ctl(lowest_ppa, PDK_PAL_CREATE_ZRL_IF, (void *)failover_ppa);

	return(0);
}

uint32_t
rmapi_teardown_trunk(ppa)
int32_t ppa;
{
	rmapi_znb_t *pzp;
	int32_t trunk_ppa;
	int i;

	/* ppa has already been translated from the zrl value */

	DEBUG2("rmapi_teardown_trunk(%d)\n", ppa);

	if (ppa == -1) {
		DEBUG1("rmapi_teardown_trunk: zrl ppa not found\n");
		return(PSDB_LAYER_PUSH_ERROR);
	}

	pzp = &rmapi_znb_array[ppa];

	if (pzp->pz_trunk_built == 0)
		return(PSDB_PPA_OUT_RANGE);

	if (pzp->pz_failover_built)
		return(PSDB_FAILOVER_IN_USE);

	/* Don't allow teardown on up links */
	if (pdk_pal_ctl(ppa, PDK_PAL_PORT_CONFIGURED,(void *) 0))
		return(PSDB_TRUNK_IN_USE);

	trunk_ppa = pzp->pz_trunk_ppa;

	DEBUG2("rmapi_teardown_trunk(%d): Searching for members\n", ppa);
	for (i=0; i<NUM_PORTS; i++) {
		pzp = &rmapi_znb_array[i];

		DEBUG2("	(%d): trunk_ppa %d member %d built %d\n",i, pzp->pz_trunk_ppa, pzp->pz_is_trunk_member, pzp->pz_trunk_built);

		if (pzp->pz_trunk_ppa != trunk_ppa)
			continue;

		if (pzp->pz_is_trunk_member == 0)
			continue;

		if (pzp->pz_trunk_built)
			pdk_pal_ctl(i, PDK_PAL_DESTROY_ZRL_IF, (void *)rmapi_znb_array[i].pz_trunk_ppa);

		pdk_pal_ctl(i, PDK_PAL_CREATE_ZNB_IF, (void *)i);

		pzp->pz_trunk_built = 0;
		pzp->pz_is_trunk_member = 0;
	}

	return(0);
}

uint32_t
rmapi_teardown_failover(ppa)
int32_t ppa;
{
	rmapi_znb_t *pzp;
	int32_t failover_ppa;
	int i;

	/* ppa has already been translated from the zrl value */

	DEBUG2("rmapi_teardown_failover(%d)\n", ppa);

	if (ppa == -1) {
		DEBUG1("rmapi_teardown_failover: zrl ppa not found\n");
		return(PSDB_LAYER_PUSH_ERROR);
	}

	pzp = &rmapi_znb_array[ppa];

	if (pzp == 0)
		return(PSDB_PPA_OUT_RANGE);

	if (pzp->pz_failover_built == 0)
		return(PSDB_PPA_OUT_RANGE);

	/* Don't allow teardown on up links */
	if (pdk_pal_ctl(ppa, PDK_PAL_PORT_CONFIGURED,(void *) 0))
		return(PSDB_FAILOVER_IN_USE);

	failover_ppa = pzp->pz_failover_ppa;
	for (i=0; i<NUM_PORTS; i++) {
		pzp = &rmapi_znb_array[i];

		if (pzp == 0)
			continue;

		if (pzp->pz_failover_ppa != failover_ppa)
			continue;

		if (pzp->pz_is_failover_member == 0)
			continue;

		if (pzp->pz_failover_built)
			pdk_pal_ctl(i, PDK_PAL_DESTROY_ZRL_IF, (void *)rmapi_znb_array[i].pz_failover_ppa);

		if (pzp->pz_trunk_built)
			pdk_pal_ctl(i, PDK_PAL_CREATE_ZRL_IF, (void *)rmapi_znb_array[i].pz_trunk_ppa);
		else
			pdk_pal_ctl(i, PDK_PAL_CREATE_ZNB_IF, (void *)i);

		pzp->pz_failover_built = 0;
		pzp->pz_is_failover_member = 0;
	}

	return(0);
}

int32_t
rmapi_zrl_ppa_to_znb_ppa(zrl_ppa, pc_type)
int32_t zrl_ppa;
int32_t pc_type;
{
	rmapi_znb_t *pzp;
	int i;

	/* pc_type of zero get with precedence to failover
	 * and last trunk */
	switch(pc_type) {
		case 0:
		case PSDB_CONFIG_FAILOVER_TYPE:
			for (i=0; i<NUM_PORTS; i++) {
				pzp = &rmapi_znb_array[i];

				if (pzp == 0)
					continue;

				if (pzp->pz_failover_built == 0)
					continue;

				if (pzp->pz_failover_ppa == zrl_ppa)
					return(i);
			}
			if (pc_type != 0)
				break;
			/* else fall through */
		case PSDB_CONFIG_TRUNK_TYPE:
			for (i=0; i<NUM_PORTS; i++) {
				pzp = &rmapi_znb_array[i];

				if (pzp == 0)
					continue;

				if (pzp->pz_trunk_built == 0)
					continue;

				if (pzp->pz_trunk_ppa == zrl_ppa)
					return(i);
			}
			break;
	}

	return(-1);
}

int32_t
rmapi_znb_ppa_to_zrl_ppa(znb_ppa)
int32_t znb_ppa;
{
	rmapi_znb_t	*pzp;

	pzp = &rmapi_znb_array[znb_ppa];

	if (pzp == 0)
		return(-1);

	if (pzp->pz_failover_built)
		return(pzp->pz_failover_ppa);

	if (pzp->pz_trunk_built)
		return(pzp->pz_trunk_ppa);

	return(-1);
}

