/*==========================================================================
**
**	sal_dump.c
**
**	Packet dumper code
**
**==========================================================================
**
**	(c) Copyright 2001, 2002 ZNYX Networks
**	All Rights Reserved.
**
**==========================================================================
**
**	Modification History:
**	jr	02/18/02	new
**
**==========================================================================
*/

#include <pdk_port.h>
#include <pdk_global.h>
#include <pdk_types.h>
#include <pdk_time.h>
#include <pdk_print.h>
#include <pdk_hton.h>
#include <pdk_dump.h>




void	pdk_dump_ethernet_packet(char *prefix, int32_t ppa, uint8_t *p,
		int length, int flags)
{
	if(prefix == NULL) prefix = "ETH(%d)";

	if(p == NULL || length < 14) {
		pdk_print("pdk_dump_ethernet_packet(%s, %d, 0x%08x, %d)\n", prefix, (int)ppa, p, length);
		return;
	}

	pdk_print(prefix, ppa);

	if(flags == 0) flags = PDK_DUMP_LAYER2	| PDK_DUMP_LAYER3;

	if(flags & PDK_DUMP_LAYER2) {
		pdk_print("  %02x%02x%02x%02x%02x%02x %02x%02x%02x%02x%02x%02x %02x%02x %02x%02x%02x%02x len=%u\n",
			p[0], p[1], p[2], p[3], p[4], p[5],
			p[6], p[7], p[8], p[9], p[10], p[11],
			p[12], p[13],
			p[14], p[15], p[16], p[17],
			length);
	}

	if(!(flags & PDK_DUMP_LAYER3)) return;

	if(p[12] == 0x08 && p[13] == 0x06 && length >= 14+28) {
		uint8_t *arp = p+14, *a = arp+8;
		pdk_print("  arp: %s  sender=%02x%02x%02x%02x%02x%02x/%u.%u.%u.%u  target=%02x%02x%02x%02x%02x%02x/%u.%u.%u.%u\n",
		(arp[7] == 1) ? "reqst" : (arp[7] == 2) ? "reply" : "op???",
		a[0], a[1], a[2], a[3], a[4], a[5],
		a[6], a[7], a[8], a[9],
		a[10], a[11], a[12], a[13], a[14], a[15],
		a[16], a[17], a[18], a[19]);
	}

	if(p[12] == 0x08 && p[13] == 0x00 && length >= 14+20) {
		uint8_t *ip = p+14, *dp = (ip+((ip[0]&0x0f)<<2));
		pdk_print("  ip: %u.%u.%u.%u -> %u.%u.%u.%u",
		ip[12], ip[13], ip[14], ip[15],
		ip[16], ip[17], ip[18], ip[19]);

		if(ip[9] == 1) {
			/* icmp */
			static char *icmps[] = {
				"echo reply", "1", "2", "unreach", "quench",
				"redirect", "6", "7", "echo request", "9",
				"10", "time exc", "param pr", "timest req",
				"timest rep", "info req", "info rep",
				"amask req", "amask rep" };

			pdk_print(" icmp %s %u/%u id-seq/data=%02x.%02x.%02x.%02x\n",
				(dp[0] < 19) ? icmps[dp[0]] : "???",
				dp[0], dp[1], dp[4], dp[5], dp[6], dp[7]);
		} else if(ip[9] == 6 || ip[9] == 17) {
			/* tcp, udp */
			uint16_t *ports = (uint16_t*)dp;
			pdk_print(" %s %u -> %u\n",
				(ip[9] == 6) ? "tcp" : "udp",
				pdk_htons(ports[0]), pdk_htons(ports[1]));
		} else {
			pdk_print(" prot=%u ??\n", ip[9]);
		}
	}
}




