/*==========================================================================
**
**	./pdk/src/drivers/sal/sal_lock.c
**
**	System abstraction layer for Linux
**
**==========================================================================
**
**	(c) Copyright 1998 ZNYX Corporation
**	All Rights Reserved.
**
**==========================================================================
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**==========================================================================
**
**	Modification History:
**	david	03/03/99      	Created
**	jr	09/18/01	NB version, namespace cleanup
**				added pdk_lock_held() for debugging
**
**==========================================================================
**
**	Notes:
**==========================================================================
*/


#include <pdk_port.h>
#include <pdk_global.h>
#include <pdk_types.h>
#include <pdk_lock.h>
#include <pdk_print.h>
#include <pdk_lib.h>
#include <pdk_queue.h>
#include <pdk_linux.h>

#include <asm/bitops.h>
#include <asm/atomic.h>


#define DEBUG1 if (pdk_sal_debug>0) pdk_print

/*extern int sal_debug;*/

#define NUM_LOCKS	8*NUM_PORTS

static pdk_lock_t lock_array[NUM_LOCKS];

static pdk_lock_t *lock_freeq;




ulong
pdk_lock_global_init()
{
	int i;

	pdk_bzero(lock_array, sizeof(lock_array));
	lock_freeq = 0;

	for (i=0;i<NUM_LOCKS;i++)  {
		pdk_q_enq((pdk_q_t **) &lock_freeq, (pdk_q_t *) &lock_array[i]);
	}
	return(0);
}

ulong
pdk_lock_global_deinit()
{
	return 0;
}

ulong
pdk_lock_init(ppa)
int ppa;
{
	return 0;
}

ulong
pdk_lock_deinit(ppa)
int ppa;
{
	return 0;
}

pdk_lock_t *
pdk_lock_alloc(ppa, flags)
int ppa;
ulong flags;
{
	pdk_lock_t *lp;

	if ((lp = (pdk_lock_t *) pdk_q_deq((pdk_q_t **) &lock_freeq)) == 0) {
		pdk_print("pdk_lock_alloc: porting coding error. Increase NUM_LOCKS\n");
		return(0);
	}

	spin_lock_init(&lp->lock);

	lp->l_flags = flags;

	return(lp);
}

void
pdk_lock_free(lp)
pdk_lock_t *lp;
{
	pdk_q_enq((pdk_q_t **) &lock_freeq, (pdk_q_t *) lp);
}

int pdk_lock_held(pdk_lock_t *lp)
{
	return(atomic_read(&lp->lkcnt));
}

void pdk_lock_acquire(pdk_lock_t *lp)
{
/* lkcnt was for debugging, and could be removed now.
	if (atomic_read(&lp->lkcnt) != 0) {
		pdk_print("pdk_lock_acquire: ERROR 0x%x\n", (uint32_t)lp);
	}
*/

	if (lp->l_flags == PDK_LOCK_INTR)
		spin_lock_irqsave(&lp->lock, lp->save);
	else
		spin_lock(&lp->lock);

	atomic_inc(&lp->lkcnt);
}

void pdk_lock_release(pdk_lock_t *lp)
{
	atomic_dec(&lp->lkcnt);

/*
	if (atomic_read(&lp->lkcnt) != 0) {
		pdk_print("pdk_lock_release: ERROR 0x%x\n", (uint32_t)lp);
	}
*/

	if (lp->l_flags == PDK_LOCK_INTR)
		spin_unlock_irqrestore(&lp->lock, lp->save);
	else
		spin_unlock(&lp->lock);
}

