/*==========================================================================
**
**	./pdk/src/drivers/sal/sal_mem.c
**
**	System abstraction layer for Linux
**
**==========================================================================
**
**	(c) Copyright 1998 ZNYX Corporation
**	All Rights Reserved.
**
**==========================================================================
**
**	Modification History:
**	david   02/24/99	Created
**	jr	09/19/01	OA version, namespace cleanup
**
**==========================================================================
**
**	Notes:
**==========================================================================
*/
#include <pdk_port.h>
#include <pdk_global.h>
#include <pdk_types.h>
#include <pdk_mem.h>
#include <pdk_buf.h>
#include <pdk_print.h>
#include <pdk_queue.h>
#include <pdk_errno.h>
#include <pdk_lib.h>
#include <pdk_br554.h>
#include <pdk_linux.h>

/*
 * Patchable debug flag.
 */
/*extern int32_t sal_debug;*/

#define DEBUG1 if (pdk_sal_debug>0) pdk_print
#define DEBUG2 if (pdk_sal_debug>1) pdk_print
#define DEBUG3 if (pdk_sal_debug>2) pdk_print

/* memory function prototypes */
uint32_t
pdk_mem_global_init()
{
	return(0);
}

uint32_t
pdk_mem_global_deinit()
{
	return 0;
}

uint32_t
pdk_mem_init(ppa)
int32_t ppa;
{
	return 0;
}

uint32_t
pdk_mem_deinit(ppa)
int32_t ppa;
{
	return 0;
}

uchar *pdk_mem_alloc(int32_t ppa, uint32_t size)
{
#if (LINUX_VERSION_CODE >= 0x020400)
	return(kmalloc((size_t) size, in_irq() ? GFP_ATOMIC : GFP_KERNEL));
#else
	return(kmalloc((size_t) size, GFP_KERNEL | GFP_DMA));
#endif
}

void pdk_mem_free(int32_t ppa, uchar *p, uint32_t size)
{
	kfree((void *) p);
}

uchar *
pdk_mem_zalloc(ppa, size)
int32_t ppa;
uint32_t size;
{
	uchar *mem;

	mem = pdk_mem_alloc(ppa, size);
	pdk_bzero(mem, size);
	return(mem);
}


pdk_desc_handle_t *
pdk_mem_desc_alloc(ppa, n, size)
int32_t ppa;
uint32_t n;
uint32_t size;
{
	pdk_desc_handle_t *dhp;

	size = (((size-1)/PDK_CACHELINE)+1) * PDK_CACHELINE;

	if((dhp = (pdk_desc_handle_t *) pdk_mem_zalloc(ppa, sizeof(pdk_desc_handle_t))) == NULL) {
		DEBUG1("pdk_mem_desc_alloc: alloc handle failed.\n");
		return(NULL);
	}

#if (LINUX_VERSION_CODE >= 0x020400)
	dhp->d_desc_mem = (caddr_t)pci_alloc_consistent(znb_pdev[ppa], size*n, &dhp->d_paddr);
#else
	if((dhp->d_desc_mem = pdk_mem_zalloc(ppa, size * n)) != NULL) {
		dhp->d_paddr = virt_to_bus(dhp->d_desc_mem);
	}
#endif

#if 0
 mmc	if (!dhp || (dhp->d_desc_mem = (caddr_t)pci_alloc_consistent(znb_pdev[ppa], size*n, &dhp->d_paddr)) == 0) {
#endif
	if(!dhp->d_desc_mem) {
		DEBUG1("pdk_mem_desc_alloc: alloc failed.\n");
		return(NULL);
	}

	dhp->d_pdev = znb_pdev[ppa];
	dhp->d_size = size;
	dhp->d_endoff = size*n;

	DEBUG2("pdk_mem_desc_alloc: vaddr=0x%x paddr=0x%x len=0x%x\n", (uint32_t)dhp->d_desc_mem, (uint32_t)dhp->d_paddr, size*n);

	return(dhp);
}

void
pdk_mem_desc_free(dhp)
pdk_desc_handle_t *dhp;
{
#if (LINUX_VERSION_CODE >= 0x020400)
	pci_free_consistent(dhp->d_pdev,dhp->d_endoff,dhp->d_desc_mem,dhp->d_paddr);
#else
	kfree((void *)dhp->d_desc_mem);
#endif
	kfree((void *)dhp);
}

pdk_desc_handle_t *
pdk_mem_desc_get_pmap(dhp, vaddrp, paddrp, errp)
pdk_desc_handle_t *dhp;
void **vaddrp;
uint32_t *paddrp;
int32_t *errp;
{

	if (dhp->d_nextoff >= dhp->d_endoff) {
		*errp = PDK_NO_ROOM;
		return(0);
	}

	/* d_paddr set at allocation */
	*vaddrp = (void *) (dhp->d_desc_mem + dhp->d_nextoff);
	*paddrp = ((uint32_t)dhp->d_paddr) + dhp->d_nextoff;
	*errp = 0;

	dhp->d_nextoff += dhp->d_size;

	if (dhp->d_nextoff >= dhp->d_endoff) {
		dhp->d_nextoff = 0;
		return(0);
	}

	return(dhp);
}


