/*
 *      $Id: ip_wccp.c,v 1.1 1999/09/30 20:43:37 wessels Exp $
 *
 * Glenn Chisholm <glenn@ircache.net>
 * Jorge Boncompte <jorge@dti2.net> (Modified for kernel 2.4)
 */

#include <linux/config.h>
#include <linux/module.h>
#include <linux/types.h>
#include <linux/sched.h>
#include <linux/kernel.h>
#include <linux/skbuff.h>
#include <linux/netdevice.h>
#include <linux/in.h>
#include <linux/if_arp.h>
#include <linux/init.h>
#include <linux/inetdevice.h>
#include <linux/netfilter_ipv4.h>

#include <net/ip.h>

MODULE_LICENSE("GPL");

#define WCCP_PROTOCOL_TYPE 	0x883E
#define WCCP_GRE_LEN		sizeof(long)
#define WCCP2_GRE_EXTRA	sizeof(long)

static rwlock_t ipwccp_lock = RW_LOCK_UNLOCKED;

int ip_wccp_rcv(struct sk_buff *skb, unsigned short len)
{
	long *gre_hdr;

	gre_hdr = (unsigned long *)skb->h.raw;

	if(*gre_hdr != htonl(WCCP_PROTOCOL_TYPE)) 
		{
		printk(KERN_INFO "ip_wccp: Not a valid WCCP packet. Wrong protocol type\n");
		goto drop_nolock;
		}

	read_lock(&ipwccp_lock);

	skb->mac.raw = skb->nh.raw;
    /* WCCP2 puts an extra 4 octets into the header, but uses the same
       encapsulation type; if it looks as if the first octet of the packet
       isn't the beginning of an IPv4 header, assume it's WCCP2. */
    if ((skb->h.raw[WCCP_GRE_LEN] & 0xF0) != 0x40) {
                skb->nh.raw = skb_pull(skb, skb->h.raw + WCCP_GRE_LEN + WCCP2_GRE_EXTRA - skb->data);
        } else { 
                skb->nh.raw = skb_pull(skb, skb->h.raw + WCCP_GRE_LEN - skb->data);
        }

	if (skb->len <= 0) 
		{
		printk(KERN_INFO "ip_wccp: Not a valid IP packet. Wrong packet lenght\n");
                goto drop;
		}

	memset(&(IPCB(skb)->opt), 0, sizeof(struct ip_options));
/*	skb->protocol = *(u16*)(h + 2);*/
	skb->protocol = __constant_htons(ETH_P_IP);
	skb->pkt_type = PACKET_HOST;
	skb->ip_summed = 0;
	dst_release(skb->dst);
	skb->dst = NULL;

#ifdef CONFIG_NETFILTER
	nf_conntrack_put(skb->nfct);
	skb->nfct = NULL;

#ifdef CONFIG_NETFILTER_DEBUG
	skb->nf_debug = 0;
#endif
#endif

/*	printk(KERN_DEBUG "ip_wccp: Packet received SRC=%u.%u.%u.%u DST=%u.%u.%u.%u \n",
	       NIPQUAD(skb->nh.iph->saddr), NIPQUAD(skb->nh.iph->daddr));*/
/*        ip_rcv(skb, skb->dev, NULL); */

	netif_rx(skb);
	read_unlock(&ipwccp_lock);
	return(0);

drop:
	read_unlock(&ipwccp_lock);
drop_nolock:
	printk(KERN_DEBUG "ip_wccp: Packet dropped SRC=%u.%u.%u.%u DST=%u.%u.%u.%u \n",
	       NIPQUAD(skb->nh.iph->saddr), NIPQUAD(skb->nh.iph->daddr));
	kfree_skb(skb);
	return(0);
}

static struct inet_protocol ipgre_protocol = {
  ip_wccp_rcv,     
  NULL,           
  0,            
  IPPROTO_GRE, 
  0,          
  NULL,      
  "GRE"     
};

#ifdef MODULE
int init_module(void) 
#else
int __init ipwccp_init(void)
#endif
{
	printk(KERN_INFO "ip_wccp: WCCP IPv4/GRE driver loaded\n");
	inet_add_protocol(&ipgre_protocol);
	return 0;
}

#ifdef MODULE

void cleanup_module(void)
{
	if ( inet_del_protocol(&ipgre_protocol) < 0 )
		printk(KERN_INFO "ip_wccp: on close can't remove protocol\n");
	else
		printk(KERN_INFO "ip_wccp: WCCP IPv4/GRE driver unloaded\n");
}

#endif
